@@ -1,19 +1,23 @@
-/***************************************************************************
-                                 krarc.cpp
-                             -------------------
-    begin                : Sat Jun 14 14:42:49 IDT 2003
-    copyright            : (C) 2003 by Rafi Yanai & Shie Erlich
-    email                : krusader@users.sf.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Rafi Yanai <krusader@users.sf.net>                     *
+ * Copyright (C) 2003 Shie Erlich <krusader@users.sf.net>                    *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krarc.h"
 #include "../krusader/defaults.h"
@@ -37,6 +41,8 @@
 #include <KIO/Job>
 #include <KIOCore/KFileItem>
 
+#include <kio_version.h>
+
 #include <errno.h>
 
 #define MAX_IPC_SIZE           (1024*32)
@@ -196,18 +202,27 @@ void kio_krarcProtocol::receivedData(KProcess *, QByteArray &d)
 void kio_krarcProtocol::mkdir(const QUrl &url, int permissions)
 {
     KRFUNC;
-    KRDEBUG(getPath(url));
+    const QString path = getPath(url);
+    KRDEBUG(path);
 
     if (!checkWriteSupport())
         return;
 
+    // In case of KIO::mkpath call there is a mkdir call for every path element.
+    // Therefore the path all the way up to our archive needs to be checked for existence
+    // and reported as success.
+    if (QDir().exists(path)) {
+        finished();
+        return;
+    }
+
     if (!setArcFile(url)) {
-        error(ERR_CANNOT_ENTER_DIRECTORY, getPath(url));
+        error(ERR_CANNOT_ENTER_DIRECTORY, path);
         return;
     }
 
     if (newArchiveURL && !initDirDict(url)) {
-        error(ERR_CANNOT_ENTER_DIRECTORY, getPath(url));
+        error(ERR_CANNOT_ENTER_DIRECTORY, path);
         return;
     }
 
@@ -217,8 +232,10 @@ void kio_krarcProtocol::mkdir(const QUrl &url, int permissions)
         return;
     }
 
+    const QString arcFilePath = getPath(arcFile->url());
+
     if (arcType == "arj" || arcType == "lha") {
-        QString arcDir = getPath(url).mid(getPath(arcFile->url()).length());
+        QString arcDir = path.mid(arcFilePath.length());
         if (arcDir.right(1) != DIR_SEPARATOR) arcDir = arcDir + DIR_SEPARATOR;
 
         if (dirDict.find(arcDir) == dirDict.end())
@@ -228,7 +245,7 @@ void kio_krarcProtocol::mkdir(const QUrl &url, int permissions)
     }
 
     QString arcDir  = findArcDirectory(url);
-    QString tempDir = arcDir.mid(1) + getPath(url).mid(getPath(url).lastIndexOf(DIR_SEPARATOR) + 1);
+    QString tempDir = arcDir.mid(1) + path.mid(path.lastIndexOf(DIR_SEPARATOR) + 1);
     if (tempDir.right(1) != DIR_SEPARATOR) tempDir = tempDir + DIR_SEPARATOR;
 
     if (permissions == -1) permissions = 0777;  //set default permissions
@@ -245,7 +262,7 @@ void kio_krarcProtocol::mkdir(const QUrl &url, int permissions)
 
     // pack the directory
     KrLinecountingProcess proc;
-    proc << putCmd << getPath(arcFile->url()) << localeEncodedString(tempDir);
+    proc << putCmd << arcFilePath << localeEncodedString(tempDir);
     infoMessage(i18n("Creating %1...", url.fileName()));
     QDir::setCurrent(arcTempDir);
 
@@ -259,7 +276,7 @@ void kio_krarcProtocol::mkdir(const QUrl &url, int permissions)
     QDir().rmdir(arcTempDir);
 
     if (proc.exitStatus() != QProcess::NormalExit || !checkStatus(proc.exitCode()))  {
-        error(ERR_COULD_NOT_WRITE, getPath(url) + "\n\n" + proc.getErrorMsg());
+        error(ERR_COULD_NOT_WRITE, path + "\n\n" + proc.getErrorMsg());
         return;
     }
 
@@ -334,14 +351,26 @@ void kio_krarcProtocol::put(const QUrl &url, int permissions, KIO::JobFlags flag
         ba.prepend(arcTempDirEnc);
         fd = QT_OPEN(ba, O_CREAT | O_TRUNC | O_WRONLY, initialMode);
     }
+
     QByteArray buffer;
     int readResult;
+    bool isIncomplete = false;
     do {
         dataReq();
         readResult = readData(buffer);
-        ::write(fd, buffer.data(), buffer.size());
+        auto bytesWritten = ::write(fd, buffer.data(), buffer.size());
+        if (bytesWritten < buffer.size()) {
+            isIncomplete = true;
+            break;
+        }
     } while (readResult > 0);
     ::close(fd);
+
+    if (isIncomplete) {
+        error(ERR_COULD_NOT_WRITE, getPath(url));
+        return;
+    }
+
     // pack the file
     KrLinecountingProcess proc;
     proc << putCmd << getPath(arcFile->url()) << localeEncodedString(tempFile);
@@ -764,6 +793,8 @@ void kio_krarcProtocol::copy(const QUrl &url, const QUrl &dest, int, KIO::JobFla
 
 void kio_krarcProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags)
 {
+    Q_UNUSED(flags);
+
     KRDEBUG("renaming from: " << src.path() << " to: " << dest.path());
     KRDEBUG("command: " << arcPath);
 
@@ -1794,9 +1825,18 @@ QString kio_krarcProtocol::getPassword()
 
     authInfo.password.clear();
 
+#if KIO_VERSION_MINOR >= 24
+    int errCode = openPasswordDialogV2(authInfo, i18n("Accessing the file requires a password."));
+    if (!errCode && !authInfo.password.isNull()) {
+#else
     if (openPasswordDialog(authInfo, i18n("Accessing the file requires a password.")) && !authInfo.password.isNull()) {
+#endif
         KRDEBUG(authInfo.password);
         return (password = authInfo.password);
+#if KIO_VERSION_MINOR >= 24
+    } else {
+        error(errCode, QString());
+#endif
     }
 
     KRDEBUG(password);
