@@ -1,19 +1,21 @@
 /*****************************************************************************
  * Copyright (C) 2004-2007 Jonas Bähr <jonas.baehr@web.de>                   *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "actionproperty.h"
@@ -23,19 +25,17 @@
 #include "../UserAction/kraction.h"
 #include "../krusader.h"
 #include "../krglobal.h"
+#include "../icon.h"
 
 // QtWidgets
 #include <QFileDialog>
 #include <QInputDialog>
 
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 #include <KXmlGui/KActionCollection>
 
 
-#define ICON(N)  KIconLoader::global()->loadIcon(N, KIconLoader::Small)
-
 ActionProperty::ActionProperty(QWidget *parent, KrAction *action)
         : QWidget(parent), _modified(false)
 {
@@ -47,8 +47,8 @@ ActionProperty::ActionProperty(QWidget *parent, KrAction *action)
         updateGUI(_action);
     }
 
-    ButtonAddPlaceholder->setIcon(ICON("list-add"));
-    ButtonAddStartpath->setIcon(ICON("document-open"));
+    ButtonAddPlaceholder->setIcon(Icon("list-add"));
+    ButtonAddStartpath->setIcon(Icon("document-open"));
 
     // fill with all existing categories
     cbCategory->addItems(krUserAction->allCategories());
@@ -290,7 +290,7 @@ void ActionProperty::updateAction(KrAction *action)
 
     _action->setConfirmExecution(chkConfirmExecution->isChecked());
 
-    _action->setIcon(QIcon::fromTheme(ButtonIcon->icon()));
+    _action->setIcon(Icon(ButtonIcon->icon()));
     _action->setIconName(ButtonIcon->icon());
 
     _action->setUser(leDifferentUser->text());
