@@ -1,27 +1,30 @@
 /*****************************************************************************
  * Copyright (C) 2004 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2004 Rafi Yanai <yanai@users.sourceforge.net>               *
- * Copyright (C) Jonas Bähr <jonas.baehr@web.de>                             *
+ * Copyright (C) 2004 Jonas Bähr <jonas.baehr@web.de>                        *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "addplaceholderpopup.h"
 
 // for ParameterDialog
 #include "../krglobal.h" // for konfig-access
+#include "../icon.h"
 #include "../BookMan/krbookmarkbutton.h"
 #include "../GUI/profilemanager.h"
 
@@ -304,7 +307,7 @@ ParameterPlaceholder::ParameterPlaceholder(const exp_parameter& parameter, QWidg
     _lineEdit = new KLineEdit(hboxWidget);
     hbox->addWidget(_lineEdit);
     _button = new QToolButton(hboxWidget);
-    _button->setIcon(QIcon::fromTheme("list-add"));
+    _button->setIcon(Icon("list-add"));
     hbox->addWidget(_button);
     connect(_button, SIGNAL(clicked()), this, SLOT(addPlaceholder()));
 }
@@ -417,7 +420,7 @@ ParameterFile::ParameterFile(const exp_parameter& parameter, QWidget* parent) :
     hbox->addWidget(_lineEdit);
     _button = new QToolButton(hboxWidget);
     hbox->addWidget(_button);
-    _button->setIcon(QIcon::fromTheme("document-open"));
+    _button->setIcon(Icon("document-open"));
     connect(_button, SIGNAL(clicked()), this, SLOT(addFile()));
 }
 
@@ -530,10 +533,10 @@ ParameterGoto::ParameterGoto(const exp_parameter& parameter, QWidget* parent) :
     hbox->addWidget(_lineEdit);
     _dirButton = new QToolButton(hboxWidget);
     hbox->addWidget(_dirButton);
-    _dirButton->setIcon(QIcon::fromTheme("document-open"));
+    _dirButton->setIcon(Icon("document-open"));
     connect(_dirButton, SIGNAL(clicked()), this, SLOT(setDir()));
     _placeholderButton = new QToolButton(hboxWidget);
-    _placeholderButton->setIcon(QIcon::fromTheme("list-add"));
+    _placeholderButton->setIcon(Icon("list-add"));
     hbox->addWidget(_placeholderButton);
     connect(_placeholderButton, SIGNAL(clicked()), this, SLOT(addPlaceholder()));
 
