@@ -1,19 +1,21 @@
 /*****************************************************************************
  * Copyright (C) 2006 Jonas Bähr <jonas.baehr@web.de>                        *
+ * Copyright (C) 2006-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "useractionlistview.h"
@@ -24,9 +26,9 @@
 #include <QDomEntity>
 
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../UserAction/kraction.h"
 #include "../UserAction/useraction.h"
 
@@ -237,7 +239,7 @@ void UserActionListViewItem::update()
         return;
 
     if (! _action->icon().isNull())
-        setIcon(COL_TITLE, KIconLoader::global()->loadIcon(_action->iconName(), KIconLoader::Small));
+        setIcon(COL_TITLE, Icon(_action->iconName()));
     setText(COL_TITLE, _action->text());
 }
 
@@ -245,7 +247,7 @@ bool UserActionListViewItem::operator<(const QTreeWidgetItem &other) const
 {
 // FIXME some how this only produces bullshit :-/
 //   if ( i->text( COL_NAME ).isEmpty() ) { // categories only have titles
-//      //qDebug() << "this->title: " << text(COL_TITLE) << " |=|   i->title: " << i->text(COL_TITLE)  << endl;
+//      //qDebug() << "this->title: " << text(COL_TITLE) << " |=|   i->title: " << i->text(COL_TITLE);
 //       return ( ascending ? -1 : 1 ); // <0 means this is smaller then i
 //    }
 //    else
