@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2006 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2006 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2006-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "useractionpage.h"
@@ -35,7 +37,6 @@
 #include <KWidgetsAddons/KStandardGuiItem>
 #include <KCompletion/KLineEdit>
 #include <KWidgetsAddons/KMessageBox>
-#include <KIconThemes/KIconLoader>
 
 #include "actionproperty.h"
 #include "useractionlistview.h"
@@ -43,8 +44,9 @@
 #include "../UserAction/kraction.h"
 #include "../krusader.h"
 #include "../krglobal.h"
+#include "../icon.h"
+
 
-#define ICON(N)  KIconLoader::global()->loadIcon(N, KIconLoader::Toolbar)
 //This is the filter in the QFileDialog of Import/Export:
 static const char* FILE_FILTER = I18N_NOOP("*.xml|XML files\n*|All files");
 
@@ -62,32 +64,32 @@ UserActionPage::UserActionPage(QWidget* parent)
     toolbarLayout->setContentsMargins(0, 0, 0, 0);
 
     newButton = new QToolButton(this);
-    newButton->setIcon(ICON("document-new"));
+    newButton->setIcon(Icon("document-new"));
     newButton->setAutoRaise(true);
     newButton->setToolTip(i18n("Create new useraction"));
 
     importButton = new QToolButton(this);
-    importButton->setIcon(ICON("document-import"));
+    importButton->setIcon(Icon("document-import"));
     importButton->setAutoRaise(true);
     importButton->setToolTip(i18n("Import useractions"));
 
     exportButton = new QToolButton(this);
-    exportButton->setIcon(ICON("document-export"));
+    exportButton->setIcon(Icon("document-export"));
     exportButton->setAutoRaise(true);
     exportButton->setToolTip(i18n("Export useractions"));
 
     copyButton = new QToolButton(this);
-    copyButton->setIcon(ICON("edit-copy"));
+    copyButton->setIcon(Icon("edit-copy"));
     copyButton->setAutoRaise(true);
     copyButton->setToolTip(i18n("Copy useractions to clipboard"));
 
     pasteButton = new QToolButton(this);
-    pasteButton->setIcon(ICON("edit-paste"));
+    pasteButton->setIcon(Icon("edit-paste"));
     pasteButton->setAutoRaise(true);
     pasteButton->setToolTip(i18n("Paste useractions from clipboard"));
 
     removeButton = new QToolButton(this);
-    removeButton->setIcon(ICON("edit-delete"));
+    removeButton->setIcon(Icon("edit-delete"));
     removeButton->setAutoRaise(true);
     removeButton->setToolTip(i18n("Delete selected useractions"));
 
@@ -228,7 +230,7 @@ void UserActionPage::slotRemoveAction()
                         KStandardGuiItem::remove(), //Label for the continue-button
                         KStandardGuiItem::cancel(),
                         "Confirm Remove UserAction", //dontAskAgainName (for the config-file)
-                        KMessageBox::Dangerous | KMessageBox::Notify) ;
+                        KMessageBox::Dangerous | KMessageBox::Notify);
 
     if (messageDelete != KMessageBox::Continue)
         return;
