@@ -1,32 +1,22 @@
-/***************************************************************************
-                         packjob.cpp  -  description
-                             -------------------
-    copyright            : (C) 2009 + by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2009 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2009-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "abstractthreadedjob.h"
 
@@ -48,7 +38,6 @@
 #include "../krglobal.h"
 #include "../krservices.h"
 #include "../FileSystem/filesystemprovider.h"
-#include "../FileSystem/filesystem.h"
 
 extern KRarcHandler arcHandler;
 
@@ -511,14 +500,14 @@ void countFiles(const QString &path, unsigned long &totalFiles, bool &stop)
     }
 }
 
-void AbstractJobThread::countLocalFiles(const QUrl &baseUrl, const QStringList &files,
+void AbstractJobThread::countLocalFiles(const QUrl &baseUrl, const QStringList &names,
                                        unsigned long &totalFiles)
 {
     sendReset(i18n("Counting files"));
 
     FileSystem *calcSpaceFileSystem = FileSystemProvider::instance().getFilesystem(baseUrl);
-    calcSpaceFileSystem->refresh(baseUrl);
-    for (const QString name : files) {
+    calcSpaceFileSystem->scanDir(baseUrl);
+    for (const QString name : names) {
         if (_exited)
             return;
 
