@@ -1,32 +1,23 @@
-/***************************************************************************
-                                krarchandler.cpp
-                            -------------------
-   copyright            : (C) 2001 by Shie Erlich & Rafi Yanai
-   email                : krusader@users.sourceforge.net
-   web site   : http://krusader.sourceforge.net
----------------------------------------------------------------------------
- Description
-***************************************************************************
-
- A
-
-    db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-    88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-    88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-    88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-    88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-    YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                    S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krarchandler.h"
 
@@ -118,10 +109,10 @@ QStringList KRarcHandler::supportedPackers()
     if (KrServices::cmdExist("dpkg")) packers.append("dpkg");
     if (KrServices::cmdExist("7z") || KrServices::cmdExist("7za")) packers.append("7z");
     if (KrServices::cmdExist("rpm") && KrServices::cmdExist("rpm2cpio")) packers.append("rpm");
-    // qDebug() << "Supported Packers:" << endl;
+    // qDebug() << "Supported Packers:";
     //QStringList::Iterator it;
     //for( it = packers.begin(); it != packers.end(); ++it )
-    // qDebug() << *it << endl;
+    // qDebug() << *it;
 
     return packers;
 }
@@ -263,7 +254,7 @@ bool KRarcHandler::unpack(QString archive, QString type, QString password, QStri
     QStringList packer;
 
     // set the right packer to do the job
-    if (type == "zip") packer << KrServices::fullPathName("unzip") << "-o" ;
+    if (type == "zip") packer << KrServices::fullPathName("unzip") << "-o";
     else if (type == "tar") packer << KrServices::fullPathName("tar") << "-xvf";
     else if (type == "tgz") packer << KrServices::fullPathName("tar") << "-xvzf";
     else if (type == "tarz") packer << KrServices::fullPathName("tar") << "-xvzf";
