@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef KRBOOKMARK_H
@@ -26,21 +28,27 @@
 // QtWidgets
 #include <QAction>
 
-
 class KActionCollection;
+class ListPanelActions;
+
 
 class KrBookmark: public QAction
 {
     Q_OBJECT
 public:
-    KrBookmark(QString name, QUrl url, KActionCollection *parent, QString icon = "", QString actionName = QString());
-    explicit KrBookmark(QString name, QString icon = ""); // creates a folder
+    KrBookmark(QString name, QUrl url, KActionCollection *parent, QString iconName = "", QString actionName = QString());
+    explicit KrBookmark(QString name, QString iconName = ""); // creates a folder
     ~KrBookmark();
+
     // text() and setText() to change the name of the bookmark
     // icon() and setIcon() to change icons
+
+    void setIconName(QString iconName);
+
     inline const QString& iconName() const {
-        return _icon;
+        return _iconName;
     }
+
     inline const QUrl &url() const {
         return _url;
     }
@@ -57,12 +65,14 @@ public:
         return _children;
     }
 
-    static KrBookmark* getExistingBookmark(QString actionName, KActionCollection *collection);
+    static KrBookmark * getExistingBookmark(QString actionName, KActionCollection *collection);
+
     // ----- special bookmarks
-    static KrBookmark* trash(KActionCollection *collection);
-    static KrBookmark* virt(KActionCollection *collection);
-    static KrBookmark* lan(KActionCollection *collection);
-    static KrBookmark* separator();
+    static KrBookmark * trash(KActionCollection *collection);
+    static KrBookmark * virt(KActionCollection *collection);
+    static KrBookmark * lan(KActionCollection *collection);
+    static QAction * jumpBackAction(KActionCollection *collection, bool isSetter = false, ListPanelActions *sourceActions = 0);
+    static KrBookmark * separator();
 
 signals:
     void activated(const QUrl &url);
@@ -73,7 +83,7 @@ protected slots:
 
 private:
     QUrl _url;
-    QString _icon;
+    QString _iconName;
     bool _folder;
     bool _separator;
     bool _autoDelete;
