@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef KRBOOKMARKHANDLER_H
@@ -30,6 +32,8 @@
 #include <QDomEntity>
 // QtWidgets
 #include <QMenu>
+#include <QWidgetAction>
+#include <QLineEdit>
 
 #include "krbookmark.h"
 
@@ -57,11 +61,10 @@ protected:
     void exportToFile();
     void exportToFileFolder(QDomDocument &doc, QDomElement &parent, KrBookmark *folder);
     void exportToFileBookmark(QDomDocument &doc, QDomElement &where, KrBookmark *bm);
-    void clearBookmarks(KrBookmark *root);
-    void buildMenu(KrBookmark *parent, QMenu *menu);
+    void clearBookmarks(KrBookmark *root, bool removeBookmarks = true);
+    void buildMenu(KrBookmark *parent, QMenu *menu, int depth = 0);
 
     bool eventFilter(QObject *obj, QEvent *ev);
-
     void rightClicked(QMenu *menu, KrBookmark *bm);
     void rightClickOnSpecialBookmark();
 
@@ -81,6 +84,16 @@ private:
 
     QPointer<QMenu>            _mainBookmarkPopup; // main bookmark popup menu
     QList<QAction *>           _specialBookmarks; // the action list of the special bookmarks
+
+    QWidgetAction *_quickSearchAction; ///< Search bar container action
+    QLineEdit *_quickSearchBar; ///< Search bar containing current query
+    QMenu *_quickSearchMenu; ///< The menu where the search is performed
+    QHash<QAction *, QString> _quickSearchOriginalActionTitles; ///< Saved original action text values to restore after search
+
+    void _setQuickSearchText(const QString &text);
+    QString _quickSearchText() const;
+    static void _highlightAction(QAction *action, bool isMatched = true);
+    void _resetActionTextAndHighlighting();
 };
 
 Q_DECLARE_METATYPE(KrBookmark *)
