@@ -2,25 +2,28 @@
  * Copyright (C) 2005 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2007-2008 Csaba Karai <cskarai@freemail.hu>                 *
  * Copyright (C) 2008 Jonas Bähr <jonas.baehr@web.de>                        *
+ * Copyright (C) 2005-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "checksumdlg.h"
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../krservices.h"
 #include "../krusader.h"
 #include "../GUI/krlistwidget.h"
@@ -44,7 +47,6 @@
 
 #include <KI18n/KLocalizedString>
 #include <KIOWidgets/KUrlRequester>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 
 void Checksum::startCreationWizard(const QString &path, const QStringList &files)
@@ -192,7 +194,7 @@ QWizardPage *ChecksumWizard::createProgressPage(const QString &title)
 
     page->setTitle(title);
     page->setPixmap(QWizard::LogoPixmap,
-                    krLoader->loadIcon("process-working", KIconLoader::Desktop, 32));
+                    Icon("process-working").pixmap(32));
     page->setSubTitle(i18n("Please wait..."));
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -265,7 +267,7 @@ QWizardPage *CreateWizard::createIntroPage()
 
     page->setTitle(i18n("Create Checksums"));
     page->setPixmap(QWizard::LogoPixmap,
-                    krLoader->loadIcon("document-edit-sign", KIconLoader::Desktop, 32));
+                    Icon("document-edit-sign").pixmap(32));
     page->setSubTitle(i18n("About to calculate checksum for the following files or directories:"));
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -363,8 +365,7 @@ void CreateWizard::onResultPage()
 
     QWizardPage *page = currentPage();
     page->setPixmap(QWizard::LogoPixmap,
-        krLoader->loadIcon(errors || !successes ? "dialog-error" : "dialog-information",
-                           KIconLoader::Desktop, 32));
+        Icon(errors || !successes ? "dialog-error" : "dialog-information").pixmap(32));
     page->setSubTitle(errors || !successes ?
                           i18n("Errors were detected while creating the checksums") :
                           i18n("Checksums were created successfully"));
@@ -479,7 +480,7 @@ QWizardPage *VerifyWizard::createIntroPage()
 
     page->setTitle(i18n("Verify Checksum File"));
     page->setPixmap(QWizard::LogoPixmap,
-                    krLoader->loadIcon("document-edit-verify", KIconLoader::Desktop, 32));
+                    Icon("document-edit-verify").pixmap(32));
     page->setSubTitle(i18n("About to verify the following checksum file"));
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -555,8 +556,7 @@ void VerifyWizard::onResultPage()
 
     QWizardPage *page = currentPage();
     page->setPixmap(QWizard::LogoPixmap,
-                    krLoader->loadIcon(errors ? "dialog-error" : "dialog-information",
-                                       KIconLoader::Desktop, 32));
+                    Icon(errors ? "dialog-error" : "dialog-information").pixmap(32));
     page->setSubTitle(errors ? i18n("Errors were detected while verifying the checksums") :
                                i18n("Checksums were verified successfully"));
 
