@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2000 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef KRDIALOGS_H
@@ -57,8 +59,6 @@ public:
     struct ChooseResult {
         QUrl url;
         bool enqueue;
-        bool preserveAttrs; // NOTE: field never read
-        QUrl baseURL;       // NOTE: field never read
     };
 
     /**
@@ -69,8 +69,7 @@ public:
      */
     static QUrl getFile(const QString &text, const QUrl &url, const QUrl &cwd);
     static QUrl getDir(const QString &text, const QUrl &url, const QUrl &cwd);
-    static ChooseResult getCopyDir(const QString &text, const QUrl &url, const QUrl &cwd,
-                                   bool preserveAttrs = false, const QUrl &baseURL = QUrl());
+    static ChooseResult getCopyDir(const QString &text, const QUrl &url, const QUrl &cwd);
 
 
   private:
@@ -81,33 +80,23 @@ class KUrlRequesterDlgForCopy : public QDialog
 {
     Q_OBJECT
 public:
-    KUrlRequesterDlgForCopy(const QUrl& url, const QString& text, bool presAttrs, QWidget *parent,
-                            bool modal = true, const QUrl &baseURL = QUrl());
+    KUrlRequesterDlgForCopy(const QUrl& url, const QString& text, QWidget *parent,
+                            bool modal = true);
 
     QUrl selectedURL() const;
-    QUrl baseURL() const;
-    bool preserveAttrs();
     bool isQueued() { return queueStart; }
-    bool copyDirStructure();
-    void hidePreserveAttrs() {
-//         preserveAttrsCB->hide();
-    }
 
     KUrlRequester *urlRequester();
 
 protected:
     virtual void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
 
-
 private slots:
     void slotQueueButtonClicked();
     void slotTextChanged(const QString &);
-    void slotDirStructCBChanged();
+
 private:
     KUrlRequester *urlRequester_;
-    QComboBox *baseUrlCombo;
-//     QCheckBox *preserveAttrsCB;
-    QCheckBox *copyDirStructureCB;
     QPushButton *okButton;
     bool queueStart = false;
 };
