@@ -2,20 +2,22 @@
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
  * Copyright (C) 2009 Fathi Boudra <fboudra@gmail.com>                       *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "newftpgui.h"
@@ -35,13 +37,22 @@
 #include <KConfigCore/KConfigGroup>
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KIOCore/KProtocolInfo>
 
 #include "../krglobal.h"
+#include "../icon.h"
 
 #define SIZE_MINIMUM QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed)
 
+const QStringList sProtocols = QStringList()
+                               << QStringLiteral("ftp") << QStringLiteral("ftps")
+                               << QStringLiteral("sftp")
+                               << QStringLiteral("fish") << QStringLiteral("nfs")
+                               << QStringLiteral("smb") << QStringLiteral("webdav")
+                               << QStringLiteral("svn") << QStringLiteral("svn+file")
+                               << QStringLiteral("svn+http") << QStringLiteral("svn+https")
+                               << QStringLiteral("svn+ssh");
+
 /**
  * Constructs a newFTPGUI which is a child of 'parent',
  * with the name 'name' and widget flags set to 'f'
@@ -50,7 +61,7 @@ newFTPGUI::newFTPGUI(QWidget* parent) : QDialog(parent)
 {
     setModal(true);
     setWindowTitle(i18n("New Network Connection"));
-    resize(400, 240);
+    resize(500, 240);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
@@ -60,7 +71,7 @@ newFTPGUI::newFTPGUI(QWidget* parent) : QDialog(parent)
     setSizePolicy(policy);
 
     iconLabel = new QLabel(this);
-    iconLabel->setPixmap(krLoader->loadIcon("network-wired", KIconLoader::Desktop, 32));
+    iconLabel->setPixmap(Icon("network-wired").pixmap(32));
     iconLabel->setSizePolicy(SIZE_MINIMUM);
 
     aboutLabel = new QLabel(i18n("About to connect to..."), this);
@@ -80,15 +91,11 @@ newFTPGUI::newFTPGUI(QWidget* parent) : QDialog(parent)
     url->setMaxCount(50);
     url->setMinimumContentsLength(10);
 
-    QStringList protocols = KProtocolInfo::protocols();
-    if (protocols.contains("ftp"))
-        prefix->addItem(i18n("ftp://"));
-    if (protocols.contains("smb"))
-        prefix->addItem(i18n("smb://"));
-    if (protocols.contains("fish"))
-        prefix->addItem(i18n("fish://"));
-    if (protocols.contains("sftp"))
-        prefix->addItem(i18n("sftp://"));
+    const QStringList availableProtocols = KProtocolInfo::protocols();
+    for (const QString protocol : sProtocols) {
+        if (availableProtocols.contains(protocol))
+            prefix->addItem(protocol + QStringLiteral("://"));
+    }
 
     // load the history and completion list after creating the history combo
     KConfigGroup group(krConfig, "Private");
@@ -98,12 +105,11 @@ newFTPGUI::newFTPGUI(QWidget* parent) : QDialog(parent)
     url->setHistoryItems(list);
 
     // Select last used protocol
-    QString lastUsedProtocol = group.readEntry("newFTP Protocol", QString());
+    const QString lastUsedProtocol = group.readEntry("newFTP Protocol", QString());
     if(!lastUsedProtocol.isEmpty()) {
         prefix->setCurrentItem(lastUsedProtocol);
     }
 
-
     port = new QSpinBox(this);
     port->setMaximum(65535);
     port->setValue(21);
