@@ -2,20 +2,22 @@
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
  * Copyright (C) 2009 Fathi Boudra <fboudra@gmail.com>                       *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef NEWFTPGUI_H
@@ -30,10 +32,9 @@
 #include <KCompletion/KHistoryComboBox>
 #include <KCompletion/KLineEdit>
 
-class QEvent;
-class QString;
-class QWidget;
-
+/**
+ * The "New Network Connection" dialog
+ */
 class newFTPGUI : public QDialog
 {
     Q_OBJECT
@@ -42,6 +43,19 @@ public:
     explicit newFTPGUI(QWidget *parent = 0);
     ~newFTPGUI();
 
+    KComboBox* prefix;
+    KHistoryComboBox* url;
+    QSpinBox* port;
+    KLineEdit* username;
+    KLineEdit* password;
+
+protected:
+    bool event(QEvent *);
+
+private slots:
+    void slotTextChanged(const QString &);
+
+private:
     QLabel* iconLabel;
     QLabel* aboutLabel;
     QLabel* protocolLabel;
@@ -49,17 +63,6 @@ public:
     QLabel* hostLabel;
     QLabel* usernameLabel;
     QLabel* portLabel;
-    QSpinBox* port;
-    KComboBox* prefix;
-    KHistoryComboBox* url;
-    KLineEdit* username;
-    KLineEdit* password;
-
-public slots:
-    void slotTextChanged(const QString &);
-
-protected:
-    bool event(QEvent *);
 };
 
 #endif
