@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "popularurls.h"
@@ -35,10 +37,10 @@
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
 #include <KWidgetsAddons/KMessageBox>
-#include <KIconThemes/KIconLoader>
 #include <KItemViews/KTreeWidgetSearchLine>
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../krslots.h"
 #include "../GUI/krtreewidget.h"
 
@@ -359,7 +361,7 @@ void PopularUrlsDlg::run(QList<QUrl> list)
         QTreeWidgetItem *item = new QTreeWidgetItem(urls, lastItem);
         lastItem = item;
         item->setText(0, (*it).isLocalFile() ? (*it).path() : (*it).toDisplayString());
-        item->setIcon(0, (*it).isLocalFile() ? SmallIcon("folder") : SmallIcon("folder-html"));
+        item->setIcon(0, (*it).isLocalFile() ? Icon("folder") : Icon("folder-html"));
     }
 
     setMinimumSize(urls->sizeHint().width() + 45, 400);
