@@ -1,36 +1,27 @@
-/***************************************************************************
-                         diskusage.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 + by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "diskusage.h"
 
 // QtCore
+#include <QDebug>
 #include <QEvent>
 #include <QHash>
 #include <QMimeDatabase>
@@ -59,17 +50,18 @@
 #include <KIO/Job>
 #include <KIO/DeleteJob>
 
-#include "../FileSystem/krpermhandler.h"
-#include "../FileSystem/filesystemprovider.h"
-#include "../kicons.h"
-#include "../defaults.h"
-#include "../krglobal.h"
-#include "../Panel/krpanel.h"
-#include "../Panel/panelfunc.h"
-#include "filelightParts/Config.h"
+#include "dufilelight.h"
 #include "dulines.h"
 #include "dulistview.h"
-#include "dufilelight.h"
+#include "filelightParts/Config.h"
+#include "../FileSystem/fileitem.h"
+#include "../FileSystem/filesystemprovider.h"
+#include "../FileSystem/krpermhandler.h"
+#include "../Panel/krpanel.h"
+#include "../Panel/panelfunc.h"
+#include "../defaults.h"
+#include "../krglobal.h"
+#include "../filelisticon.h"
 
 // these are the values that will exist in the menu
 #define DELETE_ID            90
@@ -266,7 +258,7 @@ void DiskUsage::load(const QUrl &baseDir)
     }
     searchFileSystem = FileSystemProvider::instance().getFilesystem(baseDir);
     if (searchFileSystem == 0) {
-        krOut << "diskusage could not get filesystem for directory " << baseDir;
+        qWarning() << "could not get filesystem for directory=" << baseDir;
         loading = abortLoading = clearAfterAbort = false;
         emit loadFinished(false);
         return;
@@ -338,7 +330,7 @@ void DiskUsage::slotLoadDirectory()
 
                 loaderView->setCurrentURL(url);
 
-                if (!searchFileSystem->refresh(url))
+                if (!searchFileSystem->scanDir(url))
                     break;
                 fileItems = searchFileSystem->fileItems();
 
@@ -873,16 +865,19 @@ void DiskUsage::keyPressEvent(QKeyEvent *e)
                 executeAction(EXCLUDE_ID, getCurrentFile());
                 return;
             }
+            break;
         case Qt::Key_D:
             if (e->modifiers() == Qt::ControlModifier) {
                 executeAction(DETAILED_VIEW_ID);
                 return;
             }
+            break;
         case Qt::Key_F:
             if (e->modifiers() == Qt::ControlModifier) {
                 executeAction(FILELIGHT_VIEW_ID);
                 return;
             }
+            break;
         case Qt::Key_I:
             if (e->modifiers() == Qt::ControlModifier) {
                 executeAction(INCLUDE_ALL_ID);
@@ -894,6 +889,7 @@ void DiskUsage::keyPressEvent(QKeyEvent *e)
                 executeAction(LINES_VIEW_ID);
                 return;
             }
+            break;
         case Qt::Key_N:
             if (e->modifiers() == Qt::ControlModifier) {
                 executeAction(NEW_SEARCH_ID);
@@ -935,6 +931,7 @@ void DiskUsage::keyPressEvent(QKeyEvent *e)
                 executeAction(DELETE_ID, getCurrentFile());
                 return;
             }
+            break;
         case Qt::Key_Plus:
             if (activeView == VIEW_FILELIGHT) {
                 filelightView->zoomIn();
@@ -959,14 +956,14 @@ QPixmap DiskUsage::getIcon(QString mime)
     if (!QPixmapCache::find(mime, icon)) {
         // get the icon.
         if (mime == "Broken Link !") // FIXME: this doesn't work anymore - the reported mimetype for a broken link is now "unknown"
-            icon = FL_LOADICON("file-broken");
+            icon = FileListIcon("file-broken").pixmap();
         else {
             QMimeDatabase db;
             QMimeType mt = db.mimeTypeForName(mime);
             if (mt.isValid())
-                icon = FL_LOADICON(mt.iconName());
+                icon = FileListIcon(mt.iconName()).pixmap();
             else
-                icon = FL_LOADICON("file-broken");
+                icon = FileListIcon("file-broken").pixmap();
         }
 
         // insert it into the cache
