@@ -1,32 +1,22 @@
-/***************************************************************************
-                          diskusage.h  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef DISKUSAGE_H
 #define DISKUSAGE_H
@@ -49,7 +39,6 @@
 
 #include <KWidgetsAddons/KSqueezedTextLabel>
 
-#include "../FileSystem/filesystem.h"
 #include "filelightParts/fileTree.h"
 
 #define VIEW_LINES      0
@@ -64,6 +53,8 @@ class DULines;
 class DUFilelight;
 class QMenu;
 class LoaderWidget;
+class FileItem;
+class FileSystem;
 
 class DiskUsage : public QStackedWidget
 {
@@ -173,11 +164,11 @@ protected:
     QStack<QString> directoryStack;
     QStack<Directory *> parentStack;
 
-    FileSystem       * searchFileSystem;
-    FileItem     * currentFileItem;
+    FileSystem *searchFileSystem;
+    FileItem *currentFileItem;
     QList<FileItem *> fileItems;
-    Directory * currentParent;
-    QString     dirToCheck;
+    Directory *currentParent;
+    QString dirToCheck;
 
     int   fileNum;
     int   dirNum;
