@@ -1,32 +1,22 @@
-/***************************************************************************
-                       diskusagegui.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "diskusagegui.h"
 
@@ -42,21 +32,19 @@
 
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 
-#include "../kicons.h"
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../FileSystem/filesystem.h"
 #include "../Dialogs/krdialogs.h"
 
-DiskUsageGUI::DiskUsageGUI(QUrl openDir, QWidget* parent)
-        : QDialog(parent), exitAtFailure(true)
+DiskUsageGUI::DiskUsageGUI(const QUrl &openDir)
+        : QDialog(nullptr), exitAtFailure(true)
 {
     setWindowTitle(i18n("Krusader::Disk Usage"));
+    setAttribute(Qt::WA_DeleteOnClose);
 
     baseDirectory = openDir;
-    if (!newSearch())
-        return;
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
@@ -71,38 +59,38 @@ DiskUsageGUI::DiskUsageGUI(QUrl openDir, QWidget* parent)
     duTools->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
     btnNewSearch = new QToolButton(duTools);
-    btnNewSearch->setIcon(QIcon(krLoader->loadIcon("document-open", KIconLoader::Desktop)));
+    btnNewSearch->setIcon(Icon("document-open"));
     duHBox->addWidget(btnNewSearch);
     btnNewSearch->setToolTip(i18n("Start new disk usage search"));
 
     btnRefresh = new QToolButton(duTools);
-    btnRefresh->setIcon(QIcon(krLoader->loadIcon("view-refresh", KIconLoader::Desktop)));
+    btnRefresh->setIcon(Icon("view-refresh"));
     duHBox->addWidget(btnRefresh);
     btnRefresh->setToolTip(i18n("Refresh"));
 
     btnDirUp = new QToolButton(duTools);
-    btnDirUp->setIcon(QIcon(krLoader->loadIcon("go-up", KIconLoader::Desktop)));
+    btnDirUp->setIcon(Icon("go-up"));
     duHBox->addWidget(btnDirUp);
     btnDirUp->setToolTip(i18n("Parent folder"));
 
-    QWidget * separatorWidget = new QWidget(duTools);
+    QWidget *separatorWidget = new QWidget(duTools);
     separatorWidget->setMinimumWidth(10);
     duHBox->addWidget(separatorWidget);
 
     btnLines = new QToolButton(duTools);
-    btnLines->setIcon(QIcon(krLoader->loadIcon("view-list-details", KIconLoader::Desktop)));
+    btnLines->setIcon(Icon("view-list-details"));
     btnLines->setCheckable(true);
     duHBox->addWidget(btnLines);
     btnLines->setToolTip(i18n("Line view"));
 
     btnDetailed = new QToolButton(duTools);
-    btnDetailed->setIcon(QIcon(krLoader->loadIcon("view-list-tree", KIconLoader::Desktop)));
+    btnDetailed->setIcon(Icon("view-list-tree"));
     btnDetailed->setCheckable(true);
     duHBox->addWidget(btnDetailed);
     btnDetailed->setToolTip(i18n("Detailed view"));
 
     btnFilelight = new QToolButton(duTools);
-    btnFilelight->setIcon(QIcon(krLoader->loadIcon("kr_diskusage", KIconLoader::Desktop)));
+    btnFilelight->setIcon(Icon("kr_diskusage"));
     btnFilelight->setCheckable(true);
     duHBox->addWidget(btnFilelight);
     btnFilelight->setToolTip(i18n("Filelight view"));
@@ -126,47 +114,49 @@ DiskUsageGUI::DiskUsageGUI(QUrl openDir, QWidget* parent)
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
     mainLayout->addWidget(buttonBox);
 
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
-    connect(diskUsage, SIGNAL(status(QString)), this, SLOT(setStatus(QString)));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
+    connect(diskUsage, SIGNAL(status(QString)), this, SLOT(slotStatus(QString)));
     connect(diskUsage, SIGNAL(viewChanged(int)), this, SLOT(slotViewChanged(int)));
-    connect(diskUsage, SIGNAL(newSearch()), this,  SLOT(newSearch()));
+    connect(diskUsage, SIGNAL(newSearch()), this,  SLOT(askDir()));
     connect(diskUsage, SIGNAL(loadFinished(bool)), this,  SLOT(slotLoadFinished(bool)));
-    connect(btnNewSearch, SIGNAL(clicked()), this, SLOT(newSearch()));
-    connect(btnRefresh, SIGNAL(clicked()), this, SLOT(loadUsageInfo()));
+    connect(btnNewSearch, SIGNAL(clicked()), this, SLOT(askDir()));
+    connect(btnRefresh, SIGNAL(clicked()), this, SLOT(slotLoadUsageInfo()));
     connect(btnDirUp, SIGNAL(clicked()), diskUsage, SLOT(dirUp()));
-    connect(btnLines, SIGNAL(clicked()), this, SLOT(selectLinesView()));
-    connect(btnDetailed, SIGNAL(clicked()), this, SLOT(selectListView()));
-    connect(btnFilelight, SIGNAL(clicked()), this, SLOT(selectFilelightView()));
+    connect(btnLines, SIGNAL(clicked()), this, SLOT(slotSelectLinesView()));
+    connect(btnDetailed, SIGNAL(clicked()), this, SLOT(slotSelectListView()));
+    connect(btnFilelight, SIGNAL(clicked()), this, SLOT(slotSelectFilelightView()));
 
     KConfigGroup group(krConfig, "DiskUsage");
 
     int view = group.readEntry("View",  VIEW_LINES);
     if (view < VIEW_LINES || view > VIEW_FILELIGHT)
         view = VIEW_LINES;
+
     diskUsage->setView(view);
 
     sizeX = group.readEntry("Window Width",  QFontMetrics(font()).width("W") * 70);
     sizeY = group.readEntry("Window Height", QFontMetrics(font()).height() * 25);
     resize(sizeX, sizeY);
 
-    if (group.readEntry("Window Maximized",  false))
-        showMaximized();
-    else
-        show();
-
-    exec();
+    if (group.readEntry("Window Maximized",  false)) {
+        setWindowState(windowState() | Qt::WindowMaximized);
+    }
 }
 
-DiskUsageGUI::~DiskUsageGUI()
+void DiskUsageGUI::askDirAndShow()
 {
+    if (askDir()) {
+        show();
+    }
 }
 
 void DiskUsageGUI::slotLoadFinished(bool result)
 {
-    if (exitAtFailure && !result)
-        reject();
-    else
+    if (exitAtFailure && !result) {
+        close();
+    } else {
         exitAtFailure = false;
+    }
 }
 
 void DiskUsageGUI::enableButtons(bool isOn)
@@ -188,7 +178,7 @@ void DiskUsageGUI::resizeEvent(QResizeEvent *e)
     QDialog::resizeEvent(e);
 }
 
-void DiskUsageGUI::reject()
+void DiskUsageGUI::closeEvent(QCloseEvent *event)
 {
     KConfigGroup group(krConfig, "DiskUsage");
     group.writeEntry("Window Width", sizeX);
@@ -196,15 +186,15 @@ void DiskUsageGUI::reject()
     group.writeEntry("Window Maximized", isMaximized());
     group.writeEntry("View", diskUsage->getActiveView());
 
-    QDialog::reject();
+    event->accept();
 }
 
-void DiskUsageGUI::loadUsageInfo()
+void DiskUsageGUI::slotLoadUsageInfo()
 {
     diskUsage->load(baseDirectory);
 }
 
-void DiskUsageGUI::setStatus(QString stat)
+void DiskUsageGUI::slotStatus(QString stat)
 {
     status->setText(stat);
 }
@@ -236,15 +226,17 @@ void DiskUsageGUI::slotViewChanged(int view)
     }
 }
 
-bool DiskUsageGUI::newSearch()
+bool DiskUsageGUI::askDir()
 {
-    // ask the user for the copy dest
+    // ask the user for the copy destX
+    const QUrl newDir =
+        KChooseDir::getDir(i18n("Viewing the usage of folder:"), baseDirectory, baseDirectory);
 
-    QUrl tmp = KChooseDir::getDir(i18n("Viewing the usage of folder:"), baseDirectory, baseDirectory);
-    if (tmp.isEmpty()) return false;
-    baseDirectory = tmp;
+    if (newDir.isEmpty())
+        return false;
 
-    QTimer::singleShot(0, this, SLOT(loadUsageInfo()));
+    baseDirectory = newDir;
+
+    QTimer::singleShot(0, this, SLOT(slotLoadUsageInfo()));
     return true;
 }
-
