@@ -1,24 +1,27 @@
 /*****************************************************************************
  * Copyright (C) 2003-2004 Max Howell <max.howell@methylblue.com>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "fileTree.h"
 #include "radialMap.h"   //class Segment
 #include "widget.h"
+#include "../../icon.h"
 
 #include <cmath>
 
@@ -34,7 +37,6 @@
 #include <QMenu>
 
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KIconThemes/KIconEffect>
 #include <KIO/DeleteJob>
 #include <KIO/JobUiDelegate>
@@ -171,19 +173,19 @@ RadialMap::Widget::mousePressEvent(QMouseEvent *e)
             QAction * actKonq = 0, * actKonsole = 0, *actViewMag = 0, * actFileOpen = 0, * actEditDel = 0;
 
             if (isDir) {
-                actKonq = popup.addAction(QIcon::fromTheme("system-file-manager"), i18n("Open File Manager Here"));
+                actKonq = popup.addAction(Icon("system-file-manager"), i18n("Open File Manager Here"));
                 if (url.scheme() == "file")
-                    actKonsole = popup.addAction(QIcon::fromTheme("utilities-terminal"), i18n("Open Terminal Here"));
+                    actKonsole = popup.addAction(Icon("utilities-terminal"), i18n("Open Terminal Here"));
 
                 if (m_focus->file() != m_tree) {
                     popup.addSeparator();
-                    actViewMag = popup.addAction(QIcon::fromTheme("zoom-original"), i18n("&Center Map Here"));
+                    actViewMag = popup.addAction(Icon("zoom-original"), i18n("&Center Map Here"));
                 }
             } else
-                actFileOpen = popup.addAction(QIcon::fromTheme("document-open"), i18n("&Open"));
+                actFileOpen = popup.addAction(Icon("document-open"), i18n("&Open"));
 
             popup.addSeparator();
-            actEditDel = popup.addAction(QIcon::fromTheme("edit-delete"), i18n("&Delete"));
+            actEditDel = popup.addAction(Icon("edit-delete"), i18n("&Delete"));
 
             QAction * result = popup.exec(e->globalPos());
             if (result == 0)
