@@ -1,36 +1,29 @@
-/***************************************************************************
-                      advancedfilter.cpp  -  description
-                             -------------------
-    copyright            : (C) 2003 + by Shie Erlich & Rafi Yanai & Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2003 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "advancedfilter.h"
 
 // QtCore
+#include <QDebug>
 #include <QFile>
 #include <QTextStream>
 // QtGui
@@ -45,10 +38,10 @@
 #include <QLabel>
 
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../Dialogs/krdialogs.h"
 
 #define USERSFILE  QString("/etc/passwd")
@@ -120,7 +113,7 @@ AdvancedFilter::AdvancedFilter(FilterTabs *tabs, QWidget *parent) : QWidget(pare
 
     // Options for date
 
-    QPixmap iconDate = krLoader->loadIcon("view-calendar", KIconLoader::Toolbar, 16);
+    Icon iconDate("view-calendar");
 
     QGroupBox *dateGroup = new QGroupBox(this);
     QButtonGroup *btnGroup = new QButtonGroup(dateGroup);
@@ -147,7 +140,7 @@ AdvancedFilter::AdvancedFilter(FilterTabs *tabs, QWidget *parent) : QWidget(pare
     modifiedBetweenBtn1 = new QToolButton(dateGroup);
     modifiedBetweenBtn1->setEnabled(false);
     modifiedBetweenBtn1->setText("");
-    modifiedBetweenBtn1->setIcon(QIcon(iconDate));
+    modifiedBetweenBtn1->setIcon(iconDate);
 
     QLabel *andLabel = new QLabel(dateGroup);
     andLabel->setText(i18n("an&d"));
@@ -160,7 +153,7 @@ AdvancedFilter::AdvancedFilter(FilterTabs *tabs, QWidget *parent) : QWidget(pare
     modifiedBetweenBtn2 = new QToolButton(dateGroup);
     modifiedBetweenBtn2->setEnabled(false);
     modifiedBetweenBtn2->setText("");
-    modifiedBetweenBtn2->setIcon(QIcon(iconDate));
+    modifiedBetweenBtn2->setIcon(iconDate);
 
     notModifiedAfterEnabled = new QRadioButton(dateGroup);
     notModifiedAfterEnabled->setText(i18n("&Not modified after"));
@@ -173,7 +166,7 @@ AdvancedFilter::AdvancedFilter(FilterTabs *tabs, QWidget *parent) : QWidget(pare
     notModifiedAfterBtn = new QToolButton(dateGroup);
     notModifiedAfterBtn->setEnabled(false);
     notModifiedAfterBtn->setText("");
-    notModifiedAfterBtn->setIcon(QIcon(iconDate));
+    notModifiedAfterBtn->setIcon(iconDate);
 
     modifiedInTheLastEnabled = new QRadioButton(dateGroup);
     modifiedInTheLastEnabled->setText(i18n("Mod&ified in the last"));
@@ -464,7 +457,7 @@ void AdvancedFilter::fillList(KComboBox *list, QString filename)
 {
     QFile data(filename);
     if (!data.open(QIODevice::ReadOnly)) {
-        krOut << "Search: Unable to read " << filename << " !!!" << endl;
+        qWarning() << "Search: Unable to read " << filename << " !!!";
         return;
     }
     // and read it into the temporary array
