@@ -1,23 +1,26 @@
 /*****************************************************************************
  * Copyright (C) 2004 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2004 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "dirhistorybutton.h"
+#include "../icon.h"
 #include "../Panel/dirhistoryqueue.h"
 
 #include "../FileSystem/filesystem.h"
@@ -35,7 +38,7 @@
 DirHistoryButton::DirHistoryButton(DirHistoryQueue* hQ, QWidget *parent) : QToolButton(parent)
 {
     setAutoRaise(true);
-    setIcon(QIcon::fromTheme("chronometer"));
+    setIcon(Icon("chronometer"));
     setText(i18n("Open the folder history list"));
     setToolTip(i18n("Open the folder history list"));
     setPopupMode(QToolButton::InstantPopup);
@@ -64,13 +67,13 @@ void DirHistoryButton::showMenu()
 /** No descriptions */
 void DirHistoryButton::slotPopup()
 {
-//    qDebug() << "History slot" << endl;
+//    qDebug() << "History slot";
 }
 /** No descriptions */
 void DirHistoryButton::slotAboutToShow()
 {
     emit aboutToShow();
-//    qDebug() << "about to show" << endl;
+//    qDebug() << "about to show";
     popupMenu->clear();
 
     for (int i = 0; i < historyQueue->count(); i++) {
