@@ -1,20 +1,23 @@
 /*****************************************************************************
  * Copyright (C) 2005 Csaba Karai <cskarai@freemail.hu>                      *
- * based on KRemoteEncodingPlugin from Dawit Alemayehu <adawit@kde.org>      *
+ * Copyright (C) 2005-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * Based on KRemoteEncodingPlugin from Dawit Alemayehu <adawit@kde.org>      *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krremoteencodingmenu.h"
@@ -33,14 +36,14 @@
 #include <KIOCore/KProtocolManager>
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../Panel/krpanel.h"
 #include "../Panel/panelfunc.h"
-#include "../kicons.h"
 
 #define DATA_KEY    QString::fromLatin1("Charset")
 
-KrRemoteEncodingMenu::KrRemoteEncodingMenu(const QString &text, const QString &icon, KActionCollection *parent) :
-        KActionMenu(QIcon::fromTheme(icon), text, parent), settingsLoaded(false)
+KrRemoteEncodingMenu::KrRemoteEncodingMenu(const QString &text, const QString &iconName, KActionCollection *parent) :
+        KActionMenu(Icon(iconName), text, parent), settingsLoaded(false)
 {
     connect(menu(), SIGNAL(aboutToShow()), this, SLOT(slotAboutToShow()));
 
@@ -79,7 +82,7 @@ void KrRemoteEncodingMenu::slotAboutToShow()
         }
 
         if (!found)
-            qWarning() << Q_FUNC_INFO << "could not find entry for charset=" << charset << endl;
+            qWarning() << Q_FUNC_INFO << "could not find entry for charset=" << charset;
     } else {
         foreach(QAction *act, acts) {
             if (act->data().canConvert<int> ()) {
