@@ -1,28 +1,31 @@
 /*****************************************************************************
  * Copyright (C) 2008 Václav Juza <vaclavjuza@gmail.com>                     *
+ * Copyright (C) 2008-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "terminaldock.h"
 
 // QtCore
-#include <QEvent>
+#include <QDebug>
 #include <QDir>
-#include <QString>
+#include <QEvent>
 #include <QObject>
+#include <QString>
 #include <QUrl>
 // QtGui
 #include <QKeyEvent>
@@ -40,21 +43,23 @@
 #include <KWidgetsAddons/KToggleAction>
 #include <KWidgetsAddons/KMessageBox>
 
-#include "../kractions.h"
-#include "../krusaderview.h"
-#include "../krmainwindow.h"
 #include "kcmdline.h"
-#include "../FileSystem/filesystem.h"
-#include "../Panel/listpanel.h"
-#include "../Panel/panelfunc.h"
-#include "../Panel/listpanelactions.h"
+#include "../kractions.h"
+#include "../krmainwindow.h"
 #include "../krservices.h"
+#include "../krslots.h"
+#include "../krusaderview.h"
+#include "../FileSystem/filesystem.h"
+#include "../Panel/PanelView/krview.h"
+#include "../Panel/listpanel.h"
+#include "../Panel/listpanelactions.h"
+#include "../Panel/panelfunc.h"
 
 /**
  * A widget containing the konsolepart for the Embedded terminal emulator
  */
 TerminalDock::TerminalDock(QWidget* parent, KrMainWindow *mainWindow) : QWidget(parent),
-    _mainWindow(mainWindow), konsole_part(0), t(0), initialised(false)
+    _mainWindow(mainWindow), konsole_part(0), t(0), initialised(false), firstInput(true)
 {
     terminal_hbox = new QHBoxLayout(this);
 }
@@ -77,8 +82,8 @@ bool TerminalDock::initialise()
             if (konsole_part) { //loaded successfully
                 terminal_hbox->addWidget(konsole_part->widget());
                 setFocusProxy(konsole_part->widget());
-                connect(konsole_part, SIGNAL(destroyed()),
-                        this, SLOT(killTerminalEmulator()));
+                connect(konsole_part, &KParts::ReadOnlyPart::destroyed, this,
+                        &TerminalDock::killTerminalEmulator);
                 // must filter app events, because some of them are processed
                 // by child widgets of konsole_part->widget()
                 // and would not be received on konsole_part->widget()
@@ -89,6 +94,7 @@ bool TerminalDock::initialise()
                     t->showShellInDir(lastPath);
                 }
                 initialised = true;
+                firstInput = true;
             } else
                 KMessageBox::error(0, i18n("<b>Cannot create embedded terminal.</b><br/>"
                                            "The reported error was: %1", error));
@@ -112,6 +118,8 @@ bool TerminalDock::initialise()
 
 void TerminalDock::killTerminalEmulator()
 {
+    qDebug() << "killed";
+
     initialised = false;
     konsole_part = NULL;
     t = NULL;
@@ -129,10 +137,12 @@ void TerminalDock::sendInput(const QString& input, bool clearCommand)
         // and command is appended to current input (e.g. "rm -rf x " concatenated with 'cd /usr');
         // code "borrowed" from Dolphin, Copyright (C) 2007-2010 by Peter Penz <peter.penz19@gmail.com>
         const int processId = t->terminalProcessId();
-        if (processId > 0) {
+        // workaround (firstInput): kill is send to terminal if shell is not initialized yet
+        if (processId > 0 && !firstInput) {
             kill(processId, SIGINT);
         }
     }
+    firstInput = false;
 
     t->sendInput(input);
 }
@@ -179,21 +189,9 @@ bool TerminalDock::applyShortcuts(QKeyEvent * ke)
     }
 
     //insert current to the terminal
-    if ((ke->key() == Qt::Key_Enter || ke->key() == Qt::Key_Return)
-            && ((ke->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier)) {
-
-        QString filename = ACTIVE_PANEL->view->getCurrentItem();
-        if (filename.isEmpty()) {
-            return true;
-        }
-        if (ke->modifiers() & Qt::ShiftModifier) {
-            QString path = FileSystem::ensureTrailingSlash(ACTIVE_PANEL->virtualPath()).toDisplayString(QUrl::PreferLocalFile);
-            filename = path + filename;
-        }
-
-        filename = KrServices::quote(filename);
-
-        sendInput(QString(" ") + filename + QString(" "), false);
+    if ((ke->key() == Qt::Key_Enter || ke->key() == Qt::Key_Return) &&
+        (ke->modifiers() & Qt::ControlModifier)) {
+        SLOTS->insertFileName((ke->modifiers() & Qt::ShiftModifier) != 0);
         return true;
     }
 
