@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "panelviewer.h"
@@ -45,6 +47,8 @@ PanelViewerBase::PanelViewerBase(QWidget *parent, KrViewer::Mode mode) :
 
     mimes = new QHash<QString, QPointer<KParts::ReadOnlyPart> >();
     cpart = 0;
+    // NOTE: the fallback should be never visible. The viewer is not opened without a file and the
+    // tab is closed if a file cannot be opened.
     fallback = new QLabel(i18n("No file selected or selected file cannot be displayed."), this);
     fallback->setAlignment(Qt::Alignment(QFlag(Qt::AlignCenter | Qt::TextExpandTabs)));
     fallback->setWordWrap(true);
@@ -189,27 +193,25 @@ KParts::ReadOnlyPart* PanelViewer::getDefaultPart(KFileItem fi)
 
     switch(mode) {
     case KrViewer::Generic:
-        if((mimetype.startsWith(QLatin1String("text/")) ||
-            mimetype.startsWith(QLatin1String("all/"))) &&
-                fileSize > limit) {
+        if ((mimetype.startsWith(QLatin1String("text/")) ||
+             mimetype.startsWith(QLatin1String("all/"))) &&
+            fileSize > limit) {
             part = getListerPart(isBinary);
             break;
-        } else if((part = getPart(mimetype)))
+        } else if ((part = getPart(mimetype))) {
             break;
+        }
+#if __GNUC__ >= 7
+        [[gnu::fallthrough]];
+#endif
     case KrViewer::Text:
-        if (fileSize > limit)
-            part =  getListerPart(false);
-        else
-            part = getTextPart();
+        part = fileSize > limit ? getListerPart(false) : getTextPart();
         break;
     case KrViewer::Lister:
         part = getListerPart(isBinary);
         break;
     case KrViewer::Hex:
-        if (fileSize > limit)
-            part = getListerPart(true);
-        else
-            part = getHexPart();
+        part = fileSize > limit ? getListerPart(true) : getHexPart();
         break;
     default:
         abort();
