@@ -1,32 +1,22 @@
-/***************************************************************************
-                       kgdependencies.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kgdependencies.h"
 #include "../krservices.h"
@@ -130,32 +120,35 @@ KgDependencies::KgDependencies(bool first, QWidget* parent) :
     kgDependenciesLayout->addWidget(tabWidget, 0, 0);
 }
 
-void KgDependencies::addApplication(QString name, QGridLayout *grid, int row, QWidget *parent, int page, QString additionalList)
+void KgDependencies::addApplication(QString name, QGridLayout *grid, int row, QWidget *parent,
+                                    int page, QString additionalList)
 {
-    QString dflt = KrServices::fullPathName(name);   /* try to autodetect the full path name */
+    // try to autodetect the full path name
+    QString defaultValue = KrServices::fullPathName(name);
 
-    if (dflt.isEmpty()) {
+    if (defaultValue.isEmpty()) {
         QStringList list = additionalList.split(',', QString::SkipEmptyParts);
         for (int i = 0; i != list.count(); i++)
             if (!KrServices::fullPathName(list[ i ]).isEmpty()) {
-                dflt = KrServices::fullPathName(list[ i ]);
+                defaultValue = KrServices::fullPathName(list[ i ]);
                 break;
             }
     }
 
     addLabel(grid, row, 0, name, parent);
 
-    KonfiguratorURLRequester *fullPath = createURLRequester("Dependencies", name, dflt, parent, false, page);
+    KonfiguratorURLRequester *fullPath =
+        createURLRequester("Dependencies", name, defaultValue, parent, false, page);
     connect(fullPath->extension(), SIGNAL(applyManually(QObject*,QString,QString)),
             this, SLOT(slotApply(QObject*,QString,QString)));
     grid->addWidget(fullPath, row, 1);
 }
 
-void KgDependencies::slotApply(QObject *obj, QString cls, QString name)
+void KgDependencies::slotApply(QObject *obj, QString configGroup, QString name)
 {
     KonfiguratorURLRequester *urlRequester = (KonfiguratorURLRequester *) obj;
 
-    KConfigGroup group(krConfig, cls);
+    KConfigGroup group(krConfig, configGroup);
     group.writeEntry(name, urlRequester->url().toDisplayString(QUrl::PreferLocalFile));
 
     QString usedPath = KrServices::fullPathName(name);
@@ -163,11 +156,13 @@ void KgDependencies::slotApply(QObject *obj, QString cls, QString name)
     if (urlRequester->url().toDisplayString(QUrl::PreferLocalFile) != usedPath) {
         group.writeEntry(name, usedPath);
         if (usedPath.isEmpty())
-            KMessageBox::error(this, i18n("The %1 path is incorrect, no valid path found.",
-                                          urlRequester->url().toDisplayString(QUrl::PreferLocalFile)));
+            KMessageBox::error(this,
+                               i18n("The %1 path is incorrect, no valid path found.",
+                                    urlRequester->url().toDisplayString(QUrl::PreferLocalFile)));
         else
-            KMessageBox::error(this, i18n("The %1 path is incorrect, %2 used instead.",
-                                          urlRequester->url().toDisplayString(QUrl::PreferLocalFile), usedPath));
+            KMessageBox::error(
+                this, i18n("The %1 path is incorrect, %2 used instead.",
+                           urlRequester->url().toDisplayString(QUrl::PreferLocalFile), usedPath));
         urlRequester->setUrl(QUrl::fromLocalFile(usedPath));
     }
 }
