@@ -1,32 +1,22 @@
-/***************************************************************************
-                         kggeneral.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kggeneral.h"
 
@@ -43,12 +33,11 @@
 
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 
 #include "krresulttabledialog.h"
 #include "../defaults.h"
-#include "../kicons.h"
+#include "../icon.h"
 #include "../krglobal.h"
 
 #define PAGE_GENERAL        0
@@ -187,17 +176,17 @@ void KgGeneral::createExtensionsTab()
     QToolButton *addButton = new QToolButton(hboxWidget3);
     hbox3->addWidget(addButton);
 
-    QPixmap icon = krLoader->loadIcon("list-add", KIconLoader::Desktop, size);
-    addButton->setFixedSize(icon.width() + 4, icon.height() + 4);
-    addButton->setIcon(QIcon(icon));
+    QPixmap iconPixmap = Icon("list-add").pixmap(size);
+    addButton->setFixedSize(iconPixmap.width() + 4, iconPixmap.height() + 4);
+    addButton->setIcon(QIcon(iconPixmap));
     connect(addButton, SIGNAL(clicked()), this, SLOT(slotAddExtension()));
 
     QToolButton *removeButton = new QToolButton(hboxWidget3);
     hbox3->addWidget(removeButton);
 
-    icon = krLoader->loadIcon("list-remove", KIconLoader::Desktop, size);
-    removeButton->setFixedSize(icon.width() + 4, icon.height() + 4);
-    removeButton->setIcon(QIcon(icon));
+    iconPixmap = Icon("list-remove").pixmap(size);
+    removeButton->setFixedSize(iconPixmap.width() + 4, iconPixmap.height() + 4);
+    removeButton->setIcon(QIcon(iconPixmap));
     connect(removeButton, SIGNAL(clicked()), this, SLOT(slotRemoveExtension()));
 
     QStringList defaultAtomicExtensions;
@@ -230,7 +219,7 @@ void KgGeneral::createGeneralTab()
 
     KONFIGURATOR_CHECKBOX_PARAM settings[] = { //   cfg_class  cfg_name                default             text                              restart tooltip
         {"Look&Feel", "Warn On Exit",         _WarnOnExit,        i18n("Warn on exit"),           false,  i18n("Display a warning when trying to close the main window.") },    // KDE4: move warn on exit to the other confirmations
-        {"Look&Feel", "Minimize To Tray",     _MinimizeToTray,    i18n("Minimize to tray"),       false,  i18n("The icon will appear in the system tray instead of the taskbar, when Krusader is minimized.") },
+        {"Look&Feel", "Minimize To Tray",     _ShowTrayIcon,      i18n("Show and close to tray"), false,  i18n("Show an icon in the system tray and keep running in the background when the window is closed.") },
     };
     KonfiguratorCheckBoxGroup *cbs = createCheckBoxGroup(2, 0, settings, 2 /*count*/, generalGrp, PAGE_GENERAL);
     generalGrid->addWidget(cbs, 0, 0);
@@ -297,12 +286,12 @@ void KgGeneral::createGeneralTab()
     kgGeneralLayout->addWidget(terminalGrp, 2 , 0);
 }
 
-void KgGeneral::applyTempDir(QObject *obj, QString cls, QString name)
+void KgGeneral::applyTempDir(QObject *obj, QString configGroup, QString name)
 {
     KonfiguratorURLRequester *urlReq = (KonfiguratorURLRequester *)obj;
     QString value = urlReq->url().toDisplayString(QUrl::PreferLocalFile);
 
-    KConfigGroup(krConfig, cls).writeEntry(name, value);
+    KConfigGroup(krConfig, configGroup).writeEntry(name, value);
 }
 
 void KgGeneral::slotFindTools()
