@@ -1,35 +1,26 @@
-/***************************************************************************
-                         KgProtocols.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kgprotocols.h"
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../krservices.h"
 
 // QtCore
@@ -43,7 +34,7 @@
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
 #include <KIOCore/KProtocolManager>
-#include <KIconThemes/KIconLoader>
+
 
 KgProtocols::KgProtocols(bool first, QWidget* parent) :
         KonfiguratorPage(first, parent)
@@ -73,12 +64,12 @@ KgProtocols::KgProtocols(bool first, QWidget* parent) :
 
     addSpacer(vbox1);
     btnAddProtocol = new QPushButton(vbox1Widget);
-    btnAddProtocol->setIcon(krLoader->loadIcon("arrow-left", KIconLoader::Small));
+    btnAddProtocol->setIcon(Icon("arrow-left"));
     btnAddProtocol->setWhatsThis(i18n("Add protocol to the link list."));
     vbox1->addWidget(btnAddProtocol);
 
     btnRemoveProtocol = new QPushButton(vbox1Widget);
-    btnRemoveProtocol->setIcon(krLoader->loadIcon("arrow-right", KIconLoader::Small));
+    btnRemoveProtocol->setIcon(Icon("arrow-right"));
     btnRemoveProtocol->setWhatsThis(i18n("Remove protocol from the link list."));
     vbox1->addWidget(btnRemoveProtocol);
     addSpacer(vbox1);
@@ -90,12 +81,12 @@ KgProtocols::KgProtocols(bool first, QWidget* parent) :
 
     addSpacer(vbox2);
     btnAddMime = new QPushButton(vbox2Widget);
-    btnAddMime->setIcon(krLoader->loadIcon("arrow-left", KIconLoader::Small));
+    btnAddMime->setIcon(Icon("arrow-left"));
     btnAddMime->setWhatsThis(i18n("Add MIME to the selected protocol on the link list."));
     vbox2->addWidget(btnAddMime);
 
     btnRemoveMime = new QPushButton(vbox2Widget);
-    btnRemoveMime->setIcon(krLoader->loadIcon("arrow-right", KIconLoader::Small));
+    btnRemoveMime->setIcon(Icon("arrow-right"));
     btnRemoveMime->setWhatsThis(i18n("Remove MIME from the link list."));
     vbox2->addWidget(btnRemoveMime);
     addSpacer(vbox2);
@@ -204,10 +195,10 @@ void KgProtocols::addProtocol(QString name, bool changeCurrent)
         delete list[ 0 ];
         QTreeWidgetItem *listViewItem = new QTreeWidgetItem(linkList);
         listViewItem->setText(0, name);
-        QString icon = KProtocolInfo::icon(name);
-        if (icon.isEmpty())
-            icon = "go-next-view";
-        listViewItem->setIcon(0, krLoader->loadIcon(icon, KIconLoader::Small));
+        QString iconName = KProtocolInfo::icon(name);
+        if (iconName.isEmpty())
+            iconName = "go-next-view";
+        listViewItem->setIcon(0, Icon(iconName));
 
         if (changeCurrent)
             linkList->setCurrentItem(listViewItem);
@@ -268,7 +259,7 @@ void KgProtocols::addMime(QString name, QString protocol)
         delete list[ 0 ];
         QTreeWidgetItem *listViewItem = new QTreeWidgetItem(currentListItem);
         listViewItem->setText(0, name);
-        listViewItem->setIcon(0, krLoader->loadMimeTypeIcon(name, KIconLoader::Small));
+        listViewItem->setIcon(0, Icon(name.replace(QLatin1Char('/'), QLatin1Char('-')), Icon("unknown")));
         linkList->expandItem( currentListItem );
     }
 }
