@@ -1,32 +1,22 @@
-/***************************************************************************
-                        kgstartup.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kgstartup.h"
 #include "../defaults.h"
@@ -84,6 +74,19 @@ KgStartup::KgStartup(bool first, QWidget* parent) :
     KonfiguratorCheckBoxGroup* cbs = createCheckBoxGroup(2, 0, settings, 2 /* settings count */, panelsGrp);
     panelsGrid->addWidget(cbs, 2, 0, 1, 2);
 
+    QHBoxLayout *iconThemeLayout = new QHBoxLayout();
+    QLabel *iconThemeLabel = new QLabel(i18n("Fallback Icon Theme:"));
+    iconThemeLabel->setWhatsThis(i18n("Whenever icon is not found in system icon theme, "
+                                      "this theme will be used as a fallback. "
+                                      "If fallback theme doesn't contain the icon, "
+                                      "Breeze or Oxygen will be used if any of these are present."));
+    iconThemeLayout->addWidget(iconThemeLabel);
+    KonfiguratorEditBox *iconThemeEditBox = createEditBox("Startup", "Fallback Icon Theme", "",
+                                                          panelsGrp, true);
+    iconThemeLayout->addWidget(iconThemeEditBox);
+    iconThemeLayout->addStretch(1);
+    panelsGrid->addLayout(iconThemeLayout, 3, 0, 1, 2);
+
     kgStartupLayout->addWidget(panelsGrp, 0, 0);
 
     //  ------------------------ USERINTERFACE GROUPBOX ------------------------------
@@ -101,7 +104,7 @@ KgStartup::KgStartup(bool first, QWidget* parent) :
         {"Startup", "Update Default Panel Settings", _RememberPos, i18n("Update default panel settings"), true,
             i18n("When settings of a panel are changed, save them as the default for new panels of the same type.") },
         {"Startup", "Start To Tray", _StartToTray, i18n("Start to tray"), false,
-            i18n("Krusader starts to tray (if minimize to tray is set), without showing the main window") },
+            i18n("Krusader starts to tray, without showing the main window") },
     };
 
     KonfiguratorCheckBoxGroup *uiSettingsGroup = createCheckBoxGroup(1, 0, uiSettings, 3, uiGrp);
