@@ -1,35 +1,27 @@
-/***************************************************************************
-                     konfiguratoritems.cpp  -  description
-                             -------------------
-    copyright            : (C) 2003 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "konfiguratoritems.h"
+
 #include "../krglobal.h"
+#include "../icon.h"
 
 // QtCore
 #include <QMetaMethod>
@@ -45,11 +37,12 @@
 #include <KCompletion/KLineEdit>
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 
-KonfiguratorExtension::KonfiguratorExtension(QObject *obj, QString cfgClass, QString cfgName, bool rst, int pg) :
-        QObject(), objectPtr(obj), applyConnected(false), setDefaultsConnected(false),
-        changed(false), restartNeeded(rst), subpage(pg), configClass(cfgClass), configName(cfgName)
+
+KonfiguratorExtension::KonfiguratorExtension(QObject *obj, QString cfgGroup, QString cfgName,
+                                             bool restartNeeded, int page)
+    : QObject(), objectPtr(obj), applyConnected(false), setDefaultsConnected(false), changed(false),
+      restartNeeded(restartNeeded), subpage(page), configGroup(cfgGroup), configName(cfgName)
 {
 }
 
@@ -69,9 +62,9 @@ bool KonfiguratorExtension::apply()
         return false;
 
     if (applyConnected)
-        emit applyManually(objectPtr, configClass, configName);
+        emit applyManually(objectPtr, configGroup, configName);
     else
-        emit applyAuto(objectPtr, configClass, configName);
+        emit applyAuto(objectPtr, configGroup, configName);
 
     setChanged(false);
     return restartNeeded;
@@ -98,11 +91,11 @@ bool KonfiguratorExtension::isChanged()
 // KonfiguratorCheckBox class
 ///////////////////////////////
 
-KonfiguratorCheckBox::KonfiguratorCheckBox(QString cls, QString name, bool dflt, QString text,
-        QWidget *parent, bool rst, int pg) : QCheckBox(text, parent),
-        defaultValue(dflt)
+KonfiguratorCheckBox::KonfiguratorCheckBox(QString configGroup, QString name, bool defaultValue, QString text,
+        QWidget *parent, bool restart, int page) : QCheckBox(text, parent),
+        defaultValue(defaultValue)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -118,8 +111,8 @@ KonfiguratorCheckBox::~KonfiguratorCheckBox()
 
 void KonfiguratorCheckBox::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    setChecked(group.readEntry(ext->getCfgName(), defaultValue));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    setChecked(group.readEntry(ext->getConfigName(), defaultValue));
     ext->setChanged(false);
 }
 
@@ -147,9 +140,9 @@ void KonfiguratorCheckBox::updateDeps()
         dep->setEnabled(isChecked());
 }
 
-void KonfiguratorCheckBox::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorCheckBox::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, isChecked());
+    KConfigGroup(krConfig, configGroup).writeEntry(name, isChecked());
 }
 
 void KonfiguratorCheckBox::slotSetDefaults(QObject *)
@@ -162,11 +155,12 @@ void KonfiguratorCheckBox::slotSetDefaults(QObject *)
 // KonfiguratorSpinBox class
 ///////////////////////////////
 
-KonfiguratorSpinBox::KonfiguratorSpinBox(QString cls, QString name, int dflt, int min, int max,
-        QWidget *parent, bool rst, int pg) : QSpinBox(parent),
-        defaultValue(dflt)
+KonfiguratorSpinBox::KonfiguratorSpinBox(QString configGroup, QString configName, int defaultValue,
+                                         int min, int max, QWidget *parent, bool restartNeeded,
+                                         int page)
+    : QSpinBox(parent), defaultValue(defaultValue)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, configName, restartNeeded, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -186,14 +180,14 @@ KonfiguratorSpinBox::~KonfiguratorSpinBox()
 
 void KonfiguratorSpinBox::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    setValue(group.readEntry(ext->getCfgName(), defaultValue));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    setValue(group.readEntry(ext->getConfigName(), defaultValue));
     ext->setChanged(false);
 }
 
-void KonfiguratorSpinBox::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorSpinBox::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, value());
+    KConfigGroup(krConfig, configGroup).writeEntry(name, value());
 }
 
 void KonfiguratorSpinBox::slotSetDefaults(QObject *)
@@ -223,7 +217,7 @@ KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find(QString name)
     while (it.hasNext()) {
         KonfiguratorCheckBox * checkBox = it.next();
 
-        if (checkBox->extension()->getCfgName() == name)
+        if (checkBox->extension()->getConfigName() == name)
             return checkBox;
     }
 
@@ -234,11 +228,11 @@ KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find(QString name)
 // KonfiguratorRadioButtons class
 ///////////////////////////////
 
-KonfiguratorRadioButtons::KonfiguratorRadioButtons(QString cls, QString name,
-        QString dflt, QWidget *parent, bool rst, int pg) :
-        QWidget(parent), defaultValue(dflt)
+KonfiguratorRadioButtons::KonfiguratorRadioButtons(QString configGroup, QString name,
+        QString defaultValue, QWidget *parent, bool restart, int page) :
+        QWidget(parent), defaultValue(defaultValue)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -297,8 +291,8 @@ void KonfiguratorRadioButtons::selectButton(QString value)
 
 void KonfiguratorRadioButtons::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    QString initValue = group.readEntry(ext->getCfgName(), defaultValue);
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    QString initValue = group.readEntry(ext->getConfigName(), defaultValue);
 
     selectButton(initValue);
     ext->setChanged(false);
@@ -321,12 +315,12 @@ QString KonfiguratorRadioButtons::selectedValue()
     return QString();
 }
 
-void KonfiguratorRadioButtons::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorRadioButtons::slotApply(QObject *, QString configGroup, QString name)
 {
     QString value = selectedValue();
 
     if (!value.isEmpty())
-        KConfigGroup(krConfig, cls).writeEntry(name, value);
+        KConfigGroup(krConfig, configGroup).writeEntry(name, value);
 }
 
 void KonfiguratorRadioButtons::slotSetDefaults(QObject *)
@@ -337,12 +331,13 @@ void KonfiguratorRadioButtons::slotSetDefaults(QObject *)
 // KonfiguratorEditBox class
 ///////////////////////////////
 
-KonfiguratorEditBox::KonfiguratorEditBox(QString cls, QString name, QString dflt,
-        QWidget *parent, bool rst, int pg) : QLineEdit(parent),
-        defaultValue(dflt)
+KonfiguratorEditBox::KonfiguratorEditBox(QString configGroup, QString name, QString defaultValue,
+        QWidget *parent, bool restart, int page) : QLineEdit(parent),
+        defaultValue(defaultValue)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
-    connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
+    connect(ext, SIGNAL(applyAuto(QObject *, QString, QString)), this,
+            SLOT(slotApply(QObject *, QString, QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
 
@@ -358,14 +353,14 @@ KonfiguratorEditBox::~KonfiguratorEditBox()
 
 void KonfiguratorEditBox::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    setText(group.readEntry(ext->getCfgName(), defaultValue));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    setText(group.readEntry(ext->getConfigName(), defaultValue));
     ext->setChanged(false);
 }
 
-void KonfiguratorEditBox::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorEditBox::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, text());
+    KConfigGroup(krConfig, configGroup).writeEntry(name, text());
 }
 
 void KonfiguratorEditBox::slotSetDefaults(QObject *)
@@ -378,13 +373,14 @@ void KonfiguratorEditBox::slotSetDefaults(QObject *)
 // KonfiguratorURLRequester class
 ///////////////////////////////
 
-KonfiguratorURLRequester::KonfiguratorURLRequester(QString cls, QString name, QString dflt,
-        QWidget *parent, bool rst, int pg, bool expansion) : KUrlRequester(parent),
-        defaultValue(dflt),
-        expansion(expansion)
+KonfiguratorURLRequester::KonfiguratorURLRequester(QString configGroup, QString name,
+                                                   QString defaultValue, QWidget *parent,
+                                                   bool restart, int page, bool expansion)
+    : KUrlRequester(parent), defaultValue(defaultValue), expansion(expansion)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
-    connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
+    connect(ext, SIGNAL(applyAuto(QObject *, QString, QString)), this,
+            SLOT(slotApply(QObject *, QString, QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
 
@@ -400,14 +396,15 @@ KonfiguratorURLRequester::~KonfiguratorURLRequester()
 
 void KonfiguratorURLRequester::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    lineEdit()->setText(group.readEntry(ext->getCfgName(), defaultValue));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    lineEdit()->setText(group.readEntry(ext->getConfigName(), defaultValue));
     ext->setChanged(false);
 }
 
-void KonfiguratorURLRequester::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorURLRequester::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, expansion ? url().toDisplayString(QUrl::PreferLocalFile) : text());
+    KConfigGroup(krConfig, configGroup)
+        .writeEntry(name, expansion ? url().toDisplayString(QUrl::PreferLocalFile) : text());
 }
 
 void KonfiguratorURLRequester::slotSetDefaults(QObject *)
@@ -419,13 +416,13 @@ void KonfiguratorURLRequester::slotSetDefaults(QObject *)
 // KonfiguratorFontChooser class
 ///////////////////////////////
 
-KonfiguratorFontChooser::KonfiguratorFontChooser(QString cls, QString name, QFont dflt,
-        QWidget *parent, bool rst, int pg) : QWidget(parent),
-        defaultValue(dflt)
+KonfiguratorFontChooser::KonfiguratorFontChooser(QString configGroup, QString name, QFont defaultValue,
+        QWidget *parent, bool restart, int page) : QWidget(parent),
+        defaultValue(defaultValue)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
 
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -438,7 +435,7 @@ KonfiguratorFontChooser::KonfiguratorFontChooser(QString cls, QString name, QFon
 
     connect(pToolButton, SIGNAL(clicked()), this, SLOT(slotBrowseFont()));
 
-    pToolButton->setIcon(SmallIcon("document-open"));
+    pToolButton->setIcon(Icon("document-open"));
     layout->addWidget(pToolButton);
 
     loadInitialValue();
@@ -451,8 +448,8 @@ KonfiguratorFontChooser::~KonfiguratorFontChooser()
 
 void KonfiguratorFontChooser::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    font = group.readEntry(ext->getCfgName(), defaultValue);
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    font = group.readEntry(ext->getConfigName(), defaultValue);
     ext->setChanged(false);
     setFont();
 }
@@ -463,9 +460,9 @@ void KonfiguratorFontChooser::setFont()
     pLabel->setText(font.family() + QString(", %1").arg(font.pointSize()));
 }
 
-void KonfiguratorFontChooser::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorFontChooser::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, font);
+    KConfigGroup(krConfig, configGroup).writeEntry(name, font);
 }
 
 void KonfiguratorFontChooser::slotSetDefaults(QObject *)
@@ -487,10 +484,10 @@ void KonfiguratorFontChooser::slotBrowseFont()
 // KonfiguratorComboBox class
 ///////////////////////////////
 
-KonfiguratorComboBox::KonfiguratorComboBox(QString cls, QString name, QString dflt,
+KonfiguratorComboBox::KonfiguratorComboBox(QString configGroup, QString name, QString defaultValue,
         KONFIGURATOR_NAME_VALUE_PAIR *listIn, int listInLen, QWidget *parent,
-        bool rst, bool editable, int pg) : QComboBox(parent),
-        defaultValue(dflt), listLen(listInLen)
+        bool restart, bool editable, int page) : QComboBox(parent),
+        defaultValue(defaultValue), listLen(listInLen)
 {
     list = new KONFIGURATOR_NAME_VALUE_PAIR[ listInLen ];
 
@@ -499,7 +496,7 @@ KonfiguratorComboBox::KonfiguratorComboBox(QString cls, QString name, QString df
         addItem(list[i].text);
     }
 
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -520,13 +517,13 @@ KonfiguratorComboBox::~KonfiguratorComboBox()
 
 void KonfiguratorComboBox::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    QString select = group.readEntry(ext->getCfgName(), defaultValue);
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    QString select = group.readEntry(ext->getConfigName(), defaultValue);
     selectEntry(select);
     ext->setChanged(false);
 }
 
-void KonfiguratorComboBox::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorComboBox::slotApply(QObject *, QString configGroup, QString name)
 {
     QString text = isEditable() ? lineEdit()->text() : currentText();
     QString value = text;
@@ -537,7 +534,7 @@ void KonfiguratorComboBox::slotApply(QObject *, QString cls, QString name)
             break;
         }
 
-    KConfigGroup(krConfig, cls).writeEntry(name, value);
+    KConfigGroup(krConfig, configGroup).writeEntry(name, value);
 }
 
 void KonfiguratorComboBox::selectEntry(QString entry)
@@ -563,12 +560,13 @@ void KonfiguratorComboBox::slotSetDefaults(QObject *)
 // KonfiguratorColorChooser class
 ///////////////////////////////
 
-KonfiguratorColorChooser::KonfiguratorColorChooser(QString cls, QString name, QColor dflt,
-        QWidget *parent, bool rst, ADDITIONAL_COLOR *addColPtr,
-        int addColNum, int pg) : QComboBox(parent),
-        defaultValue(dflt), disableColorChooser(true)
+KonfiguratorColorChooser::KonfiguratorColorChooser(QString configGroup, QString name,
+                                                   QColor defaultValue, QWidget *parent,
+                                                   bool restart, ADDITIONAL_COLOR *addColPtr,
+                                                   int addColNum, int page)
+    : QComboBox(parent), defaultValue(defaultValue), disableColorChooser(true)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
 
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
@@ -639,8 +637,8 @@ void KonfiguratorColorChooser::addColor(QString text, QColor color)
 
 void KonfiguratorColorChooser::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    QString selected = group.readEntry(ext->getCfgName(), QString(""));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    QString selected = group.readEntry(ext->getConfigName(), QString(""));
     setValue(selected);
     ext->setChanged(false);
 }
@@ -673,9 +671,9 @@ void KonfiguratorColorChooser::setDefaultText(QString text)
     setItemText(1, text);
 }
 
-void KonfiguratorColorChooser::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorColorChooser::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, getValue());
+    KConfigGroup(krConfig, configGroup).writeEntry(name, getValue());
 }
 
 void KonfiguratorColorChooser::setValue(QString value)
@@ -696,7 +694,7 @@ void KonfiguratorColorChooser::setValue(QString value)
             }
 
         if (! found) {
-            KConfigGroup colGroup(krConfig, ext->getCfgClass());
+            KConfigGroup colGroup(krConfig, ext->getConfigGroup());
             colGroup.writeEntry("TmpColor", value);
             QColor color = colGroup.readEntry("TmpColor", defaultValue);
             customValue = color;
@@ -767,11 +765,11 @@ QColor KonfiguratorColorChooser::getColor()
 // KonfiguratorListBox class
 ///////////////////////////////
 
-KonfiguratorListBox::KonfiguratorListBox(QString cls, QString name, QStringList dflt,
-        QWidget *parent, bool rst, int pg) : KrListWidget(parent),
-        defaultValue(dflt)
+KonfiguratorListBox::KonfiguratorListBox(QString configGroup, QString name, QStringList defaultValue,
+        QWidget *parent, bool restart, int page) : KrListWidget(parent),
+        defaultValue(defaultValue)
 {
-    ext = new KonfiguratorExtension(this, cls, name, rst, pg);
+    ext = new KonfiguratorExtension(this, configGroup, name, restart, page);
     connect(ext, SIGNAL(applyAuto(QObject*,QString,QString)), this, SLOT(slotApply(QObject*,QString,QString)));
     connect(ext, SIGNAL(setDefaultsAuto(QObject*)), this, SLOT(slotSetDefaults(QObject*)));
     connect(ext, SIGNAL(setInitialValue(QObject*)), this, SLOT(loadInitialValue()));
@@ -786,14 +784,14 @@ KonfiguratorListBox::~KonfiguratorListBox()
 
 void KonfiguratorListBox::loadInitialValue()
 {
-    KConfigGroup group(krConfig, ext->getCfgClass());
-    setList(group.readEntry(ext->getCfgName(), defaultValue));
+    KConfigGroup group(krConfig, ext->getConfigGroup());
+    setList(group.readEntry(ext->getConfigName(), defaultValue));
     ext->setChanged(false);
 }
 
-void KonfiguratorListBox::slotApply(QObject *, QString cls, QString name)
+void KonfiguratorListBox::slotApply(QObject *, QString configGroup, QString name)
 {
-    KConfigGroup(krConfig, cls).writeEntry(name, list());
+    KConfigGroup(krConfig, configGroup).writeEntry(name, list());
 }
 
 void KonfiguratorListBox::slotSetDefaults(QObject *)
