@@ -1,32 +1,22 @@
-/***************************************************************************
-                      konfiguratoritems.h  -  description
-                             -------------------
-    copyright            : (C) 2003 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef KONFIGURATORITEMS_H
 #define KONFIGURATORITEMS_H
@@ -60,29 +50,20 @@ class KonfiguratorExtension : public QObject
     Q_OBJECT
 
 public:
-    KonfiguratorExtension(QObject *obj, QString cfgClass, QString cfgName, bool rst = false, int pg = FIRST_PAGE);
+  KonfiguratorExtension(QObject *obj, QString cfgGroup, QString cfgName, bool restartNeeded = false,
+                        int page = FIRST_PAGE);
 
-    virtual void    loadInitialValue();
-    virtual bool    apply();
-    virtual void    setDefaults();
-    virtual bool    isChanged();
-    virtual void    setSubPage(int pg) {
-        subpage = pg;
-    }
-    virtual int     subPage()          {
-        return subpage;
-    }
+  virtual void loadInitialValue();
+  virtual bool apply();
+  virtual void setDefaults();
+  virtual bool isChanged();
+  virtual void setSubPage(int page) { subpage = page; }
+  virtual int subPage() { return subpage; }
 
-    inline QObject *object()           {
-        return objectPtr;
-    }
+  inline QObject *object() { return objectPtr; }
 
-    inline QString  getCfgClass()      {
-        return configClass;
-    }
-    inline QString  getCfgName()       {
-        return configName;
-    }
+  inline QString getConfigGroup() { return configGroup; }
+  inline QString getConfigName() { return configName; }
 
 public slots:
     void    setChanged()               {
@@ -109,7 +90,7 @@ protected:
     bool    restartNeeded;
     int     subpage;
 
-    QString configClass;
+    QString configGroup;
     QString configName;
 
     virtual void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
@@ -124,13 +105,11 @@ class KonfiguratorCheckBox : public QCheckBox
     Q_OBJECT
 
 public:
-    KonfiguratorCheckBox(QString cls, QString name, bool dflt, QString text,
-                         QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorCheckBox(QString configGroup, QString name, bool defaultValue, QString text,
+                         QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE);
     ~KonfiguratorCheckBox();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
     // indicate that a checkobox is dependent of this,
     // meaning that dep is only available if this box is checked
@@ -159,13 +138,11 @@ class KonfiguratorSpinBox : public QSpinBox
     Q_OBJECT
 
 public:
-    KonfiguratorSpinBox(QString cls, QString name, int dflt, int min, int max,
-                        QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorSpinBox(QString configGroup, QString configName, int defaultValue, int min, int max,
+                        QWidget *parent = 0, bool restartNeeded = false, int page = FIRST_PAGE);
     ~KonfiguratorSpinBox();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
 public slots:
     virtual void loadInitialValue();
@@ -183,8 +160,7 @@ protected:
 class KonfiguratorCheckBoxGroup : public QWidget
 {
 public:
-    explicit KonfiguratorCheckBoxGroup(QWidget * parent = 0) :
-            QWidget(parent) {};
+    explicit KonfiguratorCheckBoxGroup(QWidget *parent = 0) : QWidget(parent){}
 
     void                    add(KonfiguratorCheckBox *);
     int                     count() {
@@ -205,24 +181,20 @@ class KonfiguratorRadioButtons : public QWidget
     Q_OBJECT
 
 public:
-    KonfiguratorRadioButtons(QString cls, QString name, QString dflt, QWidget *parent = 0,
-                             bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorRadioButtons(QString configGroup, QString name, QString defaultValue,
+                             QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE);
     ~KonfiguratorRadioButtons();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
-    void  addRadioButton(QRadioButton *radioWidget, QString name, QString value);
+    void addRadioButton(QRadioButton *radioWidget, QString name, QString value);
 
-    void            selectButton(QString value);
+    void selectButton(QString value);
 
-    int             count() {
-        return radioButtons.count();
-    }
-    QString         selectedValue();
-    QRadioButton*   find(int index);
-    QRadioButton*   find(QString name);
+    int count() { return radioButtons.count(); }
+    QString selectedValue();
+    QRadioButton *find(int index);
+    QRadioButton *find(QString name);
 
 public slots:
     virtual void loadInitialValue();
@@ -247,13 +219,11 @@ class KonfiguratorEditBox : public QLineEdit
     Q_OBJECT
 
 public:
-    KonfiguratorEditBox(QString cls, QString name, QString dflt, QWidget *parent = 0,
-                        bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorEditBox(QString configGroup, QString name, QString defaultValue,
+                        QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE);
     ~KonfiguratorEditBox();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
 public slots:
     virtual void loadInitialValue();
@@ -274,13 +244,12 @@ class KonfiguratorURLRequester : public KUrlRequester
     Q_OBJECT
 
 public:
-    KonfiguratorURLRequester(QString cls, QString name, QString dflt, QWidget *parent = 0,
-                             bool rst = false, int pg = FIRST_PAGE, bool expansion = true);
+    KonfiguratorURLRequester(QString configGroup, QString name, QString defaultValue,
+                             QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE,
+                             bool expansion = true);
     ~KonfiguratorURLRequester();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
 public slots:
     virtual void loadInitialValue();
@@ -301,13 +270,11 @@ class KonfiguratorFontChooser : public QWidget
     Q_OBJECT
 
 public:
-    KonfiguratorFontChooser(QString cls, QString name, QFont dflt, QWidget *parent = 0,
-                            bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorFontChooser(QString configGroup, QString name, QFont defaultValue,
+                            QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE);
     ~KonfiguratorFontChooser();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
 public slots:
     virtual void    loadInitialValue();
@@ -351,15 +318,12 @@ class KonfiguratorComboBox : public QComboBox
     Q_OBJECT
 
 public:
-    KonfiguratorComboBox(QString cls, QString name, QString dflt,
-                         KONFIGURATOR_NAME_VALUE_PAIR *listIn, int listInLen,
-                         QWidget *parent = 0,
-                         bool rst = false,  bool editable = false, int pg = FIRST_PAGE);
+    KonfiguratorComboBox(QString configGroup, QString name, QString defaultValue,
+                         KONFIGURATOR_NAME_VALUE_PAIR *listIn, int listInLen, QWidget *parent = 0,
+                         bool restart = false, bool editable = false, int page = FIRST_PAGE);
     ~KonfiguratorComboBox();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
 public slots:
     virtual void loadInitialValue();
@@ -390,9 +354,9 @@ class KonfiguratorColorChooser : public QComboBox
     Q_OBJECT
 
 public:
-    KonfiguratorColorChooser(QString cls, QString name, QColor dflt,
-                             QWidget *parent = 0, bool rst = false,
-                             ADDITIONAL_COLOR *addColPtr = 0, int addColNum = 0, int pg = FIRST_PAGE);
+    KonfiguratorColorChooser(QString configGroup, QString name, QColor defaultValue,
+                             QWidget *parent = 0, bool restart = false,
+                             ADDITIONAL_COLOR *addColPtr = 0, int addColNum = 0, int page = FIRST_PAGE);
     ~KonfiguratorColorChooser();
 
     inline KonfiguratorExtension *extension()   {
@@ -437,14 +401,11 @@ class KonfiguratorListBox : public KrListWidget
     Q_OBJECT
 
 public:
-    KonfiguratorListBox(QString cls, QString name, QStringList dflt,
-                        QWidget *parent = 0,
-                        bool rst = false,  int pg = FIRST_PAGE);
+    KonfiguratorListBox(QString configGroup, QString name, QStringList defaultValue,
+                        QWidget *parent = 0, bool restart = false, int page = FIRST_PAGE);
     ~KonfiguratorListBox();
 
-    inline KonfiguratorExtension *extension()   {
-        return ext;
-    }
+    inline KonfiguratorExtension *extension() { return ext; }
 
     void addItem(const QString &);
     void removeItem(const QString &);
@@ -455,11 +416,11 @@ public slots:
     void slotSetDefaults(QObject *);
 
 protected:
-    QStringList                   list();
-    void                          setList(QStringList);
+    QStringList list();
+    void setList(QStringList);
 
-    QStringList                   defaultValue;
-    KonfiguratorExtension        *ext;
+    QStringList defaultValue;
+    KonfiguratorExtension *ext;
 };
 
 #endif /* __KONFIGURATOR_ITEMS_H__ */
