@@ -1,41 +1,31 @@
-/* **************************************************************************
-                       konfiguratorpage.h  -  description
-                             -------------------
-    copyright            : (C) 2003 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef KONFIGURATORPAGE_H
 #define KONFIGURATORPAGE_H
 
 // QtWidgets
+#include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
 #include <QLayout>
-#include <QGridLayout>
 #include <QScrollArea>
 
 #include "konfiguratoritems.h"
@@ -59,7 +49,7 @@ public:
       * @param firstTime    this parameter is true if it is the first call of Konfigurator
       * @param parent       reference to the parent widget
       */
-    KonfiguratorPage(bool firstTime, QWidget* parent);
+    KonfiguratorPage(bool firstTime, QWidget *parent);
 
     /**
       * Applies the changes in the Konfigurator page.
@@ -68,7 +58,7 @@ public:
       * it with the file storage (hard disk, krusaderrc file). This function calls the apply()
       * method of each konfigurator item and finally performs the synchronization.
       *
-      * @return             a boolean value indicates that Krusader restart is needed for the correct change
+      * @return a boolean value indicates that Krusader restart is needed for the correct change
       */
     virtual bool apply();
 
@@ -105,150 +95,152 @@ public:
       * Flag, indicates the first call of Konfigurator
       * @return             true if konfigurator was started at the first time
       */
-    inline  bool isFirst()   {
-        return firstCall;
-    }
+    inline bool isFirst() { return firstCall; }
 
     /**
       * This method is used to query the active subpage from the Konfigurator
       * @return             the active page (by default the first page)
       */
-    virtual int activeSubPage() {
-        return FIRST_PAGE;
-    }
+    virtual int activeSubPage() { return FIRST_PAGE; }
 
     /**
       * Adds a new checkbox item to the page.
-      * <br>The checkbox widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The checkbox widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
-      * KonfiguratorCheckBox *myCheckBox = createCheckBox( "class", "name", false, parentWidget );<br>
+      * KonfiguratorCheckBox *myCheckBox = createCheckBox( "class", "name", false, parentWidget);<br>
       * myLayout->addWidget( myCheckBox, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the checkbox
-      * @param  text        The text field of the checkbox
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  toolTip     Tooltip used for this checkbox
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the checkbox
+      * @param  text            The text field of the checkbox
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  toolTip         Tooltip used for this checkbox
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created checkbox
       */
-    KonfiguratorCheckBox    *createCheckBox(QString cls, QString name, bool dflt,
-                                            QString text, QWidget *parent = 0, bool rst = false,
-                                            QString toolTip = QString(), int pg = FIRST_PAGE);
+    KonfiguratorCheckBox *createCheckBox(QString configGroup, QString name, bool defaultValue,
+                                         QString text, QWidget *parent = 0, bool restart = false,
+                                         QString toolTip = QString(), int page = FIRST_PAGE);
 
     /**
       * Adds a new spinbox item to the page.
-      * <br>The spinbox widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The spinbox widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
-      * KonfiguratorSpinBox *mySpinBox = createSpinBox( "class", "name", 10, 1, 100, parentWidget );<br>
+      * KonfiguratorSpinBox *mySpinBox = createSpinBox( "class", "name", 10, 1, 100, parentWidget);<br>
       * myLayout->addWidget( mySpinBox, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the spinbox
-      * @param  min         The minimum value of the spinbox
-      * @param  max         The maximum value of the spinbox
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the spinbox
+      * @param  min             The minimum value of the spinbox
+      * @param  max             The maximum value of the spinbox
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created spinbox
       */
-    KonfiguratorSpinBox     *createSpinBox(QString cls, QString name, int dflt, int min,
-                                           int max, QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorSpinBox *createSpinBox(QString configGroup, QString configName, int defaultValue,
+                                       int min, int max, QWidget *parent = 0, bool restart = false,
+                                       int page = FIRST_PAGE);
 
     /**
       * Adds a new editbox item to the page.
-      * <br>The editbox widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The editbox widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
-      * KonfiguratorEditBox *myEditBox = createEditBox( "class", "name", "default", parentWidget );<br>
+      * KonfiguratorEditBox *myEditBox = createEditBox( "class", "name", "default", parentWidget);<br>
       * myLayout->addWidget( myEditBox, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The itemname used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the editbox
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The itemname used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the editbox
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created editbox
       */
-    KonfiguratorEditBox     *createEditBox(QString cls, QString name, QString dflt,
-                                           QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorEditBox *createEditBox(QString configGroup, QString name, QString defaultValue,
+                                       QWidget *parent = 0, bool restart = false,
+                                       int page = FIRST_PAGE);
 
     /**
       * Adds a new listbox item to the page.
-      * <br>The listbox widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The listbox widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
       * QStringList valueList;<br>
       * valueList += "item";<br>
-      * KonfiguratorListBox *myListBox = createListBox( "class", "name", valueList, parentWidget );<br>
+      * KonfiguratorListBox *myListBox = createListBox( "class", "name", valueList, parentWidget);<br>
       * myLayout->addWidget( myListBox, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The itemname used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the listbox
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The itemname used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the listbox
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created editbox
       */
-    KonfiguratorListBox     *createListBox(QString cls, QString name, QStringList dflt,
-                                           QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorListBox *createListBox(QString configGroup, QString name, QStringList defaultValue,
+                                       QWidget *parent = 0, bool restart = false,
+                                       int page = FIRST_PAGE);
 
     /**
       * Adds a new URL requester item to the page.
-      * <br>The URL requester widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The URL requester widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
       * KonfiguratorURLRequester *myURLRequester = createURLRequester( "class", "name", "default", parentWidget );<br>
       * myLayout->addWidget( myURLRequester, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The itemname used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the URL requester
-      * @param  text        The text field of the URL requester
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
-      * @param  expansion   Whether to perform url espansion
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The itemname used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the URL requester
+      * @param  text            The text field of the URL requester
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
+      * @param  expansion       Whether to perform url espansion
       *
       * @return             reference to the newly created URL requester
       */
-    KonfiguratorURLRequester *createURLRequester(QString cls, QString name,
-            QString dflt, QWidget *parent, bool rst, int pg = FIRST_PAGE, bool expansion = true);
+    KonfiguratorURLRequester *createURLRequester(QString configGroup, QString name,
+                                                 QString defaultValue, QWidget *parent,
+                                                 bool restart, int page = FIRST_PAGE,
+                                                 bool expansion = true);
 
     /**
       * Adds a new font chooser item to the page.
-      * <br>The font chooser widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The font chooser widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
       * KonfiguratorFontChooser *myFontChooser = createFontChooser( "class", "name", QFont(), parentWidget );<br>
       * myLayout->addWidget( myFontChooser, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the font chooser
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the font chooser
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created font chooser
       */
-    KonfiguratorFontChooser *createFontChooser(QString cls, QString name, QFont dflt,
-            QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorFontChooser *createFontChooser(QString configGroup, QString name,
+                                               QFont defaultValue, QWidget *parent = 0,
+                                               bool restart = false, int page = FIRST_PAGE);
 
     /**
       * Adds a new combobox item to the page.
-      * <br>The combobox widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The combobox widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
       * KONFIGURATOR_NAME_VALUE_PAIR comboInfo[] =<br>
@@ -258,22 +250,23 @@ public:
       * KonfiguratorComboBox *myComboBox = createComboBox( "class", "name", "value2", comboInfo, 3, parentWidget );<br>
       * myLayout->addWidget( myComboBox, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the combobox
-      * @param  params      Pointer to the name-value pair array (combo elements)
-      * @param  paramNum    Number of the combobox elements
-      * @param  text        The text field of the combobox
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  editable    Flag indicates that the combo can be edited
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the combobox
+      * @param  params          Pointer to the name-value pair array (combo elements)
+      * @param  paramNum        Number of the combobox elements
+      * @param  text            The text field of the combobox
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  editable        Flag indicates that the combo can be edited
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created combobox
       */
-    KonfiguratorComboBox    *createComboBox(QString cls, QString name, QString dflt,
-                                            KONFIGURATOR_NAME_VALUE_PAIR *params, int paramNum,
-                                            QWidget *parent = 0, bool rst = false, bool editable = false, int pg = FIRST_PAGE);
+    KonfiguratorComboBox *createComboBox(QString configGroup, QString name, QString defaultValue,
+                                         KONFIGURATOR_NAME_VALUE_PAIR *params, int paramNum,
+                                         QWidget *parent = 0, bool restart = false,
+                                         bool editable = false, int page = FIRST_PAGE);
 
     /**
       * Creates a frame on the page.
@@ -287,7 +280,7 @@ public:
       *
       * @return             reference to the newly created frame
       */
-    QGroupBox               *createFrame(QString text = QString(), QWidget *parent = 0);
+    QGroupBox *createFrame(QString text = QString(), QWidget *parent = 0);
 
     /**
       * Creates a new QGridLayout element and sets its margins.
@@ -301,7 +294,7 @@ public:
       *
       * @return             reference to the newly created QGridLayout
       */
-    QGridLayout             *createGridLayout(QWidget *parent);
+    QGridLayout *createGridLayout(QWidget *parent);
 
     /**
       * Adds a new label to a grid layout.
@@ -320,8 +313,7 @@ public:
       *
       * @return             reference to the newly created label
       */
-    QLabel                  *addLabel(QGridLayout *layout, int x, int y, QString label,
-                                      QWidget *parent = 0);
+    QLabel *addLabel(QGridLayout *layout, int x, int y, QString label, QWidget *parent = 0);
 
     /**
       * Creates a spacer object (for justifying in QHBox).
@@ -336,7 +328,7 @@ public:
       *
       * @return             reference to the newly created spacer widget
       */
-    QWidget                 *createSpacer(QWidget *parent = 0);
+    QWidget *createSpacer(QWidget *parent = 0);
 
     /**
       * Creates a separator line.
@@ -350,7 +342,7 @@ public:
       *
       * @return             reference to the newly created spacer widget
       */
-    QFrame                   *createLine(QWidget *parent = 0, bool vertical = false);
+    QFrame *createLine(QWidget *parent = 0, bool vertical = false);
 
     /**
       * Creates a checkbox group. A checkbox group contains a lot of checkboxes.
@@ -361,7 +353,7 @@ public:
       * maximum row number in one column. <br>
       *
       * One specific element can be reached by its name or index with the find methods.
-      * The first element is checkBoxGroup->find( 0 ), "myCb" element is checkBoxGroup->find( "myCb" ) ...
+      * The first element is checkBoxGroup->find( 0 ), "myCb" element is checkBoxGroup->find( "myCb") ...
       *
       * Sample:<br><br>
       * KONFIGURATOR_CHECKBOX_PARAM myCBArray[] =<br>
@@ -377,13 +369,14 @@ public:
       * @param  params      pointer to the checkbox array
       * @param  paramNum    number of the checkbox elements
       * @param  parent      Reference to the parent widget
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  page        The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created checkbox group widget
       */
     KonfiguratorCheckBoxGroup *createCheckBoxGroup(int sizex, int sizey,
-            KONFIGURATOR_CHECKBOX_PARAM *params, int paramNum,
-            QWidget *parent = 0, int pg = FIRST_PAGE);
+                                                   KONFIGURATOR_CHECKBOX_PARAM *params,
+                                                   int paramNum, QWidget *parent = 0,
+                                                   int page = FIRST_PAGE);
     /**
       * Creates a radio button group. A radio button group contains a lot of radio buttons.
       * The grouped buttons are embedded into one widget, which can be placed anywhere
@@ -393,34 +386,36 @@ public:
       * maximum row number in one column.<br>
       *
       * The references of the buttons can be accessed by the find methods of KonfiguratorRadioButtons.
-      * The first element is myRadioGrp->find( 0 ), "myRadio" element is myRadioGrp->find( "myRadio" ) ...
+      * The first element is myRadioGrp->find( 0 ), "myRadio" element is myRadioGrp->find( "myRadio") ...
       *
       * Sample:<br><br>
       * KONFIGURATOR_NAME_VALUE_TIP radioInfo[] =<br>
       * &nbsp;{{ i18n( "radio text1" ), "value1", i18n( "tooltip1" ) },<br>
       * &nbsp;&nbsp;{ i18n( "radio text2" ), "value2", i18n( "tooltip2" ) },<br>
       * &nbsp;&nbsp;{ i18n( "radio text3" ), "value3", i18n( "tooltip3" ) }};<br><br>
-      * KonfiguratorRadioButtons *myRadioGroup = createRadioButtonGroup( "class", "name", "value1", 1, 0, radioInfo, 3, myParent, "myRadioGroup" );<br>
+      * KonfiguratorRadioButtons *myRadioGroup = createRadioButtonGroup( "class", "name", "value1",
+      *  1, 0, radioInfo, 3, myParent, "myRadioGroup" );<br>
       * myRadioGroup->find( i18n( "radio text1" ) )->setEnabled( false );<br>
       * myLayout->addWidget( myRadioGroup, 0, 0 );<br>
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the radio buttons
-      * @param  sizex       the maximum column number at horizontal placing
-      * @param  sizey       the maximum row number at vertical placing
-      * @param  params      pointer to the checkbox array
-      * @param  paramNum    number of the checkbox elements
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the radio buttons
+      * @param  sizex           the maximum column number at horizontal placing
+      * @param  sizey           the maximum row number at vertical placing
+      * @param  params          pointer to the checkbox array
+      * @param  paramNum        number of the checkbox elements
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created radio button group widget
       */
-    KonfiguratorRadioButtons *createRadioButtonGroup(QString cls, QString name,
-            QString dflt, int sizex, int sizey,
-            KONFIGURATOR_NAME_VALUE_TIP *params, int paramNum,
-            QWidget *parent = 0, bool rst = false, int pg = FIRST_PAGE);
+    KonfiguratorRadioButtons *createRadioButtonGroup(QString configGroup, QString name,
+                                                     QString defaultValue, int sizex, int sizey,
+                                                     KONFIGURATOR_NAME_VALUE_TIP *params,
+                                                     int paramNum, QWidget *parent = 0,
+                                                     bool restart = false, int page = FIRST_PAGE);
 
     /**
       * This function is used to insert new, unknown items into KonfiguratorPage. The
@@ -431,13 +426,13 @@ public:
       *
       * @param  item        The item to be added to KonfiguratorPage
       */
-    void                    registerObject(KonfiguratorExtension *item);
+    void registerObject(KonfiguratorExtension *item);
 
     /**
       * This function is used to remove elements from KonfiguratorPage.
       *
       * Sample:<br><br>
-      * KonfiguratorEditBox *myEditBox = createEditBox( "class", "name", "default", parentWidget );<br>
+      * KonfiguratorEditBox *myEditBox = createEditBox( "class", "name", "default", parentWidget);<br>
       * myLayout->addWidget( myEditBox, 0, 0 );<br>
       * removeObject( myEditBox->extension() );
       *
@@ -446,42 +441,44 @@ public:
       *
       * @param  item        The item to be removed from KonfiguratorPage
       */
-    void                    removeObject(KonfiguratorExtension *item);
+    void removeObject(KonfiguratorExtension *item);
 
     /**
       * Adds a new color chooser combobox item to the page.
-      * <br>The chooser's widget's name is QString(cls + "/" + name).ascii()<br>
+      * <br>The chooser's widget's name is QString(configGroup + "/" + name).ascii()<br>
       *
       * Sample:<br><br>
       * KonfiguratorColorChooser *myColorChooser = createColorChooser( "class", "name", QColor( 255, 0, 255 ), parentWidget );<br>
       * myLayout->addWidget( myColorChooser, 0, 0 );
       *
-      * @param  cls         The class name used in KConfig (ex. "Archives")
-      * @param  name        The item name used in KConfig (ex. "Do Tar")
-      * @param  dflt        The default value of the color chooser
-      * @param  parent      Reference to the parent widget
-      * @param  rst         The change of this parameter requires Krusader restart
-      * @param  addColPtr   The additional color values
-      * @param  rst         Number of additional colors
-      * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
+      * @param  configGroup     The class name used in KConfig (ex. "Archives")
+      * @param  name            The item name used in KConfig (ex. "Do Tar")
+      * @param  defaultValue    The default value of the color chooser
+      * @param  parent          Reference to the parent widget
+      * @param  restart         The change of this parameter requires Krusader restart
+      * @param  addColPtr       The additional color values
+      * @param  restart         Number of additional colors
+      * @param  page            The subpage of a Konfigurator page (because of setDefaults)
       *
       * @return             reference to the newly created combobox
       */
-    KonfiguratorColorChooser *createColorChooser(QString cls, QString name, QColor dflt,
-            QWidget *parent = 0, bool rst = false,
-            ADDITIONAL_COLOR *addColPtr = 0, int addColNum = 0, int pg = FIRST_PAGE);
+    KonfiguratorColorChooser *createColorChooser(QString configGroup, QString name,
+                                                 QColor defaultValue, QWidget *parent = 0,
+                                                 bool restart = false,
+                                                 ADDITIONAL_COLOR *addColPtr = 0, int addColNum = 0,
+                                                 int page = FIRST_PAGE);
 signals:
     /**
       * The signal is emitted if the changed flag was modified in any konfigurator item.
       * Used for enabling/disabling the apply button.
       */
-    void  sigChanged();
+    void sigChanged();
 
 protected:
     QList<KonfiguratorExtension *> itemList;
 
 private:
-    bool  firstCall;
+    bool firstCall;
 };
 
 /**
@@ -500,7 +497,7 @@ struct KONFIGURATOR_CHECKBOX_PARAM {
     /**
       * The default value of the checkbox
       */
-    bool    defaultValue;
+    bool defaultValue;
     /**
       * The text field of the checkbox
       */
@@ -508,7 +505,7 @@ struct KONFIGURATOR_CHECKBOX_PARAM {
     /**
       * The change of this parameter requires Krusader restart
       */
-    bool    restart;
+    bool restart;
     /**
       * The checkbox's tooltip
       */
