@@ -1,32 +1,23 @@
-/***************************************************************************
-                             kmountman.h
-                          -------------------
- begin                : Thu May 4 2000
- copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
- e-mail               : krusader@users.sourceforge.net
- web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-***************************************************************************
-
-A
-
-  db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-  88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-  88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-  88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-  88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-  YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                  H e a d e r    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 #ifndef KMOUNTMAN_H
 #define KMOUNTMAN_H
 
@@ -59,7 +50,7 @@ public:
     enum mntStatus {DOESNT_EXIST, NOT_MOUNTED, MOUNTED};
 
     inline bool operational() {
-        return Operational;
+        return _operational;
     } // check this 1st
 
     void mount(QString mntPoint, bool blocking = true); // this is probably what you need for mount
@@ -87,8 +78,7 @@ public:
 public slots:
     void mainWindow();                        // opens up the GUI
     void autoMount(QString path);             // just call it before refreshing into a dir
-    void delayedPerformAction(QAction *);
-    void performAction();
+    void delayedPerformAction(const QAction *action);
     void quickList();
 
 protected slots:
@@ -108,10 +98,12 @@ signals:
     void refreshPanel(const QUrl &);
 
 private:
-    QString *_actions;
-    KToolBarPopupAction *_action;
+    enum ActionType { Mount, Unmount };
 
-    bool Operational;   // if false, something went terribly wrong on startup
+    KToolBarPopupAction *_action;
+    QAction *_manageAction;
+
+    bool _operational;   // if false, something went terribly wrong on startup
     bool waiting; // used to block krusader while waiting for (un)mount operation
     KMountManGUI *mountManGui;
     // the following is the FS type
