@@ -1,38 +1,29 @@
-/***************************************************************************
-                              kmountmangui.cpp
-                           -------------------
-  copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-  e-mail               : krusader@users.sourceforge.net
-  web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
-   db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-   88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-   88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-   88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-   88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-   YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                   S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 
 #include "kmountmangui.h"
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../Dialogs/krspecialwidgets.h"
-#include "../kicons.h"
 #include "../defaults.h"
 #include "../FileSystem/filesystem.h"
 
@@ -55,7 +46,6 @@ A
 
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 #include <KWidgetsAddons/KGuiItem>
 #include <KIOCore/KDiskFreeSpaceInfo>
@@ -92,7 +82,7 @@ KMountManGUI::KMountManGUI(KMountMan *mntMan) : QDialog(mntMan->parentWindow),
     mainLayout->addWidget(buttonBox);
 
     ejectButton = new QPushButton(i18n("&Eject"));
-    ejectButton->setIcon(QIcon::fromTheme(QStringLiteral("media-eject")));
+    ejectButton->setIcon(Icon(QStringLiteral("media-eject")));
     ejectButton->setEnabled(false);
     buttonBox->addButton(ejectButton, QDialogButtonBox::ActionRole);
 
@@ -231,7 +221,7 @@ void KMountManGUI::getSpaceData()
     if (mounted.size() == 0) {   // nothing is mounted
         addNonMounted();
         updateList(); // let's continue
-        return ;
+        return;
     }
 
     for (KMountPoint::List::iterator it = mounted.begin(); it != mounted.end(); ++it) {
@@ -299,12 +289,12 @@ void KMountManGUI::addItemToMountList(KrTreeWidget *lst, fsData &fs)
     item->setText(5, (mtd ? sPrct : QString("N/A")));
 
     Solid::StorageVolume *vol = device.as<Solid::StorageVolume> ();
-    QString icon;
+    QString iconName;
 
     if(device.isValid())
-        icon = device.icon();
+        iconName = device.icon();
     else if(mountMan->networkFilesystem(fs.type()))
-        icon = "folder-remote";
+        iconName = "folder-remote";
     QStringList overlays;
     if (mtd) {
         overlays << "emblem-mounted";
@@ -314,7 +304,7 @@ void KMountManGUI::addItemToMountList(KrTreeWidget *lst, fsData &fs)
     if (vol && vol->usage() == Solid::StorageVolume::Encrypted) {
         overlays << "security-high";
     }
-    item->setIcon(0, KDE::icon(icon, overlays));
+    item->setIcon(0, Icon(iconName, overlays));
 }
 
 void KMountManGUI::updateList()
@@ -416,7 +406,7 @@ void KMountManGUI::clicked(QTreeWidgetItem *item, const QPoint & pos)
 #define FORMAT_ID      93
 #define EJECT_ID       94
     //////////////////////////////////////////////////////////
-    if (!item) return ;
+    if (!item) return;
 
     fsData *system = getFsData(item);
     // create the menu
