@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2000-2002 Shie Erlich <erlich@users.sourceforge.net>        *
  * Copyright (C) 2000-2002 Rafi Yanai <yanai@users.sourceforge.net>          *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krcolorcache.h"
@@ -22,6 +24,7 @@
 #include "../defaults.h"
 
 // QtCore
+#include <QDebug>
 #include <QFile>
 #include <QList>
 // QtGui
@@ -219,7 +222,7 @@ bool KrColorSettings::isColorNameValid(const QString & settingName)
 bool KrColorSettings::setColorValue(const QString & settingName, const QColor & color)
 {
     if (!isColorNameValid(settingName)) {
-        krOut << "Invalid color setting name: " << settingName << endl;
+        qWarning() << "Invalid color setting name: " << settingName;
         return false;
     }
     m_impl->m_colorValues[settingName] = color;
@@ -229,7 +232,7 @@ bool KrColorSettings::setColorValue(const QString & settingName, const QColor &
 QColor KrColorSettings::getColorValue(const QString & settingName) const
 {
     if (!isColorNameValid(settingName)) {
-        krOut << "Invalid color setting name: " << settingName << endl;
+        qWarning() << "Invalid color setting name: " << settingName;
         return QColor();
     }
     return m_impl->m_colorValues[settingName];
@@ -238,7 +241,7 @@ QColor KrColorSettings::getColorValue(const QString & settingName) const
 bool KrColorSettings::setColorTextValue(const QString & settingName, const QString & colorText)
 {
     if (!isColorNameValid(settingName)) {
-        krOut << "Invalid color setting name: " << settingName << endl;
+        qWarning() << "Invalid color setting name: " << settingName;
         return false;
     }
     m_impl->m_colorTextValues[settingName] = colorText;
@@ -248,7 +251,7 @@ bool KrColorSettings::setColorTextValue(const QString & settingName, const QStri
 QString KrColorSettings::getColorTextValue(const QString & settingName) const
 {
     if (!isColorNameValid(settingName)) {
-        krOut << "Invalid color setting name: " << settingName << endl;
+        qWarning() << "Invalid color setting name: " << settingName;
         return QString();
     }
     return m_impl->m_colorTextValues[settingName];
@@ -267,7 +270,7 @@ bool KrColorSettings::isNumNameValid(const QString & settingName)
 bool KrColorSettings::setNumValue(const QString & settingName, int value)
 {
     if (!isNumNameValid(settingName)) {
-        krOut << "Invalid number setting name: " << settingName << endl;
+        qWarning() << "Invalid number setting name: " << settingName;
         return false;
     }
     m_impl->m_numValues[settingName] = value;
@@ -277,7 +280,7 @@ bool KrColorSettings::setNumValue(const QString & settingName, int value)
 int KrColorSettings::getNumValue(const QString & settingName, int defaultValue) const
 {
     if (!isNumNameValid(settingName)) {
-        krOut << "Invalid number setting name: " << settingName << endl;
+        qWarning() << "Invalid number setting name: " << settingName;
         return 0;
     }
     if (!m_impl->m_numValues.contains(settingName))
@@ -298,7 +301,7 @@ bool KrColorSettings::isBoolNameValid(const QString & settingName)
 bool KrColorSettings::setBoolValue(const QString & settingName, bool value)
 {
     if (!isBoolNameValid(settingName)) {
-        krOut << "Invalid bool setting name: " << settingName << endl;
+        qWarning() << "Invalid bool setting name: " << settingName;
         return false;
     }
     m_impl->m_boolValues[settingName] = value;
@@ -308,7 +311,7 @@ bool KrColorSettings::setBoolValue(const QString & settingName, bool value)
 int KrColorSettings::getBoolValue(const QString & settingName, bool defaultValue) const
 {
     if (!isBoolNameValid(settingName)) {
-        krOut << "Invalid bool setting name: " << settingName << endl;
+        qWarning() << "Invalid bool setting name: " << settingName;
         return false;
     }
     if (!m_impl->m_boolValues.contains(settingName))
