@@ -1,32 +1,22 @@
-/***************************************************************************
-                            krlayoutfactory.cpp
-                         -------------------
-copyright            : (C) 2010 by Jan Lepper
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
- db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
- 88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
- 88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
- 88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
- 88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
- YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                 S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2010 Jan Lepper <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2010-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krlayoutfactory.h"
 
@@ -34,6 +24,7 @@ A
 #include "../krglobal.h"
 
 // QtCore
+#include <QDebug>
 #include <QMetaEnum>
 #include <QFile>
 #include <QResource>
@@ -78,23 +69,15 @@ bool KrLayoutFactory::parseFiles()
     if (_parsed)
         return true;
 
-    QString mainFilePath = QStandardPaths::locate(QStandardPaths::DataLocation, MAIN_FILE);
-
-    if (!mainFilePath.isEmpty())
-        _parsed = parseFile(mainFilePath, _mainDoc);
-    else
-        krOut << "can't locate" << MAIN_FILE << endl;
-
-    if (!_parsed)
-        _parsed = parseRessource(MAIN_FILE_RC_PATH, _mainDoc);
-
-    if (!_parsed)
+    _parsed = parseResource(MAIN_FILE_RC_PATH, _mainDoc);
+    if (!_parsed) {
         return false;
+    }
 
     QStringList extraFilePaths = QStandardPaths::locateAll(QStandardPaths::DataLocation, EXTRA_FILE_MASK);
 
     foreach(const QString &path, extraFilePaths) {
-        krOut << "extra file: " << path << endl;
+        qWarning() << "extra file: " << path;
         QDomDocument doc;
         if (parseFile(path, doc))
             _extraDocs << doc;
@@ -112,12 +95,12 @@ bool KrLayoutFactory::parseFile(QString path, QDomDocument &doc)
     if (file.open(QIODevice::ReadOnly))
         return parseContent(file.readAll(), path, doc);
     else
-        krOut << "can't open" << path << endl;
+        qWarning() << "can't open" << path;
 
     return success;
 }
 
-bool KrLayoutFactory::parseRessource(QString path, QDomDocument &doc)
+bool KrLayoutFactory::parseResource(QString path, QDomDocument &doc)
 {
     QResource res(path);
     if (res.isValid()) {
@@ -128,7 +111,7 @@ bool KrLayoutFactory::parseRessource(QString path, QDomDocument &doc)
             data = QByteArray(reinterpret_cast<const char*>(res.data()), res.size());
         return parseContent(data, path, doc);
     } else {
-        krOut << "resource does not exist:" << path;
+        qWarning() << "resource does not exist:" << path;
         return false;
     }
 }
@@ -145,11 +128,11 @@ bool KrLayoutFactory::parseContent(QByteArray content, QString fileName, QDomDoc
             if(version == XMLFILE_VERSION)
                 success = true;
             else
-                krOut << fileName << "has wrong version" << version << "- required is" << XMLFILE_VERSION << endl;
+                qWarning() << fileName << "has wrong version" << version << "- required is" << XMLFILE_VERSION;
         } else
-            krOut << "root.tagName() != \"KrusaderLayout\"\n";
+            qWarning() << "root.tagName() != \"KrusaderLayout\"";
     } else
-        krOut << "error parsing" << fileName << ":" << errorMsg << endl;
+        qWarning() << "error parsing" << fileName << ":" << errorMsg;
 
     return success;
 }
@@ -214,7 +197,7 @@ QLayout *KrLayoutFactory::createLayout(QString layoutName)
             }
         }
         if (layoutRoot.isNull()) {
-            krOut << "no layout with name" << layoutName << "found\n";
+            qWarning() << "no layout with name" << layoutName << "found";
             if(layoutName != DEFAULT_LAYOUT)
                 return createLayout(DEFAULT_LAYOUT);
         } else {
@@ -224,11 +207,11 @@ QLayout *KrLayoutFactory::createLayout(QString layoutName)
 
     if(layout) {
         foreach(const QString &name, widgets.keys()) {
-            krOut << "widget" << name << "was not added to the layout\n";
+            qWarning() << "widget" << name << "was not added to the layout";
             widgets[name]->hide();
         }
     } else
-         krOut << "couldn't load layout" << layoutName << endl;
+         qWarning() << "couldn't load layout" << layoutName;
 
 
     return layout;
@@ -246,7 +229,7 @@ QBoxLayout *KrLayoutFactory::createLayout(QDomElement e, QWidget *parent)
     else if(e.attribute("type") == "vertical")
         l = new QVBoxLayout();
     else {
-        krOut << "unknown layout type:" << e.attribute("type") << endl;
+        qWarning() << "unknown layout type:" << e.attribute("type");
         return 0;
     }
 
@@ -264,12 +247,12 @@ QBoxLayout *KrLayoutFactory::createLayout(QDomElement e, QWidget *parent)
             if(QWidget *w = widgets.take(child.attribute("name")))
                 l->addWidget(w);
             else
-                krOut << "layout: so such widget:" << child.attribute("name") << endl;
+                qWarning() << "layout: no such widget:" << child.attribute("name");
         } else if(child.tagName() == "hide_widget") {
             if(QWidget *w = widgets.take(child.attribute("name")))
                 w->hide();
             else
-                krOut << "layout: so such widget:" << child.attribute("name") << endl;
+                qWarning() << "layout: no such widget:" << child.attribute("name");
         } else if(child.tagName() == "spacer") {
             if(horizontal)
                 l->addSpacerItem(new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Fixed));
