@@ -47,7 +47,7 @@ class KrSearchBar : public QWidget
 
 public:
     enum SearchMode {
-        MODE_LAST = -1,
+        MODE_DEFAULT = -1,
         // NOTE: values used for combobox index
         MODE_SEARCH = 0,
         MODE_SELECT = 1,
@@ -60,9 +60,15 @@ public:
      * Set another KrView, old one must not be deleted yet!
      */
     void setView(KrView *view);
+    /**
+     * Hide the search bar if its mode was the search one.
+     *
+     * This function is normally used to hide bar after a user has quicksearched for something and found it.
+     */
+    void hideBarIfSearching();
 
 public slots:
-    void showBar(SearchMode mode = MODE_LAST);
+    void showBar(SearchMode mode = MODE_DEFAULT);
     void hideBar();
     /**
      * Reset search to empty string.
