@@ -56,6 +56,7 @@
 #include "dirhistoryqueue.h"
 #include "krcalcspacedialog.h"
 #include "krerrordisplay.h"
+#include "krsearchbar.h"
 #include "listpanel.h"
 #include "listpanelactions.h"
 #include "PanelView/krview.h"
@@ -436,6 +437,8 @@ void ListPanelFunc::krlink(bool sym)
 
 void ListPanelFunc::view()
 {
+    panel->searchBar->hideBarIfSearching();
+
     QString fileName = panel->getCurrentName();
     if (fileName.isNull())
         return;
@@ -456,7 +459,7 @@ void ListPanelFunc::view()
 void ListPanelFunc::viewDlg()
 {
     // ask the user for a url to view
-    QUrl dest = KChooseDir::getFile(i18n("Enter a URL to view:"), panel->virtualPath(), panel->virtualPath());
+    QUrl dest = KChooseDir::getFile(i18n("Enter a URL to view:"), QUrl(panel->getCurrentName()), panel->virtualPath());
     if (dest.isEmpty())
         return ;   // the user canceled
 
@@ -470,6 +473,7 @@ void ListPanelFunc::terminal()
 
 void ListPanelFunc::edit()
 {
+    panel->searchBar->hideBarIfSearching();
     KFileItem tmp;
 
     if (fileToCreate.isEmpty()) {
@@ -503,7 +507,7 @@ void ListPanelFunc::editNew()
         return;
 
     // ask the user for the filename to edit
-    fileToCreate = KChooseDir::getFile(i18n("Enter the filename to edit:"), panel->virtualPath(), panel->virtualPath());
+    fileToCreate = KChooseDir::getFile(i18n("Enter the filename to edit:"), QUrl(panel->getCurrentName()), panel->virtualPath());
     if(fileToCreate.isEmpty())
         return ;   // the user canceled
 
@@ -542,6 +546,8 @@ void ListPanelFunc::slotFileCreated(KJob *job)
 
 void ListPanelFunc::copyFiles(bool enqueue, bool move)
 {
+    panel->searchBar->hideBarIfSearching();
+
     const QStringList fileNames = panel->getSelectedNames();
     if (fileNames.isEmpty())
         return ;  // safety
@@ -615,6 +621,7 @@ void ListPanelFunc::copyFiles(bool enqueue, bool move)
 // called from SLOTS to begin the renaming process
 void ListPanelFunc::rename()
 {
+    panel->searchBar->hideBarIfSearching();
     panel->view->renameCurrentItem();
 }
 
@@ -673,7 +680,10 @@ void ListPanelFunc::defaultOrAlternativeDeleteFiles(bool invert)
 
 void ListPanelFunc::deleteFiles(bool moveToTrash)
 {
-    if (files()->type() == FileSystem::FS_VIRTUAL && files()->isRoot()) {
+    panel->searchBar->hideBarIfSearching();
+
+    const bool isVFS = files()->type() == FileSystem::FS_VIRTUAL;
+    if (isVFS && files()->isRoot()) {
         // only virtual deletion possible
         removeVirtualFiles();
         return;
@@ -690,7 +700,7 @@ void ListPanelFunc::deleteFiles(bool moveToTrash)
     // now ask the user if he/she is sure:
 
     const QList<QUrl> confirmedUrls = confirmDeletion(
-        files()->getUrls(fileNames), moveToTrash, files()->type() == FileSystem::FS_VIRTUAL, false);
+        files()->getUrls(fileNames), moveToTrash, isVFS, false);
 
     if (confirmedUrls.isEmpty())
         return; // nothing to delete
@@ -700,11 +710,7 @@ void ListPanelFunc::deleteFiles(bool moveToTrash)
     panel->prepareToDelete();
 
     // let the filesystem do the job...
-    QStringList confirmedFileNames;
-    for (QUrl fileUrl : confirmedUrls) {
-        confirmedFileNames.append(fileUrl.fileName());
-    }
-    files()->deleteFiles(confirmedFileNames, moveToTrash);
+    files()->deleteFiles(confirmedUrls, moveToTrash);
 }
 
 QList<QUrl> ListPanelFunc::confirmDeletion(const QList<QUrl> &urls, bool moveToTrash,
@@ -1012,6 +1018,7 @@ void ListPanelFunc::calcSpace()
         // current file is ".." dummy file
         panel->view->selectAllIncludingDirs();
         panel->view->getSelectedItems(&fileNames);
+        panel->view->unselectAll();
     }
 
     SizeCalculator *sizeCalculator = createAndConnectSizeCalculator(files()->getUrls(fileNames));
