@@ -1,33 +1,23 @@
-/***************************************************************************
-                                panelfunc.h
-                             -------------------
-    begin                : Thu May 4 2000
-    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 
 #ifndef PANELFUNC_H
@@ -49,6 +39,7 @@ class FileItem;
 class FileSystem;
 class KrViewItem;
 class ListPanel;
+class SizeCalculator;
 
 class ListPanelFunc : public QObject
 {
@@ -85,8 +76,11 @@ public slots:
      * asks the user the new directory name
      */
     void mkdir();
-    void defaultDeleteFiles(bool invert = false);
-    // delete virtual files or directories in virtual filesystem
+    /** Delete or move selected files to trash - depending on user setting. */
+    void defaultDeleteFiles() { defaultOrAlternativeDeleteFiles(false); }
+    /** Delete or move selected files to trash - inverting the user setting. */
+    void alternativeDeleteFiles() { defaultOrAlternativeDeleteFiles(true); }
+    /** Delete virtual files or directories in virtual filesystem. */
     void removeVirtualFiles();
     void rename();
     void krlink(bool sym = true);
@@ -97,6 +91,8 @@ public slots:
     void testArchive();
     /** Calculate the occupied space of the currently selected items and show a dialog. */
     void calcSpace();
+    /** Calculate the occupied space of the current item without dialog. */
+    void quickCalcSpace();
     void properties();
     void cut() {
         copyToClipboard(true);
@@ -127,6 +123,10 @@ public:
     ListPanelFunc* otherFunc();
     bool atHome();
 
+    /** Ask user for confirmation before deleting files. Returns only confirmed files.*/
+    static QList<QUrl> confirmDeletion(const QList<QUrl> &urls, bool moveToTrash,
+                                       bool virtualFS, bool showPath);
+
 protected slots:
     // Load the current url from history and refresh filesystem and panel to it
     void doRefresh();
@@ -146,20 +146,23 @@ protected:
                          bool immediately, bool manuallyEntered);
     void runCommand(QString cmd);
 
-    ListPanel*           panel;     // our ListPanel
-    DirHistoryQueue*     history;
-    FileSystem*          fileSystemP;      // pointer to fileSystem.
-    QTimer               delayTimer;
-    QUrl                 syncURL;
-    QUrl                 fileToCreate; // file that's to be created by editNewFile()
-    bool                 urlManuallyEntered;
+    ListPanel*               panel;     // our ListPanel
+    DirHistoryQueue*         history;
+    FileSystem*              fileSystemP;      // pointer to fileSystem.
+    QTimer                   delayTimer;
+    QUrl                     syncURL;
+    QUrl                     fileToCreate; // file that's to be created by editNewFile()
+    bool                     urlManuallyEntered;
 
     static QPointer<ListPanelFunc> copyToClipboardOrigin;
 
 private:
+    void defaultOrAlternativeDeleteFiles(bool invert);
     bool getSelectedFiles(QStringList& args);
+    SizeCalculator *createAndConnectSizeCalculator(const QList<QUrl> &urls);
     bool _isPaused; // do not refresh while panel is not visible
     bool _refreshAfterPaused; // refresh after not paused anymore
+    QPointer<SizeCalculator> _quickSizeCalculator;
 };
 
 #endif
