@@ -1,36 +1,26 @@
-/***************************************************************************
-                          viewactions.cpp
-                       -------------------
-copyright            : (C) 2010 by Jan Lepper
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
-db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                               S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2010 Jan Lepper <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2010-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "viewactions.h"
 
-#include "krview.h"
+#include "PanelView/krview.h"
 #include "../krmainwindow.h"
 
 #include <KI18n/KLocalizedString>
