@@ -1,32 +1,23 @@
-/***************************************************************************
-                                 krsearchdialog.h
-                             -------------------
-    copyright            : (C) 2001 by Shie Erlich & Rafi Yanai
-    email                : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef KRSEARCHDIALOG_H
 #define KRSEARCHDIALOG_H
@@ -35,22 +26,23 @@
 #include <QString>
 #include <QStringList>
 // QtWidgets
+#include <QCheckBox>
 #include <QDialog>
+#include <QLabel>
+#include <QTabWidget>
 
-#include "krsearchmod.h"
-
-
-class QLabel;
-class SearchResultContainer;
-class KrView;
-class KrViewItem;
-class ProfileManager;
+class FileItem;
 class FilterTabs;
 class GeneralFilter;
-class QTabWidget;
-class KSqueezedTextLabel;
-class KrSqueezedTextLabel;
 class KrSearchBar;
+class KrSqueezedTextLabel;
+class KrView;
+class KrViewItem;
+class KRQuery;
+class KRSearchMod;
+class KSqueezedTextLabel;
+class ProfileManager;
+class SearchResultContainer;
 
 class KrSearchDialog : public QDialog
 {
@@ -87,8 +79,16 @@ private:
     void viewCurrent();
     void compareByContent();
 
+    /**
+     * Placing search query to clipboard is optional (opt-in).
+     * So user has clipboard untact by default when opening found documents,
+     * but can enable it persistently by checking "Query to clipboard" checkbox.
+     */
+    void tryPlaceSearchQueryToClipboard();
+
 private:
     ProfileManager *profileManager;
+    QCheckBox *searchTextToClipboard;
 
     FilterTabs * filterTabs;
     GeneralFilter * generalFilter;
