@@ -1,32 +1,22 @@
-/***************************************************************************
-                        synchronizer.cpp  -  description
-                             -------------------
-    copyright            : (C) 2003 + by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "synchronizer.h"
 #include "synchronizerdirlist.h"
@@ -240,7 +230,7 @@ void Synchronizer::compareDirectory(SynchronizerFileItem *parent, SynchronizerDi
         checkIfSelected = true;
 
     /* walking through in the left directory */
-    for (left_file = left_directory->first(); left_file != 0 && !stopped ;
+    for (left_file = left_directory->first(); left_file != 0 && !stopped;
             left_file = left_directory->next()) {
         if (isDir(left_file))
             continue;
@@ -271,7 +261,7 @@ void Synchronizer::compareDirectory(SynchronizerFileItem *parent, SynchronizerDi
     }
 
     /* walking through in the right directory */
-    for (right_file = right_directory->first(); right_file != 0 && !stopped ;
+    for (right_file = right_directory->first(); right_file != 0 && !stopped;
             right_file = right_directory->next()) {
         if (isDir(right_file))
             continue;
@@ -292,7 +282,7 @@ void Synchronizer::compareDirectory(SynchronizerFileItem *parent, SynchronizerDi
 
     /* walking through the subdirectories */
     if (recurseSubDirs) {
-        for (left_file = left_directory->first(); left_file != 0 && !stopped ;
+        for (left_file = left_directory->first(); left_file != 0 && !stopped;
                 left_file = left_directory->next()) {
             if (left_file->isDir() && (followSymLinks || !left_file->isSymLink())) {
                 QString left_file_name =  left_file->getName();
@@ -333,7 +323,7 @@ void Synchronizer::compareDirectory(SynchronizerFileItem *parent, SynchronizerDi
         }
 
         /* walking through the right side subdirectories */
-        for (right_file = right_directory->first(); right_file != 0 && !stopped ;
+        for (right_file = right_directory->first(); right_file != 0 && !stopped;
                 right_file = right_directory->next()) {
             if (right_file->isDir() && (followSymLinks || !right_file->isSymLink())) {
                 file_name =  right_file->getName();
@@ -660,9 +650,9 @@ void Synchronizer::operate(SynchronizerFileItem *item,
 
     if (item->isDir()) {
         QString leftDirName = (item->leftDirectory().isEmpty()) ?
-                              item->leftName() : item->leftDirectory() + '/' + item->leftName() ;
+                              item->leftName() : item->leftDirectory() + '/' + item->leftName();
         QString rightDirName = (item->rightDirectory().isEmpty()) ?
-                               item->rightName() : item->rightDirectory() + '/' + item->rightName() ;
+                               item->rightName() : item->rightDirectory() + '/' + item->rightName();
 
         QListIterator<SynchronizerFileItem *> it(resultList);
         while (it.hasNext()) {
@@ -1048,8 +1038,11 @@ void Synchronizer::slotTaskFinished(KJob *job)
                         if (g != 0L)
                             newGroupID = g->gr_gid;
                     }
-                    chown((const char *)(leftURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), newOwnerID, (gid_t) - 1);
-                    chown((const char *)(leftURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), (uid_t) - 1, newGroupID);
+                    int status1 = chown((const char *)(leftURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), newOwnerID, (gid_t) - 1);
+                    int status2 = chown((const char *)(leftURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), (uid_t) - 1, newGroupID);
+                    if (status1 < 0 || status2 < 0) {
+                        // synchronizer currently ignores chown errors
+                    }
 
                     chmod((const char *)(leftURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), item->rightMode() & 07777);
 
@@ -1085,8 +1078,11 @@ void Synchronizer::slotTaskFinished(KJob *job)
                         if (g != 0L)
                             newGroupID = g->gr_gid;
                     }
-                    chown((const char *)(rightURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), newOwnerID, (uid_t) - 1);
-                    chown((const char *)(rightURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), (uid_t) - 1, newGroupID);
+                    int status1 = chown((const char *)(rightURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), newOwnerID, (uid_t) - 1);
+                    int status2 = chown((const char *)(rightURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), (uid_t) - 1, newGroupID);
+                    if (status1 < 0 || status2 < 0) {
+                        // synchronizer currently ignores chown errors
+                    }
 
                     chmod((const char *)(rightURL.adjusted(QUrl::StripTrailingSlash).path().toLocal8Bit()), item->leftMode() & 07777);
 
