@@ -1,19 +1,21 @@
 /*****************************************************************************
  * Copyright (C) 2004 Jonas Bähr <jonas.baehr@web.de>                        *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "useraction.h"
@@ -37,12 +39,12 @@
 #include <KWidgetsAddons/KMessageBox>
 
 #include "kraction.h"
+#include "../FileSystem/filesystem.h"
+#include "../Panel/PanelView/krview.h"
+#include "../Panel/krpanel.h"
+#include "../Panel/panelfunc.h"
 #include "../krusader.h"
 #include "../krusaderview.h"
-#include "../FileSystem/filesystem.h"
-#include "../Panel/krpanel.h"
-#include "../Panel/krview.h"
-#include "../Panel/panelfunc.h"
 
 UserAction::UserAction()
 {
@@ -68,7 +70,7 @@ void UserAction::setAvailability()
 
 void UserAction::setAvailability(const QUrl &currentURL)
 {
-    //qDebug() << "UserAction::setAvailability currendFile: " << currentURL.url() << endl;
+    //qDebug() << "UserAction::setAvailability currendFile: " << currentURL.url();
     // disable the entries that should not appear in this folder
     QListIterator<KrAction *> it(_actions);
     while (it.hasNext()) {
@@ -157,9 +159,9 @@ void UserAction::readFromFile(const QString& filename, ReadMode mode, KrActionLi
     QDomDocument* doc = new QDomDocument(ACTION_DOCTYPE);
     QFile file(filename);
     if (file.open(QIODevice::ReadOnly)) {
-        //qDebug() << "UserAction::readFromFile - " << filename << "could be opened" << endl;
+        //qDebug() << "UserAction::readFromFile - " << filename << "could be opened";
         if (! doc->setContent(&file)) {
-            //qDebug() << "UserAction::readFromFile - content set - failed" << endl;
+            //qDebug() << "UserAction::readFromFile - content set - failed";
             // if the file doesn't exist till now, the content CAN be set but is empty.
             // if the content can't be set, the file exists and is NOT an xml-file.
             file.close();
@@ -237,7 +239,7 @@ void UserAction::readFromElement(const QDomElement& element, ReadMode mode, KrAc
             if (e.tagName() == "deletedAction") {
                 QString name = e.attribute("name");
                 if (name.isEmpty()) {
-                    krOut << "A deleted action without name detected! \nThis is an error in the file.";
+                    qWarning() << "A deleted action without name detected! \nThis is an error in the file.";
                     continue;
                 }
                 _deletedActions.insert(name);
