@@ -1,33 +1,23 @@
-/***************************************************************************
-                               defaults.h
-                            -------------------
-   begin                : Thu May 4 2000
-   copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-   e-mail               : krusader@users.sourceforge.net
-   web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
- Description
-***************************************************************************
-
- A
-
-    db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-    88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-    88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-    88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-    88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-    YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                    H e a d e r    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef DEFAULTS_H
 #define DEFAULTS_H
@@ -67,7 +57,7 @@
 // Warn On Exit ////////
 #define _WarnOnExit     false
 // Minimize To Tray ////
-#define _MinimizeToTray false
+#define _ShowTrayIcon false
 // Mark Dirs ///////////
 #define _MarkDirs       false
 // Show Hidden /////////
@@ -86,8 +76,10 @@
 #define _FullPathTabNames false
 // User defined folder icons
 #define _UserDefinedFolderIcons true
+// Always show current item decoration in panel
+#define _AlwaysShowCurrentItem true
 // Unslect files before copy/move
-#define _UnselectBeforeOperation true
+#define _UnselectBeforeOperation false
 // Filter dialog remembers settings
 #define _FilterDialogRemembersSettings false
 
@@ -146,6 +138,8 @@
 #define _NewStyleQuicksearch true
 // Case Sensitive quick search, if _NewStyleQuicksearch is true
 #define _CaseSensitiveQuicksearch false
+// Special handling of Right Arrow in Quicksearch
+#define _NavigationWithRightArrowQuicksearch true
 // View In Separate Window
 #define _ViewInSeparateWindow  false
 
@@ -313,6 +307,8 @@
 #define _ShiftCtrlRight  false
 // Space Moves Down
 #define _SpaceMovesDown  true
+// Space Calc Space
+#define _SpaceCalcSpace  true
 // Insert Moves Down
 #define _InsertMovesDown true
 // Immediate Context Menu
