@@ -1,32 +1,23 @@
-/***************************************************************************
-                          kractions.cpp
-                       -------------------
-copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
-db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                               S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kractions.h"
 
@@ -43,15 +34,16 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 
 #include "defaults.h"
 #include "krusader.h"
+#include "icon.h"
 #include "krusaderview.h"
 #include "krslots.h"
 #include "krtrashhandler.h"
-#include "Panel/krviewfactory.h"
-#include "GUI/krremoteencodingmenu.h"
-#include "UserAction/useraction.h"
-#include "MountMan/kmountman.h"
 #include "Dialogs/popularurls.h"
+#include "GUI/krremoteencodingmenu.h"
 #include "JobMan/jobman.h"
+#include "MountMan/kmountman.h"
+#include "Panel/PanelView/krviewfactory.h"
+#include "UserAction/useraction.h"
 
 QAction *KrActions::actCompare = 0;
 QAction *KrActions::actDiskUsage = 0;
@@ -81,7 +73,7 @@ QAction *KrActions::actManageUseractions = 0;
 #ifdef SYNCHRONIZER_ENABLED
 QAction *KrActions::actSyncDirs = 0;
 #endif
-QAction *KrActions::actF10 = 0;
+QAction *KrActions::actF10Quit = 0;
 QAction *KrActions::actEmptyTrash = 0;
 QAction *KrActions::actTrashBin = 0;
 QAction *KrActions::actPopularUrls = 0;
@@ -120,28 +112,28 @@ QAction *KrActions::actJobUndo = 0;
 #endif
 
 
-QAction *createAction(QString text, QString icon, QKeySequence shortcut,
+QAction *createAction(QString text, QString iconName, QKeySequence shortcut,
                       QObject *recv, const char *slot, QString name, Krusader *krusaderApp)
 {
     QAction *a;
-    if (icon.isEmpty())
+    if (iconName.isEmpty())
         a = new QAction(text, krusaderApp);
     else
-        a = new QAction(QIcon::fromTheme(icon), text, krusaderApp);
+        a = new QAction(Icon(iconName), text, krusaderApp);
     krusaderApp->connect(a, SIGNAL(triggered(bool)), recv, slot);
     krusaderApp->actionCollection()->addAction(name, a);
     krusaderApp->actionCollection()->setDefaultShortcut(a, shortcut);
     return a;
 }
 
-QAction *createAction(QString text, QString icon, QList<QKeySequence> shortcuts,
+QAction *createAction(QString text, QString iconName, QList<QKeySequence> shortcuts,
                       QObject *recv, const char *slot, QString name, Krusader *krusaderApp)
 {
     QAction *a;
-    if (icon.isEmpty())
+    if (iconName.isEmpty())
         a = new QAction(text, krusaderApp);
     else
-        a = new QAction(QIcon::fromTheme(icon), text, krusaderApp);
+        a = new QAction(Icon(iconName), text, krusaderApp);
     krusaderApp->connect(a, SIGNAL(triggered(bool)), recv, slot);
     krusaderApp->actionCollection()->addAction(name, a);
     krusaderApp->actionCollection()->setDefaultShortcuts(a, shortcuts);
@@ -149,14 +141,14 @@ QAction *createAction(QString text, QString icon, QList<QKeySequence> shortcuts,
 }
 
 
-KToggleAction *createToggleAction(QString text, QString icon, QKeySequence shortcut,
+KToggleAction *createToggleAction(QString text, QString iconName, QKeySequence shortcut,
                                  QObject *recv, const char *slot, QString name, Krusader *krusaderApp)
 {
     KToggleAction *a;
-    if (icon == 0)
+    if (iconName == 0)
         a = new KToggleAction(text, krusaderApp);
     else
-        a = new KToggleAction(QIcon::fromTheme(icon), text, krusaderApp);
+        a = new KToggleAction(Icon(iconName), text, krusaderApp);
     krusaderApp->connect(a, SIGNAL(triggered(bool)), recv, slot);
     krusaderApp->actionCollection()->addAction(name, a);
     krusaderApp->actionCollection()->setDefaultShortcut(a, shortcut);
@@ -200,7 +192,7 @@ void KrActions::setupActions(Krusader *krusaderApp)
     krusaderApp->actionCollection()->addAction("toggle actions toolbar", actShowActionsToolBar);
 
     actShowStatusBar = KStandardAction::showStatusbar(SLOTS, SLOT(updateStatusbarVisibility()), krusaderApp->actionCollection());
-    KStandardAction::quit(krusaderApp, SLOT(close()), krusaderApp->actionCollection());
+    KStandardAction::quit(krusaderApp, SLOT(quit()), krusaderApp->actionCollection());
     KStandardAction::configureToolbars(krusaderApp, SLOT(configureToolbars()), krusaderApp->actionCollection());
     KStandardAction::keyBindings(krusaderApp->guiFactory(), SLOT(configureShortcuts()), krusaderApp->actionCollection());
 
@@ -218,7 +210,7 @@ void KrActions::setupActions(Krusader *krusaderApp)
 
     NEW_KACTION(actEmptyTrash, i18n("Empty Trash"), "trash-empty", 0, SLOTS, SLOT(emptyTrash()), "emptytrash");
 
-    NEW_KACTION(actTrashBin, i18n("Trash Popup Menu"), KrTrashHandler::trashIcon(), 0, SLOTS, SLOT(trashPopupMenu()), "trashbin");
+    NEW_KACTION(actTrashBin, i18n("Trash Popup Menu"), KrTrashHandler::trashIconName(), 0, SLOTS, SLOT(trashPopupMenu()), "trashbin");
 
     NEW_KACTION(actSwapSides, i18n("Sw&ap Sides"), 0, Qt::CTRL + Qt::SHIFT + Qt::Key_U, SLOTS, SLOT(toggleSwapSides()), "toggle swap sides");
     actToggleHidden->setChecked(KConfigGroup(krConfig, "Look&Feel").readEntry("Show Hidden", _ShowHidden));
@@ -286,7 +278,7 @@ void KrActions::setupActions(Krusader *krusaderApp)
     NEW_KACTION(actKonfigurator, i18n("Configure &Krusader..."), "configure", 0, SLOTS, SLOT(startKonfigurator()), "konfigurator");
     NEW_KACTION(actSavePosition, i18n("Save &Position"), 0, 0, krusaderApp, SLOT(savePosition()), "save position");
     NEW_KACTION(actCompare, i18n("Compare b&y Content..."), "kr_comparedirs", 0, SLOTS, SLOT(compareContent()), "compare");
-    NEW_KACTION(actMultiRename, i18n("Multi &Rename..."), "edit-rename", Qt::SHIFT + Qt::Key_F9, SLOTS, SLOT(multiRename()), "multirename");
+    NEW_KACTION(actMultiRename, i18n("Multi &Rename..."), "edit-rename", Qt::SHIFT + Qt::Key_F2, SLOTS, SLOT(multiRename()), "multirename");
 
     NEW_KACTION(actAddBookmark, i18n("Add Bookmark"), "bookmark-new", KStandardShortcut::addBookmark(), SLOTS, SLOT(addBookmark()), "add bookmark");
     NEW_KACTION(actVerticalMode, i18n("Vertical Mode"), "view-split-top-bottom", Qt::ALT + Qt::CTRL + Qt::Key_R, MAIN_VIEW, SLOT(toggleVerticalMode()), "toggle vertical mode");
@@ -296,7 +288,9 @@ void KrActions::setupActions(Krusader *krusaderApp)
 
     actRemoteEncoding = new KrRemoteEncodingMenu(i18n("Select Remote Charset"), "character-set", krusaderApp->actionCollection());
 
-    NEW_KACTION(actF10, i18n("Quit"), 0, Qt::Key_F10, krusaderApp, SLOT(close()) , "F10_Quit");
+    NEW_KACTION(actF10Quit, i18n("Quit"), 0, Qt::Key_F10, krusaderApp, SLOT(quit()) , "F10_Quit");
+    actF10Quit->setToolTip(i18n("Quit Krusader."));
+
     NEW_KACTION(actPopularUrls, i18n("Popular URLs..."), 0, Qt::CTRL + Qt::Key_Z, krusaderApp->popularUrls(), SLOT(showDialog()), "Popular_Urls");
     NEW_KACTION(actSwitchFullScreenTE, i18n("Toggle Fullscreen Embedded Terminal"), 0,
                 Qt::CTRL + Qt::ALT + Qt::Key_F, MAIN_VIEW, SLOT(toggleFullScreenTerminalEmulator()),
