@@ -1,51 +1,36 @@
-/***************************************************************************
-                                krglobal.h
-                           -------------------
-    begin                : Thu May 4 2000
-    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
- Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef KRGLOBAL_H
 #define KRGLOBAL_H
 
-// QtCore
-#include <QDebug>
 // QtGui
 #include <QKeySequence>
 
 #include <KConfigCore/KConfigGroup>
 
-#define krOut qDebug()
-
 class KConfig;
 class KMountMan;
 class KrBookmarkHandler;
 class KRslots;
-class KIconLoader;
 class KrusaderView;
 class UserAction;
 class JobMan;
@@ -61,7 +46,6 @@ public:
     static KMountMan *mountMan;  // krusader's Mount Manager
     static KrBookmarkHandler *bookman;
     static KRslots *slot;
-    static KIconLoader *iconLoader; // the app's icon loader
     static KrusaderView *mainView;  // The GUI
     static QWidget *mainWindow;
     static UserAction *userAction;
@@ -74,13 +58,16 @@ public:
 
 //     static void enableAction(const char *name, bool enable);
 //     static QAction *getAction(const char *name);
+
+    /** Version of saved configuration. Use this to detect configuration updates. */
+    static const int sConfigVersion = 1;
+    static int sCurrentConfigVersion;
 };
 
 #define krConfig     KrGlobal::config
 #define krMtMan      (*(KrGlobal::mountMan))
 #define krBookMan    KrGlobal::bookman
 #define SLOTS        KrGlobal::slot
-#define krLoader     KrGlobal::iconLoader
 #define MAIN_VIEW    KrGlobal::mainView
 #define krMainWindow KrGlobal::mainWindow
 #define krUserAction KrGlobal::userAction
