@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef KRSERVICES_H
@@ -29,6 +31,9 @@
 class QTextStream;
 class QFile;
 
+/**
+ * Global static utility functions.
+ */
 class KrServices
 {
 public:
@@ -49,7 +54,12 @@ public:
     static QStringList  supportedTools(); // find supported tools
     static QString      escapeFileUrl(QString urlString);
     static QUrl         escapeFileUrl(const QUrl &url);
-
+    /**
+     * Sets the global logging message handler for qDebug(), qWarning()... messages to a custom one
+     * with the ability to filter debug messages.
+     */
+    static void setGlobalKrMessageHandler(bool withDebugMessages);
+    static QString GLOBAL_MESSAGE_PATTERN;
 
 protected:
     static QString    escape(QString name);
@@ -61,7 +71,7 @@ private:
     static QMap<QString, QString>* slaveMap;
     static QSet<QString> krarcArchiveMimetypes;
     static QSet<QString> isoArchiveMimetypes;
-
+    static void krMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg);
 };
 
 // TODO: make KrServices a namespace and move it there
