@@ -1,32 +1,23 @@
-/***************************************************************************
-                          krusader.cpp
-                       -------------------
-copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
-db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                               S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krusader.h"
 
@@ -49,7 +40,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <KConfigCore/KSharedConfig>
 #include <KConfigGui/KWindowConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KXmlGui/KActionCollection>
 #include <KXmlGui/KXMLGUIFactory>
 #include <KXmlGui/KToolBar>
@@ -61,43 +51,42 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <KWindowSystem/KStartupInfo>
 #include <KWindowSystem/KWindowSystem>
 
-#include "krusaderversion.h"
-#include "kicons.h"
-#include "krusaderview.h"
 #include "defaults.h"
-#include "krslots.h"
-#include "krservices.h"
-// This makes gcc-4.1 happy. Warning about possible problem with KrAction's dtor not called
-#include "krtrashhandler.h"
-#include "tabactions.h"
-#include "krglobal.h"
 #include "kractions.h"
+#include "krglobal.h"
+#include "krservices.h"
+#include "krslots.h"
+#include "krtrashhandler.h"
+#include "krusaderversion.h"
+#include "krusaderview.h"
 #include "panelmanager.h"
-#include "Panel/krcolorcache.h"
-#include "Panel/viewactions.h"
-#include "Panel/listpanelactions.h"
-#include "Panel/krpanel.h"
-#include "Panel/krview.h"
-#include "Panel/krviewfactory.h"
-#include "UserAction/kraction.h"
-#include "UserAction/expander.h"
-#include "UserAction/useraction.h"
-#include "Dialogs/popularurls.h"
+#include "tabactions.h"
+
+#include "BookMan/krbookmarkhandler.h"
 #include "Dialogs/checksumdlg.h"
 #include "Dialogs/krpleasewait.h"
-#include "GUI/krremoteencodingmenu.h"
-#include "GUI/kfnkeys.h"
-#include "GUI/kcmdline.h"
-#include "GUI/terminaldock.h"
-#include "GUI/krusaderstatus.h"
+#include "Dialogs/popularurls.h"
 #include "FileSystem/fileitem.h"
 #include "FileSystem/krpermhandler.h"
-#include "MountMan/kmountman.h"
-#include "Konfigurator/kgprotocols.h"
-#include "BookMan/krbookmarkhandler.h"
-#include "KViewer/krviewer.h"
+#include "GUI/kcmdline.h"
+#include "GUI/kfnkeys.h"
+#include "GUI/krremoteencodingmenu.h"
+#include "GUI/krusaderstatus.h"
+#include "GUI/terminaldock.h"
 #include "JobMan/jobman.h"
-
+#include "KViewer/krviewer.h"
+#include "Konfigurator/kgprotocols.h"
+#include "MountMan/kmountman.h"
+#include "Panel/PanelView/krview.h"
+#include "Panel/PanelView/krviewfactory.h"
+#include "Panel/krcolorcache.h"
+#include "Panel/krpanel.h"
+#include "Panel/listpanelactions.h"
+#include "Panel/viewactions.h"
+#include "UserAction/expander.h"
+// This makes gcc-4.1 happy. Warning about possible problem with KrAction's dtor not called
+#include "UserAction/kraction.h"
+#include "UserAction/useraction.h"
 
 #ifdef __KJSEMBED__
 #include "KrJS/krjs.h"
@@ -118,7 +107,7 @@ QAction *Krusader::actShowJSConsole = 0;
 // construct the views, statusbar and menu bars and prepare Krusader to start
 Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
                 Qt::Window | Qt::WindowTitleHint | Qt::WindowContextHelpButtonHint),
-        _listPanelActions(0), isStarting(true), isExiting(false)
+        _listPanelActions(0), isStarting(true), isExiting(false), _quit(false)
 {
     // create the "krusader"
     App = this;
@@ -128,7 +117,7 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
 
     plzWait = new KRPleaseWaitHandler(this);
 
-    bool runKonfig = versionControl();
+    const bool runKonfig = versionControl();
 
     QString message;
     switch (krConfig->accessMode()) {
@@ -146,40 +135,37 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
         KMessageBox::error(krApp, message);
     }
 
-    // create an icon loader
-    krLoader = KIconLoader::global();
-//   iconLoader->addExtraDesktopThemes();
-
     // create MountMan
     KrGlobal::mountMan = new KMountMan(this);
     connect(KrGlobal::mountMan, SIGNAL(refreshPanel(QUrl)), SLOTS, SLOT(refresh(QUrl)));
 
+    // create popular URLs container
+    _popularUrls = new PopularUrls(this);
+
     // create bookman
     krBookMan = new KrBookmarkHandler(this);
 
     // create job manager
     krJobMan = new JobMan(this);
 
-    _popularUrls = new PopularUrls(this);
-
     // create the main view
     MAIN_VIEW = new KrusaderView(this);
 
     // setup all the krusader's actions
     setupActions();
 
-    // init the permmision handler class
+    // init the permission handler class
     KRpermHandler::init();
 
     // init the protocol handler
     KgProtocols::init();
 
-    KConfigGroup gl(krConfig, "Look&Feel");
-    FileItem::loadUserDefinedFolderIcons(gl.readEntry("Load User Defined Folder Icons",
-                                                         _UserDefinedFolderIcons));
+    const KConfigGroup lookFeelGroup(krConfig, "Look&Feel");
+    FileItem::loadUserDefinedFolderIcons(lookFeelGroup.readEntry("Load User Defined Folder Icons",
+                                                                 _UserDefinedFolderIcons));
 
-    KConfigGroup gs(krConfig, "Startup");
-    QString     startProfile = gs.readEntry("Starter Profile Name", QString());
+    const KConfigGroup startupGroup(krConfig, "Startup");
+    QString startProfile = startupGroup.readEntry("Starter Profile Name", QString());
 
     QList<QUrl> leftTabs;
     QList<QUrl> rightTabs;
@@ -201,7 +187,7 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
         rightTabs.clear();
     }
     // starting the panels
-    MAIN_VIEW->start(gs, startProfile.isEmpty(), leftTabs, rightTabs);
+    MAIN_VIEW->start(startupGroup, startProfile.isEmpty(), leftTabs, rightTabs);
 
     // create a status bar
     KrusaderStatus *status = new KrusaderStatus(this);
@@ -209,19 +195,9 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
     status->setWhatsThis(i18n("Statusbar will show basic information "
                               "about file below mouse pointer."));
 
-    // create tray icon (even if not shown)
-    sysTray = new QSystemTrayIcon(this);
-    sysTray->setIcon(krLoader->loadIcon(privIcon(), KIconLoader::Panel, 22));
-    QMenu *trayMenu = new QMenu(this);
-    trayMenu->addSection(QGuiApplication::applicationDisplayName()); // show "title"
-    QAction *restoreAction = new QAction(i18n("Restore"), this);
-    connect(restoreAction, SIGNAL(triggered()), SLOT(showFromTray()));
-    trayMenu->addAction(restoreAction);
-    trayMenu->addSeparator();
-    trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
-    sysTray->setContextMenu(trayMenu);
-    // tray is only visible if main window is hidden, so action is always "show"
-    connect(sysTray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(showFromTray()));
+    // create tray icon (if needed)
+    const bool startToTray = startupGroup.readEntry("Start To Tray", _StartToTray);
+    setTray(startToTray);
 
     setCentralWidget(MAIN_VIEW);
 
@@ -256,12 +232,11 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
         toolBar("actionsToolBar")->applySettings(cfgActionsBar);
 
         // restore toolbars position and visibility
-        const KConfigGroup cfgStartup(krConfig->group("Startup"));
-        restoreState(cfgStartup.readEntry("State", QByteArray()));
+        restoreState(startupGroup.readEntry("State", QByteArray()));
 
-        statusBar()->setVisible(cfgStartup.readEntry("Show status bar", _ShowStatusBar));
+        statusBar()->setVisible(startupGroup.readEntry("Show status bar", _ShowStatusBar));
 
-        MAIN_VIEW->updateGUI(cfgStartup);
+        MAIN_VIEW->updateGUI(startupGroup);
 
         // popular urls
         _popularUrls->load();
@@ -282,10 +257,8 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
         resize(cfg.readEntry("Start Size", _StartSize));
     }
 
-    // view initialized; show window or tray
-    if (gs.readEntry("Start To Tray", _StartToTray)) {
-        sysTray->show();
-    } else {
+    // view initialized; show window or only tray
+    if (!startToTray) {
         show();
     }
 
@@ -313,7 +286,7 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
 Krusader::~Krusader()
 {
     KrTrashHandler::stopWatcher();
-    if (!isExiting)    // save the settings if it was not saved (SIGTERM)
+    if (!isExiting) // save the settings if it was not saved (SIGTERM received)
         saveSettings();
 
     delete MAIN_VIEW;
@@ -321,44 +294,48 @@ Krusader::~Krusader()
     App = 0;
 }
 
+void Krusader::setTray(bool forceCreation)
+{
+    const bool trayIsNeeded = forceCreation || KConfigGroup(krConfig, "Look&Feel")
+                                               .readEntry("Minimize To Tray", _ShowTrayIcon);
+    if (!sysTray && trayIsNeeded) {
+        sysTray = new KStatusNotifierItem(this);
+        sysTray->setIconByName(appIconName());
+        // we have our own "quit" method, re-connect
+        QAction *quitAction = sysTray->action(QStringLiteral("quit"));
+        if (quitAction) {
+            disconnect(quitAction, &QAction::triggered, nullptr, nullptr);
+            connect(quitAction, &QAction::triggered, this, &Krusader::quit);
+        }
+    } else if (sysTray && !trayIsNeeded) {
+        // user does not want tray anymore :(
+        sysTray->deleteLater();
+    }
+}
+
 bool Krusader::versionControl()
 {
-#define FIRST_RUN "First Time"
-    bool retval = false;
     // create config file
     krConfig = KSharedConfig::openConfig().data();
     KConfigGroup nogroup(krConfig, QString());
-
-    bool firstRun = nogroup.readEntry(FIRST_RUN, true);
-
-#if 0
-    QString oldVerText = nogroup.readEntry("Version", "10.0");
-    oldVerText.truncate(oldVerText.lastIndexOf("."));     // remove the third dot
-    float oldVer = oldVerText.toFloat();
-    // older icompatible version
-    if (oldVer <= 0.9) {
-        KMessageBox::information(krApp, i18n("A configuration of 1.51 or older was detected. Krusader has to reset your configuration to default values.\nNote: your bookmarks and keybindings will remain intact.\nKrusader will now run Konfigurator."));
-        /*if ( !QDir::home().remove( ".kde/share/config/krusaderrc" ) ) {
-           KMessageBox::error( krApp, i18n( "Unable to remove your krusaderrc file. Please remove it manually and rerun Krusader." ) );
-           exit( 1 );
-        }*/
-        retval = true;
-        krConfig->reparseConfiguration();
-    }
-#endif
+    const bool firstRun = nogroup.readEntry("First Time", true);
+    KrGlobal::sCurrentConfigVersion = nogroup.readEntry("Config Version", -1);
 
     // first installation of krusader
     if (firstRun) {
-        KMessageBox::information(krApp, i18n("<qt><b>Welcome to Krusader.</b><p>As this is your first run, your machine will now be checked for external applications. Then the Konfigurator will be launched where you can customize Krusader to your needs.</p></qt>"));
-        retval = true;
+        KMessageBox::information(
+            krApp, i18n("<qt><b>Welcome to Krusader.</b><p>As this is your first run, your machine "
+                        "will now be checked for external applications. Then the Konfigurator will "
+                        "be launched where you can customize Krusader to your needs.</p></qt>"));
     }
     nogroup.writeEntry("Version", VERSION);
-    nogroup.writeEntry(FIRST_RUN, false);
+    nogroup.writeEntry("First Time", false);
     krConfig->sync();
 
-    QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/krusader/"));
+    QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
+                  QStringLiteral("/krusader/"));
 
-    return retval;
+    return firstRun;
 }
 
 void Krusader::statusBarUpdate(const QString& mess)
@@ -368,46 +345,6 @@ void Krusader::statusBarUpdate(const QString& mess)
         statusBar()->showMessage(mess, 5000);
 }
 
-void Krusader::showFromTray() {
-    setWindowState((windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
-    show();
-    sysTray->hide();
-}
-
-void Krusader::changeEvent(QEvent *event) {
-    QMainWindow::changeEvent(event);
-    if (isExiting)
-        return;
-
-    // toggle tray when minimizing (if enabled)
-    if(event->type() == QEvent::WindowStateChange) {
-        if(isMinimized()) {
-            KConfigGroup group(krConfig, "Look&Feel");
-            if (group.readEntry("Minimize To Tray", _MinimizeToTray)) {
-                // TODO tray created again to prevent bug in kf5,
-                // remove this if bug 365105 is resolved
-                sysTray->deleteLater();
-                sysTray = new QSystemTrayIcon(this);
-                sysTray->setIcon(krLoader->loadIcon(privIcon(), KIconLoader::Panel, 22));
-                QMenu *trayMenu = new QMenu(this);
-                trayMenu->addSection(QGuiApplication::applicationDisplayName()); // show "title"
-                QAction *restoreAction = new QAction(i18n("Restore"), this);
-                connect(restoreAction, SIGNAL(triggered()), SLOT(showFromTray()));
-                trayMenu->addAction(restoreAction);
-                trayMenu->addSeparator();
-                trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
-                sysTray->setContextMenu(trayMenu);
-                connect(sysTray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(showFromTray()));
-
-                sysTray->show();
-                hide();
-            }
-        } else if(isVisible()) {
-            sysTray->hide();
-        }
-    }
-}
-
 bool Krusader::event(QEvent *e) {
     if(e->type() == QEvent::ApplicationPaletteChange) {
         KrColorCache::getColorCache().refreshColors();
@@ -459,6 +396,9 @@ void Krusader::saveSettings() {
         MAIN_VIEW->setTerminalEmulator(false, true);
     }
 
+    KConfigGroup noGroup(krConfig, QString());
+    noGroup.writeEntry("Config Version", KrGlobal::sConfigVersion);
+
     // save toolbar settings
     KConfigGroup cfg(krConfig, "Main Toolbar");
     toolBar()->saveSettings(cfg);
@@ -491,6 +431,29 @@ void Krusader::saveSettings() {
     krConfig->sync();
 }
 
+void Krusader::closeEvent(QCloseEvent *event)
+{
+    if (!sysTray || _quit) {
+        _quit = false; // in case quit will be aborted
+        KParts::MainWindow::closeEvent(event); // (may) quit, continues with queryClose()...
+    } else {
+        // close window to tray
+        event->ignore();
+        hide();
+    }
+}
+
+void Krusader::showEvent(QShowEvent *event)
+{
+    const KConfigGroup lookFeelGroup(krConfig, "Look&Feel");
+    if (sysTray && !lookFeelGroup.readEntry("Minimize To Tray", _ShowTrayIcon)) {
+        // restoring from "start to tray", tray icon is not needed anymore
+        sysTray->deleteLater();
+    }
+
+    KParts::MainWindow::showEvent(event);
+}
+
 bool Krusader::queryClose() {
     if (isStarting || isExiting)
         return false;
@@ -562,7 +525,7 @@ void Krusader::acceptClose() {
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.unregisterObject("/Instances/" + Krusader::AppName);
 
-    isExiting = true; // this will also kill the pending jobs
+    isExiting = true;
 }
 
 // the please wait dialog functions
@@ -589,13 +552,19 @@ void Krusader::updateUserActions() {
     }
 }
 
-const char* Krusader::privIcon() {
+const char* Krusader::appIconName() {
     if (geteuid())
         return "krusader_user";
     else
         return "krusader_root";
 }
 
+void Krusader::quit()
+{
+    _quit = true; // remember that we want to quit and not close to tray
+    close(); // continues with closeEvent()...
+}
+
 void Krusader::moveToTop() {
     if (isHidden())
         show();
