@@ -1,33 +1,23 @@
-/***************************************************************************
-                                krusader.h
-                           -------------------
-    begin                : Thu May 4 2000
-    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
- The main application ! what's more to say ?
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     H e a d e r    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #ifndef KRUSADER_H
 #define KRUSADER_H
@@ -41,21 +31,22 @@
 // QtCore
 #include <QCommandLineParser>
 #include <QEvent>
+#include <QPointer>
 #include <QStringList>
 #include <QTimer>
 // QtGui
-#include <QShowEvent>
-#include <QResizeEvent>
 #include <QHideEvent>
 #include <QMoveEvent>
+#include <QResizeEvent>
+#include <QShowEvent>
 // QtWidgets
 #include <QAction>
-#include <QSystemTrayIcon>
 
-#include <KParts/MainWindow>
-#include <KConfigWidgets/KStandardAction>
 #include <KConfigCore/KConfig>
 #include <KConfigCore/KConfigGroup>
+#include <KConfigWidgets/KStandardAction>
+#include <KNotifications/KStatusNotifierItem>
+#include <KParts/MainWindow>
 
 #ifdef __KJSEMBED__
 class KrJS;
@@ -84,6 +75,8 @@ public:
     explicit Krusader(const QCommandLineParser &parser);
     virtual ~Krusader();
 
+    void setTray(bool forceCreation = false);
+
     // KrMainWindow implementation
     virtual QWidget *widget() Q_DECL_OVERRIDE {
         return this;
@@ -113,14 +106,16 @@ public:
     virtual void plugActionList(const char *name, QList<QAction*> &list) Q_DECL_OVERRIDE {
         KParts::MainWindow::plugActionList(name, list);
     }
-    /**
-     * This returns a defferent icon if krusader runs with root-privileges
-     * @return a character string with the specitif icon-name
-     */
-    static const char* privIcon();
 
+    /**
+     * Icon name that depends on whether krusader runs with root-privileges or not
+     *
+     * @return icon name
+     */
+    static const char* appIconName();
 
 public slots:
+    void quit();
     void moveToTop();
     void statusBarUpdate(const QString& mess);
     // in use by Krusader only
@@ -132,13 +127,13 @@ protected slots:
     void doOpenUrl();
     void slotGotNewStartup(const KStartupInfoId &id, const KStartupInfoData &data);
     void slotGotRemoveStartup(const KStartupInfoId &id, const KStartupInfoData &data);
-    void showFromTray();
 
 protected:
+    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
     bool queryClose() Q_DECL_OVERRIDE;
     void setupActions();
     bool versionControl();  // handle version differences in krusaderrc
-    void changeEvent(QEvent *even) Q_DECL_OVERRIDE;
     bool event(QEvent *) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
@@ -174,11 +169,12 @@ private:
     ViewActions *_viewActions;
     ListPanelActions *_listPanelActions;
     TabActions *_tabActions;
-    QSystemTrayIcon *sysTray;
+    QPointer<KStatusNotifierItem> sysTray;
     bool         isStarting;
     bool         isExiting;
     QTimer      _openUrlTimer;
     QString     _urlToOpen;
+    bool        _quit;
 };
 
 
