@@ -1,36 +1,28 @@
-/***************************************************************************
-                               krusaderview.cpp
-                            -------------------
-   copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-   e-mail               : krusader@users.sourceforge.net
-   web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
- Description
-***************************************************************************
-
- A
-
-    db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-    88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-    88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-    88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-    88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-    YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                    S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krusaderview.h"
 
 // QtCore
+#include <QDebug>
 #include <QList>
 #include <QEvent>
 // QtGui
@@ -47,6 +39,7 @@
 #include <KWidgetsAddons/KToggleAction>
 
 #include "krusader.h"
+#include "icon.h"
 #include "kractions.h"
 #include "krslots.h"
 #include "defaults.h"
@@ -59,14 +52,14 @@
 #include "GUI/profilemanager.h"
 #include "Dialogs/percentalsplitter.h"
 #include "krservices.h"
-#include "Panel/krviewfactory.h"
 
 KrusaderView::KrusaderView(QWidget *parent) : QWidget(parent),
     activeMng(0)
 {
 }
 
-void KrusaderView::start(KConfigGroup &cfg, bool restoreSettings, const QList<QUrl> &leftTabs, const QList<QUrl> &rightTabs)
+void KrusaderView::start(const KConfigGroup &cfg, bool restoreSettings,
+                         const QList<QUrl> &leftTabs, const QList<QUrl> &rightTabs)
 {
     ////////////////////////////////
     // make a 1x1 mainLayout, it will auto-expand:
@@ -128,7 +121,7 @@ void KrusaderView::start(KConfigGroup &cfg, bool restoreSettings, const QList<QU
     leftPanel()->start(leftTabs.isEmpty() ? QUrl::fromLocalFile(QDir::homePath()) : leftTabs.at(0));
     rightPanel()->start(rightTabs.isEmpty() ? QUrl::fromLocalFile(QDir::homePath()) : rightTabs.at(0));
 
-    ACTIVE_PANEL->gui->slotFocusOnMe();  // left starts out active
+    activePanel()->gui->slotFocusOnMe();  // left starts out active
 
     for (int i = 1; i < leftTabs.count(); i++)
         leftMng->slotNewTab(leftTabs.at(i), false);
@@ -197,44 +190,47 @@ void KrusaderView::setPanelSize(bool leftPanel, int percent)
 
 PanelManager *KrusaderView::createManager(bool left)
 {
-    PanelManager *p = new PanelManager(horiz_splitter, krApp, left);
-    connect(p, SIGNAL(draggingTab(PanelManager*,QMouseEvent*)),
-                     SLOT(draggingTab(PanelManager*,QMouseEvent*)));
-    connect(p, SIGNAL(draggingTabFinished(PanelManager*,QMouseEvent*)),
-                     SLOT(draggingTabFinished(PanelManager*,QMouseEvent*)));
-    connect(p, SIGNAL(pathChanged(ListPanel*)), SLOT(slotPathChanged(ListPanel*)));
-    connect(p, SIGNAL(setActiveManager(PanelManager*)),
-                     SLOT(slotSetActiveManager(PanelManager*)));
+    PanelManager *panelManager = new PanelManager(horiz_splitter, krApp, left);
+    connect(panelManager, &PanelManager::draggingTab, this, &KrusaderView::draggingTab);
+    connect(panelManager, &PanelManager::draggingTabFinished, this, &KrusaderView::draggingTabFinished);
+    connect(panelManager, &PanelManager::pathChanged, this, &KrusaderView::slotPathChanged);
+    connect(panelManager, &PanelManager::setActiveManager, this, &KrusaderView::slotSetActiveManager);
 
-    return p;
+    return panelManager;
 }
 
-ListPanel* KrusaderView::leftPanel()
+void KrusaderView::updateCurrentActivePath()
 {
-    return leftMng->currentPanel()->gui;
+    const QString path = activePanel()->gui->lastLocalPath();
+
+    _cmdLine->setCurrent(path);
+    KConfigGroup cfg = krConfig->group("General");
+    if (_terminalDock->isInitialised() && cfg.readEntry("Send CDs", _SendCDs)) {
+        _terminalDock->sendCd(path);
+    }
 }
 
-ListPanel* KrusaderView::rightPanel()
+KrPanel *KrusaderView::activePanel() const
 {
-    return rightMng->currentPanel()->gui;
+    // active manager might not be set yet
+    return activeMng ? activeMng->currentPanel() : nullptr;
 }
 
+ListPanel *KrusaderView::leftPanel() const { return leftMng->currentPanel()->gui; }
+
+ListPanel *KrusaderView::rightPanel() const { return rightMng->currentPanel()->gui; }
+
 // updates the command line whenever current panel or its path changes
-//////////////////////////////////////////////////////////
-void KrusaderView::slotPathChanged(ListPanel *p)
+void KrusaderView::slotPathChanged(ListPanel *listPanel)
 {
-    if(p == ACTIVE_PANEL) {
-        _cmdLine->setCurrent(p->lastLocalPath());
-        KConfigGroup cfg = krConfig->group("General");
-        if (cfg.readEntry("Send CDs", _SendCDs)) { // hopefully, this is cached in kconfig
-            _terminalDock->sendCd(p->lastLocalPath());
-        }
+    if (listPanel == activePanel()) {
+        updateCurrentActivePath();
     }
 }
 
 int KrusaderView::getFocusCandidates(QVector<QWidget*> &widgets)
 {
-    ACTIVE_PANEL->gui->getFocusCandidates(widgets);
+    activePanel()->gui->getFocusCandidates(widgets);
     if(_terminalDock->isTerminalVisible())
         widgets << _terminalDock;
     if(_cmdLine->isVisible())
@@ -249,6 +245,7 @@ int KrusaderView::getFocusCandidates(QVector<QWidget*> &widgets)
 
 void KrusaderView::focusUp()
 {
+    qDebug() << "focus UP";
     QVector<QWidget*> widgets;
     int currentFocus = getFocusCandidates(widgets);
 
@@ -262,6 +259,7 @@ void KrusaderView::focusUp()
 
 void KrusaderView::focusDown()
 {
+    qDebug() << "focus DOWN";
     QVector<QWidget*> widgets;
     int currentFocus = getFocusCandidates(widgets);
 
@@ -280,19 +278,19 @@ void KrusaderView::cmdLineFocus()    // command line receive's keyboard focus
 
 void KrusaderView::cmdLineUnFocus()   // return focus to the active panel
 {
-    ACTIVE_PANEL->gui->slotFocusOnMe();
+    activePanel()->gui->slotFocusOnMe();
 }
 
 // Tab - switch focus
 void KrusaderView::panelSwitch()
 {
-    ACTIVE_PANEL->otherPanel()->gui->slotFocusOnMe();
+    activePanel()->otherPanel()->gui->slotFocusOnMe();
 }
 
 void KrusaderView::slotSetActiveManager(PanelManager *manager)
 {
     activeMng = manager;
-    slotPathChanged(manager->currentPanel()->gui);
+    updateCurrentActivePath();
 }
 
 void KrusaderView::swapSides()
@@ -320,6 +318,8 @@ void KrusaderView::swapSides()
 
 void KrusaderView::setTerminalEmulator(bool show, bool fullscreen)
 {
+    qDebug() << "show=" << show << " fullscreen=" << fullscreen;
+
     static bool fnKeysShown = true; // first time init. should be overridden
     static bool cmdLineShown = true;
     static bool statusBarShown = true;
@@ -353,7 +353,7 @@ void KrusaderView::setTerminalEmulator(bool show, bool fullscreen)
 
             _terminalDock->show();
             _terminalDock->setFocus();
-            slotPathChanged(ACTIVE_PANEL->gui);
+            updateCurrentActivePath();
             KrActions::actToggleTerminal->setChecked(true);
         } else if (fullscreen) {
             // save current terminal size before going to fullscreen
@@ -380,9 +380,10 @@ void KrusaderView::setTerminalEmulator(bool show, bool fullscreen)
         const bool isFullscreen = isTerminalEmulatorFullscreen();
         if (!(fullscreen && terminalEmulatorShown)) {
             // hide terminal emulator
-            ACTIVE_PANEL->gui->slotFocusOnMe();
-            if (_terminalDock->isTerminalVisible() && !isFullscreen)
+            activePanel()->gui->slotFocusOnMe();
+            if (_terminalDock->isTerminalVisible() && !isFullscreen) {
                 verticalSplitterSizes = vert_splitter->sizes();
+            }
             _terminalDock->hide();
             KrActions::actToggleTerminal->setChecked(false);
         } else {
@@ -421,7 +422,7 @@ bool KrusaderView::isTerminalEmulatorFullscreen() {
 
 void KrusaderView::profiles(QString profileName)
 {
-    ProfileManager profileManager("Panel");
+    ProfileManager profileManager("Panel", this);
     profileManager.hide();
     connect(&profileManager, SIGNAL(saveToProfile(QString)), this, SLOT(savePanelProfiles(QString)));
     connect(&profileManager, SIGNAL(loadFromProfile(QString)), this, SLOT(loadPanelProfiles(QString)));
@@ -447,7 +448,7 @@ void KrusaderView::savePanelProfiles(QString group)
     KConfigGroup svr(krConfig, group);
 
     svr.writeEntry("Vertical Mode", isVertical());
-    svr.writeEntry("Left Side Is Active", ACTIVE_PANEL->gui->isLeft());
+    svr.writeEntry("Left Side Is Active", activePanel()->gui->isLeft());
     leftMng->saveSettings(KConfigGroup(&svr, "Left Tabs"), false);
     rightMng->saveSettings(KConfigGroup(&svr, "Right Tabs"), false);
 }
@@ -457,11 +458,11 @@ void KrusaderView::toggleVerticalMode()
     if (horiz_splitter->orientation() == Qt::Vertical) {
         horiz_splitter->setOrientation(Qt::Horizontal);
         KrActions::actVerticalMode->setText(i18n("Vertical Mode"));
-        KrActions::actVerticalMode->setIcon(QIcon::fromTheme("view-split-top-bottom"));
+        KrActions::actVerticalMode->setIcon(Icon("view-split-top-bottom"));
     } else {
         horiz_splitter->setOrientation(Qt::Vertical);
         KrActions::actVerticalMode->setText(i18n("Horizontal Mode"));
-        KrActions::actVerticalMode->setIcon(QIcon::fromTheme("view-split-left-right"));
+        KrActions::actVerticalMode->setIcon(Icon("view-split-left-right"));
     }
 }
 
@@ -475,7 +476,7 @@ void KrusaderView::saveSettings(KConfigGroup &cfg)
                                        vert_splitter->sizes() : verticalSplitterSizes;
     cfg.writeEntry("Terminal Emulator Splitter Sizes", vertSplitterSizes);
     cfg.writeEntry("Vertical Mode", isVertical());
-    cfg.writeEntry("Left Side Is Active", ACTIVE_PANEL->gui->isLeft());
+    cfg.writeEntry("Left Side Is Active", activePanel()->gui->isLeft());
     leftMng->saveSettings(KConfigGroup(&cfg, "Left Tab Bar"), true);
     rightMng->saveSettings(KConfigGroup(&cfg, "Right Tab Bar"), true);
 }
@@ -510,7 +511,7 @@ void KrusaderView::draggingTab(PanelManager *from, QMouseEvent *e)
     else
         icon = (from == leftMng) ? "arrow-down" : "arrow-up";
 
-    QCursor cursor(QIcon::fromTheme(icon).pixmap(22));
+    QCursor cursor(Icon(icon).pixmap(22));
 
     if (cursorIsOnOtherSide(from, e->globalPos())) {
         if(!qApp->overrideCursor())
