@@ -1,32 +1,23 @@
-/***************************************************************************
-                                main.cpp
-                             -------------------
-    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include <csignal>
 #include <unistd.h>
@@ -35,9 +26,10 @@
 #include <QAbstractEventDispatcher>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QDebug>
+#include <QDir>
 #include <QEventLoop>
 #include <QStandardPaths>
-#include <QDir>
 // QtGui
 #include <QPixmap>
 // QtDBus
@@ -55,13 +47,14 @@
 
 #include "../Archive/krarchandler.h"
 
+#include "defaults.h"
+#include "krservices.h"
+#include "krslots.h"
 #include "krusader.h"
+#include "icon.h"
+#include "krusaderversion.h"
 #include "krusaderview.h"
 #include "panelmanager.h"
-#include "krusaderversion.h"
-#include "krslots.h"
-#include "defaults.h"
-#include "Panel/krviewfactory.h"
 
 static const char *description = I18N_NOOP("Krusader\nTwin-Panel File Manager by KDE");
 
@@ -99,38 +92,8 @@ KRarcHandler arcHandler;
 
 int main(int argc, char *argv[])
 {
-// ============ begin icon-stuff ===========
-// If the user has no icon specified over the commandline we set up our own.
-// this is according to the users privileges. The icons are in Krusader::privIcon()
-
-/*    bool hasIcon = false;
-    int i = 0;
-    char * myArgv[argc+2];*/
-
-// if no --miniicon is given, --icon is used. So we don't need to check for --miniicon separately
-/*    for (i = 0; i < argc; ++i) {
-        if (strstr(argv[ i ], "-icon") != 0)   // important: just one dash because both can appear!
-            hasIcon = true;
-    }
-
-    static const char* const icon_text = "--icon";
-    const char* icon_name = Krusader::privIcon();
-    char addedParams[strlen(icon_text)+strlen(icon_name)+2];
-
-    if (! hasIcon) {
-        for (i = 0; i < argc; ++i)
-            myArgv[ i ] = argv[ i ];
-
-        strcpy(addedParams, icon_text);
-        strcpy(addedParams + strlen(icon_text) + 1, icon_name);
-
-        myArgv[ argc ] = addedParams;
-        myArgv[ ++argc ] = addedParams + strlen(icon_text) + 1;
-        myArgv[ ++argc ] = 0;
-
-        argv = myArgv;
-    }*/
-// ============ end icon-stuff ===========
+    // set global log message format
+    qSetMessagePattern(KrServices::GLOBAL_MESSAGE_PATTERN);
 
     // prevent qt5-webengine crashing
     QApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
@@ -139,6 +102,12 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("krusader");
 
+    // init icon theme
+    qDebug() << "System icon theme:" << QIcon::themeName();
+    // [WORKAROUND] setThemeName sets user theme in QIconLoader and allows to avoid Qt issues with invalid icon caching later
+    // IMPORTANT: this must be done before the first QIcon::fromTheme / QIcon::hasThemeIcon call
+    QIcon::setThemeName(QIcon::themeName());
+
     // ABOUT data information
 #ifdef RELEASE_NAME
     QString versionName = QString("%1 \"%2\"").arg(VERSION).arg(RELEASE_NAME);
@@ -149,25 +118,29 @@ int main(int argc, char *argv[])
     KAboutData aboutData(QStringLiteral("krusader"),
         (geteuid() ? i18n("Krusader") : i18n("Krusader - ROOT PRIVILEGES")), versionName,
         i18n(description), KAboutLicense::GPL_V2,
-        i18n("(c) 2000-2003, Shie Erlich, Rafi Yanai\n(c) 2004-2016, Krusader Krew"),
+        i18n("© 2000-2003 Shie Erlich, Rafi Yanai\n© 2004-2018 Krusader Krew"),
         i18n("Feedback:\nhttps://forum.kde.org/viewforum.php?f=225\n\nIRC\nserver: "
              "irc.freenode.net, channel: #krusader"),
         QStringLiteral("https://krusader.org"));
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
+    aboutData.setDesktopFileName(QStringLiteral("org.kde.krusader"));
 
-    aboutData.addAuthor(i18n("Rafi Yanai"), i18n("Author (retired)"), QStringLiteral("yanai@users.sourceforge.net"));
-    aboutData.addAuthor(i18n("Shie Erlich"), i18n("Author (retired)"), QStringLiteral("erlich@users.sourceforge.net"));
-    aboutData.addAuthor(i18n("Jan Lepper"), i18n("Developer"), QStringLiteral("jan_lepper@gmx.de"), 0);
-    aboutData.addAuthor(i18n("Andrey Matveyakin"), i18n("Developer"), QStringLiteral("a.matveyakin@gmail.com"), 0);
-    aboutData.addAuthor(i18n("Simon Persson"), i18n("Developer"), QStringLiteral("simon.persson@mykolab.com"), 0);
     aboutData.addAuthor(i18n("Davide Gianforte"), i18n("Developer"), QStringLiteral("davide@gengisdave.org"), 0);
     aboutData.addAuthor(i18n("Toni Asensi Esteve"), i18n("Developer"), QStringLiteral("toni.asensi@kdemail.net"), 0);
     aboutData.addAuthor(i18n("Alexander Bikadorov"), i18n("Developer"), QStringLiteral("alex.bikadorov@kdemail.net"), 0);
-    aboutData.addAuthor(i18n("Karai Csaba"), i18n("Developer (retired)"), QStringLiteral("ckarai@users.sourceforge.net"), 0);
+    aboutData.addAuthor(i18n("Martin Kostolný"), i18n("Developer"), QStringLiteral("clearmartin@gmail.com"), 0);
+    aboutData.addAuthor(i18n("Nikita Melnichenko"), i18n("Developer"), QStringLiteral("nikita+kde@melnichenko.name"), 0);
+    aboutData.addAuthor(i18n("Yuri Chornoivan"), i18n("Documentation"), QStringLiteral("yurchor@ukr.net"), 0);
+    aboutData.addAuthor(i18n("Rafi Yanai"), i18n("Author (retired)"), QStringLiteral("yanai@users.sourceforge.net"));
+    aboutData.addAuthor(i18n("Shie Erlich"), i18n("Author (retired)"), QStringLiteral("erlich@users.sourceforge.net"));
+    aboutData.addAuthor(i18n("Csaba Karai"), i18n("Developer (retired)"), QStringLiteral("ckarai@users.sourceforge.net"), 0);
     aboutData.addAuthor(i18n("Heiner Eichmann"), i18n("Developer (retired)"), QStringLiteral("h.eichmann@gmx.de"), 0);
     aboutData.addAuthor(i18n("Jonas Bähr"), i18n("Developer (retired)"), QStringLiteral("jonas.baehr@web.de"), 0);
     aboutData.addAuthor(i18n("Václav Jůza"), i18n("Developer (retired)"), QStringLiteral("vaclavjuza@gmail.com"), 0);
+    aboutData.addAuthor(i18n("Jan Lepper"), i18n("Developer (retired)"), QStringLiteral("jan_lepper@gmx.de"), 0);
+    aboutData.addAuthor(i18n("Andrey Matveyakin"), i18n("Developer (retired)"), QStringLiteral("a.matveyakin@gmail.com"), 0);
+    aboutData.addAuthor(i18n("Simon Persson"), i18n("Developer (retired)"), QStringLiteral("simon.persson@mykolab.com"), 0);
     aboutData.addAuthor(i18n("Dirk Eschler"), i18n("Webmaster (retired)"), QStringLiteral("deschler@users.sourceforge.net"), 0);
     aboutData.addAuthor(i18n("Frank Schoolmeesters"), i18n("Documentation and marketing coordinator (retired)"), QStringLiteral("frank_schoolmeesters@yahoo.com"), 0);
     aboutData.addAuthor(i18n("Richard Holt"), i18n("Documentation & Proofing (retired)"), QStringLiteral("richard.holt@gmail.com"), 0);
@@ -231,7 +204,7 @@ int main(int argc, char *argv[])
     // This will call QCoreApplication::setApplicationName, etc for us by using info in the KAboutData instance.
     // The only thing not called for us is setWindowIcon(), which is why we do it ourselves here.
     KAboutData::setApplicationData(aboutData);
-    app.setWindowIcon(QIcon::fromTheme(Krusader::privIcon()));
+    app.setWindowIcon(Icon(Krusader::appIconName()));
 
     // Command line arguments ...
     QCommandLineParser parser;
@@ -239,12 +212,16 @@ int main(int argc, char *argv[])
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("left"), i18n("Start left panel at <path>"), QLatin1String("path")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("right"), i18n("Start right panel at <path>"), QLatin1String("path")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("profile"), i18n("Load this profile on startup"), QLatin1String("panel-profile")));
+    parser.addOption(QCommandLineOption(QStringList() << "d" << QLatin1String("debug"), i18n("Enable debug output")));
     parser.addPositionalArgument(QLatin1String("url"), i18n("URL to open"));
 
     // check for command line arguments
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+    // set global message handler
+    KrServices::setGlobalKrMessageHandler(parser.isSet("debug"));
+
     KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("Look&Feel"));
     bool singleInstanceMode = cfg.readEntry("Single Instance Mode", _SingleInstanceMode);
 
@@ -276,7 +253,6 @@ int main(int argc, char *argv[])
 
         if (reply.isValid() && (bool)reply) {
             KStartupInfo::appStarted();
-            QStringList tabs;
             if (parser.isSet("left"))
                 openTabsRemote(parser.value("left").split(','), true, appName);
             if (parser.isSet("right"))
@@ -324,8 +300,6 @@ int main(int argc, char *argv[])
         fprintf(stderr, "DBus Error: %s, %s\n", dbus.lastError().name().toLocal8Bit().constData(), dbus.lastError().message().toLocal8Bit().constData());
     }
 
-
-
     // catching SIGTERM, SIGHUP, SIGQUIT
     signal(SIGTERM, sigterm_handler);
     signal(SIGPIPE, sigterm_handler);
@@ -340,5 +314,4 @@ int main(int argc, char *argv[])
     }
     // let's go.
     return app.exec();
-
 }
