@@ -1,31 +1,34 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "panelmanager.h"
 
 #include "defaults.h"
+#include "icon.h"
 #include "tabactions.h"
 #include "krusaderview.h"
 #include "krmainwindow.h"
 #include "Panel/listpanel.h"
 #include "Panel/panelfunc.h"
-#include "Panel/krviewfactory.h"
+#include "Panel/PanelView/krviewfactory.h"
 
 #include <assert.h>
 
@@ -38,18 +41,15 @@
 
 #include <KConfigCore/KConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 
 
-#define HIDE_ON_SINGLE_TAB  false
-
 PanelManager::PanelManager(QWidget *parent, KrMainWindow* mainWindow, bool left) :
         QWidget(parent),
         _otherManager(0),
         _actions(mainWindow->tabActions()),
         _layout(0),
         _left(left),
-        _self(0)
+        _currentPanel(0)
 {
     _layout = new QGridLayout(this);
     _layout->setContentsMargins(0, 0, 0, 0);
@@ -61,7 +61,7 @@ PanelManager::PanelManager(QWidget *parent, KrMainWindow* mainWindow, bool left)
     _newTab->setAutoRaise(true);
     _newTab->setText(i18n("Open a new tab in home"));
     _newTab->setToolTip(i18n("Open a new tab in home"));
-    _newTab->setIcon(SmallIcon("tab-new"));
+    _newTab->setIcon(Icon("tab-new"));
     _newTab->adjustSize();
     connect(_newTab, SIGNAL(clicked()), this, SLOT(slotNewTab()));
 
@@ -95,15 +95,12 @@ PanelManager::PanelManager(QWidget *parent, KrMainWindow* mainWindow, bool left)
 
 void PanelManager::tabsCountChanged()
 {
-    bool showTabbar = true;
-    if (_tabbar->count() <= 1 && HIDE_ON_SINGLE_TAB)
-        showTabbar = false;
+    const KConfigGroup cfg(krConfig, "Look&Feel");
+    const bool showTabbar = _tabbar->count() > 1 || cfg.readEntry("Show Tab Bar On Single Tab", true);
+    const bool showButtons = showTabbar && cfg.readEntry("Show Tab Buttons", true);
 
-    KConfigGroup cfg(krConfig, "Look&Feel");
-    bool showButtons = showTabbar && cfg.readEntry("Show Tab Buttons", true);
-
-    _newTab->setVisible(showButtons);
     _tabbar->setVisible(showTabbar);
+    _newTab->setVisible(showButtons);
 
     // disable close button if only 1 tab is left
     _tabbar->setTabsClosable(showButtons && _tabbar->count() > 1);
@@ -119,26 +116,32 @@ void PanelManager::activate()
 }
 
 void PanelManager::slotCurrentTabChanged(int index)
-// void PanelManager::slotChangePanel(ListPanel *p, bool makeActive)
 {
-    ListPanel *p = _tabbar->getPanel(index);
+    ListPanel *panel = _tabbar->getPanel(index);
 
-    if (!p || p == _self)
+    if (!panel || panel == _currentPanel)
         return;
 
-    ListPanel *prev = _self;
-    _self = p;
+    ListPanel *previousPanel = _currentPanel;
+    _currentPanel = panel;
 
-    _stack->setCurrentWidget(_self);
+    _stack->setCurrentWidget(_currentPanel);
 
-    if(prev)
-        prev->slotFocusOnMe(false); //FIXME - necessary ?
-    _self->slotFocusOnMe(this == ACTIVE_MNG);
+    if (previousPanel) {
+        previousPanel->slotFocusOnMe(false); // FIXME - necessary ?
+    }
+    _currentPanel->slotFocusOnMe(this == ACTIVE_MNG);
 
-    emit pathChanged(p);
+    emit pathChanged(panel);
 
-    if(otherManager())
+    if (otherManager()) {
         otherManager()->currentPanel()->otherPanelChanged();
+    }
+
+    // go back to pinned url if tab is pinned and switched back to active
+    if (panel->isPinned()) {
+        panel->func->openUrl(panel->pinnedUrl());
+    }
 }
 
 ListPanel* PanelManager::createPanel(KConfigGroup cfg)
@@ -206,6 +209,7 @@ void PanelManager::loadSettings(KConfigGroup config)
 
         ListPanel *panel = i < numTabsOld ? _tabbar->getPanel(i) : addPanel(false, grpTab);
         panel->restoreSettings(grpTab);
+        _tabbar->updateTab(panel);
     }
 
     for(int i = numTabsOld - 1; i >= numTabsNew && i > 0; i--)
@@ -224,9 +228,13 @@ void PanelManager::layoutTabs()
     QTimer::singleShot(0, _tabbar, SLOT(layoutTabs()));
 }
 
+KrPanel *PanelManager::currentPanel() const {
+    return _currentPanel;
+}
+
 void PanelManager::moveTabToOtherSide()
 {
-    if(tabCount() < 2)
+    if (tabCount() < 2)
         return;
 
     ListPanel *p;
@@ -257,19 +265,18 @@ void PanelManager::slotNewTab(const QUrl &url, bool setCurrent, KrPanel *nextTo)
         KConfigGroup cfg(krConfig, grpName);
 
         nextTo->gui->saveSettings(cfg, true);
+        // reset undesired duplicated settings
+        cfg.writeEntry("Properties", 0);
         p->restoreSettings(cfg);
         krConfig->deleteGroup(grpName);
-
-        // reset undesired duplicated settings
-        p->setLocked(false);
     }
-    else
-        p->start(url);
+    p->start(url);
 }
 
 void PanelManager::slotNewTab()
 {
     slotNewTab(QUrl::fromLocalFile(QDir::home().absolutePath()));
+    _currentPanel->slotFocusOnMe();
 }
 
 void PanelManager::slotCloseTab()
@@ -280,13 +287,10 @@ void PanelManager::slotCloseTab()
 void PanelManager::slotCloseTab(int index)
 {
     if (_tabbar->count() <= 1)    /* if this is the last tab don't close it */
-        return ;
+        return;
 
     ListPanel *oldp;
 
-//     if (index == _tabbar->currentIndex())
-//         slotChangePanel(_tabbar->removeCurrentPanel(oldp), false);
-//     else
     _tabbar->removePanel(index, oldp); //this automatically changes the current panel
 
     _stack->removeWidget(oldp);
@@ -333,9 +337,9 @@ void PanelManager::slotRecreatePanels()
         _stack->insertWidget(i, newPanel);
         _tabbar->changePanel(i, newPanel);
 
-        if (_self == oldPanel) {
-            _self = newPanel;
-            _stack->setCurrentWidget(_self);
+        if (_currentPanel == oldPanel) {
+            _currentPanel = newPanel;
+            _stack->setCurrentWidget(_currentPanel);
         }
 
         _stack->removeWidget(oldPanel);
@@ -348,8 +352,8 @@ void PanelManager::slotRecreatePanels()
         krConfig->deleteGroup(grpName);
     }
     tabsCountChanged();
-    _self->slotFocusOnMe(this == ACTIVE_MNG);
-    emit pathChanged(_self);
+    _currentPanel->slotFocusOnMe(this == ACTIVE_MNG);
+    emit pathChanged(_currentPanel);
 }
 
 void PanelManager::slotNextTab()
@@ -367,15 +371,13 @@ void PanelManager::slotPreviousTab()
     _tabbar->setCurrentIndex(nextInd);
 }
 
-void PanelManager::refreshAllTabs()
+void PanelManager::reloadConfig()
 {
-    int i = 0;
-    while (i < _tabbar->count()) {
+    for (int i = 0; i < _tabbar->count(); i++) {
         ListPanel *panel = _tabbar->getPanel(i);
         if (panel) {
             panel->func->refresh();
         }
-        ++i;
     }
 }
 
@@ -436,17 +438,25 @@ int PanelManager::findTab(QUrl url)
 
 void PanelManager::slotLockTab()
 {
-    currentPanel()->gui->setLocked(!currentPanel()->gui->isLocked());
+    ListPanel *panel = _currentPanel;
+    panel->gui->setTabState(panel->gui->isLocked() ? ListPanel::TabState::DEFAULT : ListPanel::TabState::LOCKED);
     _actions->refreshActions();
+    _tabbar->updateTab(panel);
+}
+
+void PanelManager::slotPinTab()
+{
+    ListPanel *panel = _currentPanel;
+    panel->gui->setTabState(panel->gui->isPinned() ? ListPanel::TabState::DEFAULT : ListPanel::TabState::PINNED);
+    if (panel->gui->isPinned()) {
+        QUrl virtualPath = panel->virtualPath();
+        panel->setPinnedUrl(virtualPath);
+    }
+    _actions->refreshActions();
+    _tabbar->updateTab(panel);
 }
 
 void PanelManager::newTabs(const QStringList& urls) {
     for(int i = 0; i < urls.count(); i++)
         slotNewTab(QUrl::fromUserInput(urls[i], QString(), QUrl::AssumeLocalFile));
 }
-
-KrPanel *PanelManager::currentPanel()
-{
-    return _self;
-}
-
