@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #ifndef PANELMANAGER_H
@@ -63,7 +65,8 @@ public:
     int activeTab();
     void setActiveTab(int index);
     void moveTabToOtherSide();
-    void refreshAllTabs();
+    /** Refresh all tabs after config changes. */
+    void reloadConfig();
     void layoutTabs();
     void setLeft(bool left) {
         _left = left;
@@ -73,13 +76,9 @@ public:
     }
 
     // AbstractPanelManager implementation
-    virtual bool isLeft() Q_DECL_OVERRIDE {
-        return _left;
-    }
-    virtual AbstractPanelManager *otherManager() Q_DECL_OVERRIDE {
-        return _otherManager;
-    }
-    virtual KrPanel *currentPanel() Q_DECL_OVERRIDE;
+    virtual bool isLeft() const Q_DECL_OVERRIDE { return _left; }
+    virtual AbstractPanelManager *otherManager() const Q_DECL_OVERRIDE { return _otherManager; }
+    virtual KrPanel *currentPanel() const Q_DECL_OVERRIDE;
     virtual void newTab(const QUrl &url, KrPanel *nextTo) Q_DECL_OVERRIDE {
         slotNewTab(url, true, nextTo);
     }
@@ -104,6 +103,7 @@ public slots:
     void slotNewTab(const QUrl &url, bool setCurrent = true, KrPanel *nextTo = 0);
     void slotNewTab();
     void slotLockTab();
+    void slotPinTab();
     void slotNextTab();
 
     void slotPreviousTab();
@@ -140,7 +140,7 @@ private:
     PanelTabBar *_tabbar;
     QStackedWidget *_stack;
     QToolButton *_newTab;
-    ListPanel *_self;
+    ListPanel *_currentPanel;
 };
 
 
