@@ -1,21 +1,24 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
- * based on original code from Sebastian Trueg <trueg@kde.org>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * Based on original code from Sebastian Trueg <trueg@kde.org>               *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "paneltabbar.h"
@@ -23,7 +26,9 @@
 #include "defaults.h"
 #include "tabactions.h"
 #include "../krglobal.h"
+#include "../icon.h"
 #include "Panel/listpanel.h"
+#include "Panel/panelfunc.h"
 
 // QtCore
 #include <QEvent>
@@ -39,10 +44,11 @@
 #include <KI18n/KLocalizedString>
 #include <KWidgetsAddons/KActionMenu>
 
-#define DISPLAY(X) (X.isLocalFile() ? X.path() : X.toDisplayString())
+
+static const int sDragEnterDelay = 500; // msec
 
 PanelTabBar::PanelTabBar(QWidget *parent, TabActions *actions): QTabBar(parent),
-    _maxTabLength(0), _tabClicked(false), _draggingTab(false)
+    _maxTabLength(0), _tabClicked(false), _draggingTab(false), _dragTabIndex(-1)
 {
     _panelActionMenu = new KActionMenu(i18n("Panel"), this);
 
@@ -50,6 +56,7 @@ PanelTabBar::PanelTabBar(QWidget *parent, TabActions *actions): QTabBar(parent),
 
     insertAction(actions->actNewTab);
     insertAction(actions->actLockTab);
+    insertAction(actions->actPinTab);
     insertAction(actions->actDupTab);
     insertAction(actions->actMoveTabToOtherSide);
     insertAction(actions->actCloseTab);
@@ -57,6 +64,15 @@ PanelTabBar::PanelTabBar(QWidget *parent, TabActions *actions): QTabBar(parent),
     insertAction(actions->actCloseDuplicatedTabs);
 
     setMovable(true); // enable drag'n'drop
+    _dragTimer = new QTimer(this);
+    _dragTimer->setSingleShot(true);
+    _dragTimer->setInterval(sDragEnterDelay);
+    connect(_dragTimer, &QTimer::timeout, this, [=]() {
+        if (_dragTabIndex != -1 && _dragTabIndex != currentIndex()) {
+            setCurrentIndex(_dragTabIndex);
+        }
+        _dragTabIndex = -1;
+    });
 
     setShape(QTabBar::TriangularSouth);
 }
@@ -70,32 +86,31 @@ int PanelTabBar::addPanel(ListPanel *panel, bool setCurrent, KrPanel *nextTo)
 {
     int insertIndex = -1;
 
-    if(nextTo) {
-        for(int i = 0; i < count(); i++) {
-            if(getPanel(i) == nextTo) {
+    if (nextTo) {
+        for (int i = 0; i < count(); i++) {
+            if (getPanel(i) == nextTo) {
                 insertIndex = i + 1;
                 break;
             }
         }
     }
 
-    int newId;
-    if(insertIndex != -1) {
-        newId = insertTab(insertIndex, squeeze(DISPLAY(panel->virtualPath())));
-    } else
-        newId = addTab(squeeze(DISPLAY(panel->virtualPath())));
+    QUrl virtualPath = panel->virtualPath();
+    panel->setPinnedUrl(virtualPath);
+    const QString text = squeeze(virtualPath);
+    const int index = insertIndex != -1 ? insertTab(insertIndex, text) : addTab(text);
 
-    QVariant v;
-    v.setValue((long long)panel);
-    setTabData(newId, v);
+    setTabData(index, QVariant((long long) panel));
+
+    setIcon(index, panel);
 
     // make sure all tabs lengths are correct
     layoutTabs();
 
     if (setCurrent)
-        setCurrentIndex(newId);
+        setCurrentIndex(index);
 
-    return newId;
+    return index;
 }
 
 ListPanel* PanelTabBar::getPanel(int tabIdx)
@@ -107,9 +122,7 @@ ListPanel* PanelTabBar::getPanel(int tabIdx)
 
 void PanelTabBar::changePanel(int tabIdx, ListPanel *panel)
 {
-    QVariant v;
-    v.setValue((long long)panel);
-    setTabData(tabIdx, v);
+    setTabData(tabIdx, QVariant((long long) panel));
 }
 
 ListPanel* PanelTabBar::removePanel(int index, ListPanel* &panelToDelete)
@@ -133,7 +146,8 @@ void PanelTabBar::updateTab(ListPanel *panel)
     // find which is the correct tab
     for (int i = 0; i < count(); i++) {
         if ((ListPanel*)tabData(i).toLongLong() == panel) {
-            setTabText(i, squeeze(DISPLAY(panel->virtualPath()), i));
+            setPanelTextToTab(i, panel);
+            setIcon(i, panel);
             break;
         }
     }
@@ -145,95 +159,81 @@ void PanelTabBar::duplicateTab()
     emit newTab(((ListPanel*)tabData(id).toLongLong())->virtualPath());
 }
 
-void PanelTabBar::closeTab()
+void PanelTabBar::setIcon(int index, ListPanel *panel)
 {
-    emit closeCurrentTab();
+    Icon tabIcon;
+    if (panel->isLocked()) {
+        tabIcon = Icon("lock");
+    } else if (panel->isPinned()) {
+        tabIcon = Icon("pin");
+    }
+    setTabIcon(index, tabIcon);
 }
 
-QString PanelTabBar::squeeze(QString text, int index)
+QString PanelTabBar::squeeze(const QUrl &url, int tabIndex)
 {
-    QString originalText = text;
+    const QString longText = url.isEmpty() ? i18n("[invalid]") :
+                                             url.isLocalFile() ? url.path() : url.toDisplayString();
+    if (tabIndex >= 0)
+        setTabToolTip(tabIndex, longText);
 
-    KConfigGroup group(krConfig, "Look&Feel");
-    bool longNames = group.readEntry("Fullpath Tab Names", _FullPathTabNames);
+    const KConfigGroup group(krConfig, "Look&Feel");
+    const bool showLongNames = group.readEntry("Fullpath Tab Names", _FullPathTabNames);
 
-    if (!longNames) {
-        while (text.endsWith('/'))
-            text.truncate(text.length() - 1);
-        if (text.isEmpty() || text.endsWith(':'))
-            text += '/';
-        else {
-            QString shortName;
-
-            if (text.contains(":/"))
-                shortName = text.left(text.indexOf(":/")) + ':';
-
-            shortName += text.mid(text.lastIndexOf("/") + 1);
-            text = shortName;
-        }
-
-        if (index >= 0)
-            setTabToolTip(index, originalText);
-
-        index = -1;
+    QString text;
+    if (!showLongNames) {
+        const QString scheme = url.scheme().isEmpty() || url.isLocalFile() ? "" : (url.scheme() + ":");
+        const QString host = url.host().isEmpty() ? "" : (url.host() + ":");
+        const QString name = url.isLocalFile() && url.fileName().isEmpty() ? "/" : url.fileName();
+        text = scheme + host + name;
+    } else {
+        text = longText;
     }
 
-    QFontMetrics fm(fontMetrics());
+    if (text.isEmpty())
+        text = i18nc("invalid URL path", "?");
 
     // set the real max length
+    QFontMetrics fm(fontMetrics());
     _maxTabLength = (static_cast<QWidget*>(parent())->width() - (6 * fm.width("W"))) / fm.width("W");
     // each tab gets a fair share of the max tab length
-    int _effectiveTabLength = _maxTabLength / (count() == 0 ? 1 : count());
+    const int effectiveTabLength = _maxTabLength / (count() == 0 ? 1 : count());
+    const int labelWidth = fm.width("W") * effectiveTabLength;
+    const int textWidth = fm.width(text);
+    if (textWidth <= labelWidth)
+        return text;
 
-    int labelWidth = fm.width("W") * _effectiveTabLength;
-    int textWidth = fm.width(text);
-    if (textWidth > labelWidth) {
-        // start with the dots only
-        QString squeezedText = "...";
-        int squeezedWidth = fm.width(squeezedText);
+    // squeeze text - start with the dots only
+    QString squeezedText = "...";
+    int squeezedWidth = fm.width(squeezedText);
 
-        // estimate how many letters we can add to the dots on both sides
-        int letters = text.length() * (labelWidth - squeezedWidth) / textWidth / 2;
-        if (labelWidth < squeezedWidth) letters = 1;
+    int letters = text.length() * (labelWidth - squeezedWidth) / textWidth / 2;
+    if (labelWidth < squeezedWidth)
+        letters = 1;
+    squeezedText = text.left(letters) + "..." + text.right(letters);
+    squeezedWidth = fm.width(squeezedText);
+
+    if (squeezedWidth < labelWidth) {
+        // we estimated too short
+        // add letters while text < label
+        do {
+            letters++;
+            squeezedText = text.left(letters) + "..." + text.right(letters);
+            squeezedWidth = fm.width(squeezedText);
+        } while (squeezedWidth < labelWidth);
+        letters--;
         squeezedText = text.left(letters) + "..." + text.right(letters);
-        squeezedWidth = fm.width(squeezedText);
-
-        if (squeezedWidth < labelWidth) {
-            // we estimated too short
-            // add letters while text < label
-            do {
-                letters++;
-                squeezedText = text.left(letters) + "..." + text.right(letters);
-                squeezedWidth = fm.width(squeezedText);
-            } while (squeezedWidth < labelWidth);
+    } else if (squeezedWidth > labelWidth) {
+        // we estimated too long
+        // remove letters while text > label
+        do {
             letters--;
             squeezedText = text.left(letters) + "..." + text.right(letters);
-        } else if (squeezedWidth > labelWidth) {
-            // we estimated too long
-            // remove letters while text > label
-            do {
-                letters--;
-                squeezedText = text.left(letters) + "..." + text.right(letters);
-                squeezedWidth = fm.width(squeezedText);
-            } while (letters && squeezedWidth > labelWidth);
-        }
+            squeezedWidth = fm.width(squeezedText);
+        } while (letters && squeezedWidth > labelWidth);
+    }
 
-        if (index >= 0)
-            setTabToolTip(index, originalText);
-
-        if (letters < 5) {
-            // too few letters added -> we give up squeezing
-            //return text;
-            return squeezedText;
-        } else {
-            return squeezedText;
-        }
-    } else {
-        //if( index >= 0 )
-        //  removeTabToolTip( index );
-
-        return text;
-    };
+    return squeezedText;
 }
 
 void PanelTabBar::resizeEvent(QResizeEvent *e)
@@ -265,8 +265,8 @@ void PanelTabBar::mousePressEvent(QMouseEvent* e)
 
     setCurrentIndex(clickedTab);
 
-    ListPanel *p =  getPanel(clickedTab);
-    if(p)
+    ListPanel *p = getPanel(clickedTab);
+    if (p)
         p->slotFocusOnMe();
 
     if (e->button() == Qt::RightButton) {
@@ -292,29 +292,48 @@ void PanelTabBar::mouseReleaseEvent(QMouseEvent* e)
 void PanelTabBar::dragEnterEvent(QDragEnterEvent *e)
 {
     e->accept();
-    int t = tabAt(e->pos());
-    if (t == -1)
-        return;
-    if (currentIndex() != t)
-        setCurrentIndex(t);
+    handleDragEvent(tabAt(e->pos()));
     QTabBar::dragEnterEvent(e);
 }
 
+void PanelTabBar::dragLeaveEvent(QDragLeaveEvent *)
+{
+    handleDragEvent(-1);
+}
+
 void PanelTabBar::dragMoveEvent(QDragMoveEvent *e)
 {
     e->ignore();
-    int t = tabAt(e->pos());
-    if (t == -1) return;
-    if (currentIndex() != t)
-        setCurrentIndex(t);
+    handleDragEvent(tabAt(e->pos()));
     QTabBar::dragMoveEvent(e);
 }
 
+void PanelTabBar::handleDragEvent(int tabIndex)
+{
+    if (_dragTabIndex == tabIndex)
+        return;
+
+    _dragTabIndex = tabIndex;
+    if (_dragTabIndex == -1) {
+        _dragTimer->stop();
+    } else {
+        _dragTimer->start();
+    }
+}
+
 void PanelTabBar::layoutTabs()
 {
-   for (int i = 0; i < count(); i++) {
-        setTabText(i, squeeze(DISPLAY(((ListPanel*)tabData(i).toLongLong())->virtualPath()), i));
-        emit ((ListPanel*)tabData(i).toLongLong())->refreshPathLabel();
-   }
+    for (int i = 0; i < count(); i++) {
+        setPanelTextToTab(i, (ListPanel*) tabData(i).toLongLong());
+    }
 }
 
+void PanelTabBar::setPanelTextToTab(int tabIndex, ListPanel *panel)
+{
+    // update tab text from pinnedUrl in case the tab is pinned
+    if (panel->isPinned()) {
+        setTabText(tabIndex, squeeze(panel->pinnedUrl(), tabIndex));
+    } else {
+        setTabText(tabIndex, squeeze(panel->virtualPath(), tabIndex));
+    }
+}
